@@ -32,14 +32,14 @@ constant sampler_t samplerc =  CLK_NORMALIZED_COORDS_FALSE | CLK_ADDRESS_CLAMP
 #define ICLAMP(a, mn, mx) ((a) < (mn) ? (mn) : ((a) > (mx) ? (mx) : (a)))
 
 
-inline int
+static inline int
 FC(const int row, const int col, const unsigned int filters)
 {
   return filters >> ((((row) << 1 & 14) + ((col) & 1)) << 1) & 3;
 }
 
 
-inline int
+static inline int
 FCxtrans(const int row, const int col, global const unsigned char (*const xtrans)[6])
 {
   return xtrans[row % 6][col % 6];
