@@ -18,8 +18,10 @@
 
 #pragma once
 
-float dt_colorspaces_deltaE_1976(float Lab0[3], float Lab1[3]);
-float dt_colorspaces_deltaE_2000(float Lab0[3], float Lab1[3]);
+#include "common/darktable.h"
+
+float dt_colorspaces_deltaE_1976(dt_aligned_pixel_t Lab0, dt_aligned_pixel_t Lab1);
+float dt_colorspaces_deltaE_2000(dt_aligned_pixel_t Lab0, dt_aligned_pixel_t Lab1);
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
