@@ -27,16 +27,16 @@
 void draw_no_image(cairo_t *cr, GtkWidget *widget);
 void draw_line(cairo_t *cr, point_t start, point_t end);
 void draw_cross(cairo_t *cr, point_t center);
-void draw_box(cairo_t *cr, box_t box, const double *homography);
+void draw_box(cairo_t *cr, box_t box, const float *homography);
 
 void clear_background(cairo_t *cr);
 void center_image(cairo_t *cr, image_t *image);
 void draw_image(cairo_t *cr, image_t *image);
 void draw_boundingbox(cairo_t *cr, point_t *bb);
-void draw_f_boxes(cairo_t *cr, const double *homography, chart_t *chart);
-void draw_d_boxes(cairo_t *cr, const double *homography, chart_t *chart);
-void draw_color_boxes_outline(cairo_t *cr, const double *homography, chart_t *chart);
-void draw_color_boxes_inside(cairo_t *cr, const double *homography, chart_t *chart, float shrink, float line_width,
+void draw_f_boxes(cairo_t *cr, const float *homography, chart_t *chart);
+void draw_d_boxes(cairo_t *cr, const float *homography, chart_t *chart);
+void draw_color_boxes_outline(cairo_t *cr, const float *homography, chart_t *chart);
+void draw_color_boxes_inside(cairo_t *cr, const float *homography, chart_t *chart, float shrink, float line_width,
                                gboolean colored);
 void stroke_boxes(cairo_t *cr, float line_width);
 
