@@ -27,6 +27,9 @@
   #define TYPE_XYZA_FLT         (FLOAT_SH(1)|COLORSPACE_SH(PT_XYZ)|EXTRA_SH(1)|CHANNELS_SH(3)|BYTES_SH(4))
 #endif
 
+// max iccprofile file name length
+#define DT_IOP_COLOR_ICC_LEN 512
+
 // constants fit to the ones from lcms.h:
 typedef enum dt_iop_color_intent_t
 {
@@ -101,6 +104,42 @@ typedef enum dt_colorspaces_profile_direction_t
                              | DT_PROFILE_DIRECTION_DISPLAY2
 } dt_colorspaces_profile_direction_t;
 
+/* CICP color primaries (Recommendation ITU-T H.273) */
+typedef enum dt_colorspaces_cicp_color_primaries_t
+{
+    DT_CICP_COLOR_PRIMARIES_REC709 = 1,
+    DT_CICP_COLOR_PRIMARIES_UNSPECIFIED = 2,
+    DT_CICP_COLOR_PRIMARIES_REC2020 = 9,
+    DT_CICP_COLOR_PRIMARIES_XYZ = 10,
+    DT_CICP_COLOR_PRIMARIES_P3 = 12 // D65
+} dt_colorspaces_cicp_color_primaries_t;
+
+/* CICP transfer characteristics (Recommendation ITU-T H.273) */
+typedef enum dt_colorspaces_cicp_transfer_characteristics_t
+{
+    DT_CICP_TRANSFER_CHARACTERISTICS_REC709 = 1,
+    DT_CICP_TRANSFER_CHARACTERISTICS_UNSPECIFIED = 2,
+    DT_CICP_TRANSFER_CHARACTERISTICS_REC601 = 6,
+    DT_CICP_TRANSFER_CHARACTERISTICS_LINEAR = 8,
+    DT_CICP_TRANSFER_CHARACTERISTICS_SRGB = 13,
+    DT_CICP_TRANSFER_CHARACTERISTICS_REC2020_10B = 14,
+    DT_CICP_TRANSFER_CHARACTERISTICS_REC2020_12B = 15,
+    DT_CICP_TRANSFER_CHARACTERISTICS_PQ = 16,
+    DT_CICP_TRANSFER_CHARACTERISTICS_HLG = 18
+} dt_colorspaces_cicp_transfer_characteristics_t;
+
+/* CICP matrix coefficients (Recommendation ITU-T H.273) */
+typedef enum dt_colorspaces_cicp_matrix_coefficients_t
+{
+    DT_CICP_MATRIX_COEFFICIENTS_IDENTITY = 0,
+    DT_CICP_MATRIX_COEFFICIENTS_REC709 = 1,
+    DT_CICP_MATRIX_COEFFICIENTS_UNSPECIFIED = 2,
+    DT_CICP_MATRIX_COEFFICIENTS_SYCC = 5,
+    DT_CICP_MATRIX_COEFFICIENTS_REC601 = 6,
+    DT_CICP_MATRIX_COEFFICIENTS_REC2020_NCL = 9,
+    DT_CICP_MATRIX_COEFFICIENTS_CHROMA_DERIVED_NCL = 12
+} dt_colorspaces_cicp_matrix_coefficients_t;
+
 typedef struct dt_colorspaces_t
 {
   GList *profiles;
@@ -138,8 +177,7 @@ typedef struct dt_colorspaces_t
 typedef struct dt_colorspaces_color_profile_t
 {
   dt_colorspaces_color_profile_type_t type; // filename is only used for type DT_COLORSPACE_FILE
-  // must be in synch with DT_IOPPR_COLOR_ICC_LEN in iop_order.h
-  char filename[512];                       // icc file name
+  char filename[DT_IOP_COLOR_ICC_LEN];      // icc file name
   char name[512];                           // product name, displayed in GUI
   cmsHPROFILE profile;                      // the actual profile
   int in_pos;                               // position in input combo box, -1 if not applicable
@@ -150,12 +188,20 @@ typedef struct dt_colorspaces_color_profile_t
   int work_pos;                             // position in working combo box, -1 if not applicable
 } dt_colorspaces_color_profile_t;
 
+typedef struct dt_colorspaces_cicp_t
+{
+    dt_colorspaces_cicp_color_primaries_t color_primaries;
+    dt_colorspaces_cicp_transfer_characteristics_t transfer_characteristics;
+    dt_colorspaces_cicp_matrix_coefficients_t matrix_coefficients;
+} dt_colorspaces_cicp_t;
+
 int mat3inv_float(float *const dst, const float *const src);
 int mat3inv_double(double *const dst, const double *const src);
 int mat3inv(float *const dst, const float *const src);
 
 /** populate the global color profile lists */
 dt_colorspaces_t *dt_colorspaces_init();
+
 /** cleanup on shutdown */
 void dt_colorspaces_cleanup(dt_colorspaces_t *self);
 
@@ -191,11 +237,11 @@ void dt_colorspaces_cleanup_profile(cmsHPROFILE p);
 
 /** extracts tonecurves and color matrix prof to XYZ from a given input profile, returns 0 on success (curves
  * and matrix are inverted for input) */
-int dt_colorspaces_get_matrix_from_input_profile(cmsHPROFILE prof, float *matrix, float *lutr, float *lutg,
+int dt_colorspaces_get_matrix_from_input_profile(cmsHPROFILE prof, dt_colormatrix_t matrix, float *lutr, float *lutg,
                                                  float *lutb, const int lutsize);
 
 /** extracts tonecurves and color matrix prof to XYZ from a given output profile, returns 0 on success. */
-int dt_colorspaces_get_matrix_from_output_profile(cmsHPROFILE prof, float *matrix, float *lutr, float *lutg,
+int dt_colorspaces_get_matrix_from_output_profile(cmsHPROFILE prof, dt_colormatrix_t matrix, float *lutr, float *lutg,
                                                   float *lutb, const int lutsize);
 
 /** wrapper to get the name from a color profile. this tries to handle character encodings. */
@@ -206,11 +252,12 @@ void dt_colorspaces_get_profile_name(cmsHPROFILE p, const char *language, const
 const char *dt_colorspaces_get_name(dt_colorspaces_color_profile_type_t type, const char *filename);
 
 /** common functions to change between colorspaces, used in iop modules */
-void rgb2hsl(const float rgb[3], float *h, float *s, float *l);
-void hsl2rgb(float rgb[3], float h, float s, float l);
+void rgb2hsl(const dt_aligned_pixel_t rgb, float *h, float *s, float *l);
+void hsl2rgb(dt_aligned_pixel_t rgb, float h, float s, float l);
 
 /** trigger updating the display profile from the system settings (x atom, colord, ...) */
 void dt_colorspaces_set_display_profile(const dt_colorspaces_color_profile_type_t profile_type);
+
 /** get the profile described by type & filename.
  *  this doesn't support image specifics like embedded profiles or camera matrices */
 const dt_colorspaces_color_profile_t *
@@ -222,6 +269,9 @@ dt_colorspaces_get_profile(dt_colorspaces_color_profile_type_t type, const char
  *  or just a base name */
 gboolean  dt_colorspaces_is_profile_equal(const char *fullname, const char *filename);
 
+/** try to infer profile type from CICP */
+dt_colorspaces_color_profile_type_t dt_colorspaces_cicp_to_type(const dt_colorspaces_cicp_t *cicp, const char *filename);
+
 /** update the display transforms of srgb and adobergb to the display profile.
  * make sure that darktable.color_profiles->xprofile_lock is held when calling this! */
 void dt_colorspaces_update_display_transforms();
@@ -235,7 +285,7 @@ int dt_colorspaces_conversion_matrices_xyz(const char *name, float in_XYZ_to_CAM
 int dt_colorspaces_conversion_matrices_rgb(const char *name, double RGB_to_CAM[4][3], double CAM_to_RGB[3][4], const float *embedded_matrix, double mul[4]);
 
 /** Applies CYGM WB coeffs to an image that's already been converted to RGB by dt_colorspaces_cygm_to_rgb */
-void dt_colorspaces_cygm_apply_coeffs_to_rgb(float *out, const float *in, int num, double RGB_to_CAM[4][3], double CAM_to_RGB[3][4], float coeffs[4]);
+void dt_colorspaces_cygm_apply_coeffs_to_rgb(float *out, const float *in, int num, double RGB_to_CAM[4][3], double CAM_to_RGB[3][4], dt_aligned_pixel_t coeffs);
 
 /** convert CYGM buffer to RGB */
 void dt_colorspaces_cygm_to_rgb(float *out, int num, double CAM_to_RGB[3][4]);
