@@ -20,6 +20,7 @@
 
 #include <stdint.h>
 #include <stdlib.h>
+#include "common/darktable.h"
 
 typedef void((*eaw_decompose_t)(float *const restrict out, const float *const restrict in, float *const restrict detail,
                                 const int scale, const float sharpen, const int32_t width, const int32_t height));
@@ -41,12 +42,12 @@ void eaw_synthesize_sse2(float *const restrict out, const float *const restrict
                          const int32_t width, const int32_t height);
 
 typedef void((*eaw_dn_decompose_t)(float *const restrict out, const float *const restrict in, float *const restrict detail,
-                                   float sum_squared[4], const int scale, const float inv_sigma2,
+                                   dt_aligned_pixel_t sum_squared, const int scale, const float inv_sigma2,
                                    const int32_t width, const int32_t height));
 
 void eaw_dn_decompose(float *const restrict out, const float *const restrict in, float *const restrict detail,
-                      float sum_squared[4], const int scale, const float inv_sigma2,
+                      dt_aligned_pixel_t sum_squared, const int scale, const float inv_sigma2,
                       const int32_t width, const int32_t height);
 void eaw_dn_decompose_sse(float *const restrict out, const float *const restrict in, float *const restrict detail,
-                          float sum_squared[4], const int scale, const float inv_sigma2,
+                          dt_aligned_pixel_t sum_squared, const int scale, const float inv_sigma2,
                           const int32_t width, const int32_t height);
