@@ -63,7 +63,8 @@ int dt_film_new(dt_film_t *film, const char *directory);
 void dt_film_remove_empty();
 /** gets all image ids in film. the returned GList has to be freed with g_list_free(). */
 GList *dt_film_get_image_ids(const int filmid);
-
+// initialize film folder status
+void dt_film_set_folder_status();
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
 // kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
