@@ -234,18 +234,21 @@ static void dt_focus_draw_clusters(cairo_t *cr, int width, int height, int imgid
   dt_image_cache_read_release(darktable.image_cache, img);
 
   // FIXME: get those from rawprepare IOP somehow !!!
-  int wd = buffer_width + image.crop_x, ht = buffer_height + image.crop_y;
+  int wd = buffer_width + image.crop_x;
+  int ht = buffer_height + image.crop_y;
 
   // array with cluster positions
   float *pos = malloc(fs * 6 * sizeof(float));
   float *offx = pos + fs * 2, *offy = pos + fs * 4;
+
   for(int k = 0; k < fs; k++)
   {
     const float stddevx = sqrtf(focus[k].x2 - focus[k].x * focus[k].x);
     const float stddevy = sqrtf(focus[k].y2 - focus[k].y * focus[k].y);
 
     // FIXME: get those from rawprepare IOP somehow !!!
-    float x = focus[k].x + image.crop_x, y = focus[k].y + image.crop_y;
+    const float x = focus[k].x + image.crop_x;
+    const float y = focus[k].y + image.crop_y;
 
     pos[2 * k + 0] = x;
     pos[2 * k + 1] = y;
@@ -261,7 +264,7 @@ static void dt_focus_draw_clusters(cairo_t *cr, int width, int height, int imgid
     dt_dev_init(&dev, 0);
     dt_dev_load_image(&dev, imgid);
     dt_dev_pixelpipe_t pipe;
-    int res = dt_dev_pixelpipe_init_dummy(&pipe, wd, ht);
+    const int res = dt_dev_pixelpipe_init_dummy(&pipe, wd, ht);
     if(res)
     {
       // set mem pointer to 0, won't be used.
@@ -279,7 +282,8 @@ static void dt_focus_draw_clusters(cairo_t *cr, int width, int height, int imgid
   }
 
   const int32_t tb = darktable.develop->border_size;
-  const float scale = fminf((width - 2 * tb) / (float)wd, (height - 2 * tb) / (float)ht) * full_zoom;
+  const float prev_scale = darktable.develop->preview_downsampling;
+  const float scale = fminf((width - 2 * tb) / (float)wd, (height - 2 * tb) / (float)ht) * full_zoom / prev_scale;
   cairo_scale(cr, scale, scale);
   float fx = 0.0f;
   float fy = 0.0f;
@@ -294,13 +298,13 @@ static void dt_focus_draw_clusters(cairo_t *cr, int width, int height, int imgid
     if(ht * scale <= height) fy = 0;
   }
 
-  cairo_translate(cr, -wd / 2.0f + fx / scale, -ht / 2.0f + fy / scale);
+  cairo_translate(cr, -wd / 2.0f * prev_scale + fx / scale * darktable.gui->ppd_thb, -ht / 2.0f * prev_scale + fy / scale * darktable.gui->ppd_thb);
 
   cairo_rectangle(cr, 0, 0, wd, ht);
   cairo_clip(cr);
 
   double dashes[] = { 3 };
-  int ndash = sizeof(dashes) / sizeof(dashes[0]);
+  const int ndash = sizeof(dashes) / sizeof(dashes[0]);
   double offset = 0.0f;
   cairo_set_dash(cr, dashes, ndash, offset);
 
