@@ -19,18 +19,19 @@
 #pragma once
 
 #include <glib.h>
+#include <stdint.h>
 
 /** add an image to a group */
-void dt_grouping_add_to_group(int group_id, int image_id);
+void dt_grouping_add_to_group(int group_id, int32_t image_id);
 
 /** remove an image from a group. returns the new group_id of the other images. */
-int dt_grouping_remove_from_group(int image_id);
+int dt_grouping_remove_from_group(int32_t image_id);
 
 /** make an image the representative of the group it is in. returns the new group_id. */
-int dt_grouping_change_representative(int image_id);
+int dt_grouping_change_representative(int32_t image_id);
 
 /** get images of the group */
-GList *dt_grouping_get_group_images(const int imgid);
+GList *dt_grouping_get_group_images(const int32_t imgid);
 
 /** add grouped images to images list */
 void dt_grouping_add_grouped_images(GList **images);
