@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2017-2020 darktable developers.
+    Copyright (C) 2017-2021 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -80,29 +80,6 @@ static inline int max_i(int a, int b)
   return a > b ? a : b;
 }
 
-// Kahan summation algorithm
-#ifdef _OPENMP
-#pragma omp declare simd
-#endif
-static inline float Kahan_sum(const float m, float *c, const float add)
-{
-   const float t1 = add - (*c);
-   const float t2 = m + t1;
-   *c = (t2 - m) - t1;
-   return t2;
-}
-
-#ifdef __SSE2__
-// vectorized Kahan summation algorithm
-static inline __m128 Kahan_sum_sse(const __m128 m, __m128 *c, const __m128 add)
-{
-   const __m128 t1 = add - (*c);
-   const __m128 t2 = m + t1;
-   *c = (t2 - m) - t1;
-   return t2;
-}
-#endif /* __SSE2__ */
-
 void guided_filter(const float *guide, const float *in, float *out, int width, int height, int ch, int w,
                    float sqrt_eps, float guide_weight, float min, float max);
 
