@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2010-2020 darktable developers.
+    Copyright (C) 2010-2022 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -112,6 +112,7 @@ typedef struct dt_history_item_t
   guint num;
   gchar *op;
   gchar *name;
+  gboolean enabled;
 } dt_history_item_t;
 
 /** get list of history items for image */
@@ -120,6 +121,9 @@ GList *dt_history_get_items(int32_t imgid, gboolean enabled);
 /** get list of history items for image as a nice string */
 char *dt_history_get_items_as_string(int32_t imgid);
 
+/** get a single history item as string with enabled status */
+char *dt_history_item_as_string(const char *name, gboolean enabled);
+
 /* check if a module exists in the history of corresponding image */
 gboolean dt_history_check_module_exists(int32_t imgid, const char *operation);
 
