@@ -169,7 +169,7 @@ int dt_imageio_large_thumbnail(const char *filename, uint8_t **buffer, int32_t *
 
     image = NewMagickWand();
 	mret = MagickReadImageBlob(image, buf, bufsize);
-    if (mret != MagickTrue)
+    if(mret != MagickTrue)
     {
       fprintf(stderr, "[dt_imageio_large_thumbnail IM] thumbnail not found?\n");
       goto error_im;
@@ -189,10 +189,10 @@ int dt_imageio_large_thumbnail(const char *filename, uint8_t **buffer, int32_t *
     }
 
     *buffer = malloc(sizeof(uint8_t) * (*width) * (*height) * 4);
-    if (*buffer == NULL) goto error_im;
+    if(*buffer == NULL) goto error_im;
 
     mret = MagickExportImagePixels(image, 0, 0, *width, *height, "RGBP", CharPixel, *buffer);
-    if (mret != MagickTrue) {
+    if(mret != MagickTrue) {
       free(*buffer);
       *buffer = NULL;
       fprintf(stderr,
@@ -204,7 +204,7 @@ int dt_imageio_large_thumbnail(const char *filename, uint8_t **buffer, int32_t *
 
 error_im:
     DestroyMagickWand(image);
-    if (res != 0) goto error;
+    if(res != 0) goto error;
 #else
     fprintf(stderr,
       "[dt_imageio_large_thumbnail] error: The thumbnail image is not in "
@@ -661,16 +661,21 @@ int dt_imageio_export(const int32_t imgid, const char *filename, dt_imageio_modu
     return format->write_image(format_params, filename, NULL, icc_type, icc_filename, NULL, 0, imgid, num, total, NULL,
                                export_masks);
   else
-    return dt_imageio_export_with_flags(imgid, filename, format, format_params, FALSE, FALSE, high_quality, upscale,
+  {
+    const gboolean is_scaling =
+      dt_conf_is_equal("plugins/lighttable/export/resizing", "scaling");
+
+    return dt_imageio_export_with_flags(imgid, filename, format, format_params, FALSE, FALSE, high_quality, upscale, is_scaling,
                                         FALSE, NULL, copy_metadata, export_masks, icc_type, icc_filename, icc_intent,
                                         storage, storage_params, num, total, metadata);
+  }
 }
 
 // internal function: to avoid exif blob reading + 8-bit byteorder flag + high-quality override
 int dt_imageio_export_with_flags(const int32_t imgid, const char *filename,
                                  dt_imageio_module_format_t *format, dt_imageio_module_data_t *format_params,
                                  const gboolean ignore_exif, const gboolean display_byteorder,
-                                 const gboolean high_quality, const gboolean upscale, const gboolean thumbnail_export,
+                                 const gboolean high_quality, const gboolean upscale, gboolean is_scaling, const gboolean thumbnail_export,
                                  const char *filter, const gboolean copy_metadata, const gboolean export_masks,
                                  dt_colorspaces_color_profile_type_t icc_type, const gchar *icc_filename,
                                  dt_iop_color_intent_t icc_intent, dt_imageio_module_storage_t *storage,
@@ -807,10 +812,12 @@ int dt_imageio_export_with_flags(const int32_t imgid, const char *filename,
     sRGB = 0;
   }
 
+  // if is_scaling is used don't override high_quality
   // get only once at the beginning, in case the user changes it on the way:
   const gboolean high_quality_processing
       = ((format_params->max_width == 0 || format_params->max_width >= pipe.processed_width)
-         && (format_params->max_height == 0 || format_params->max_height >= pipe.processed_height))
+         && (format_params->max_height == 0 || format_params->max_height >= pipe.processed_height)
+         && !is_scaling)
             ? FALSE
             : high_quality;
 
@@ -834,15 +841,15 @@ int dt_imageio_export_with_flags(const int32_t imgid, const char *filename,
   */
 
   const gboolean iscropped =
-    ((pipe.processed_width < (wd - img->crop_x - img->crop_width)) ||
-     (pipe.processed_height < (ht - img->crop_y - img->crop_height)));
+    (   (pipe.processed_width < (wd - img->crop_x - img->crop_width))
+     || (pipe.processed_height < (ht - img->crop_y - img->crop_height)));
 
-  const gboolean exact_size = (
-      iscropped ||
-      upscale ||
-      (format_params->max_width != 0) ||
-      (format_params->max_height != 0) ||
-      thumbnail_export);
+  const gboolean exact_size =
+         iscropped
+      || upscale
+      || (format_params->max_width != 0)
+      || (format_params->max_height != 0)
+      || thumbnail_export;
 
   int width = format_params->max_width > 0 ? format_params->max_width : 0;
   int height = format_params->max_height > 0 ? format_params->max_height : 0;
@@ -853,7 +860,7 @@ int dt_imageio_export_with_flags(const int32_t imgid, const char *filename,
     height = pipe.processed_height;
   }
 
-  const double max_scale = ( upscale && ( width > 0 || height > 0 )) ? 100.0 : 1.0;
+  const double max_scale = (upscale && (width > 0 || height > 0)) ? 100.0 : 1.0;
 
   const double scalex = width > 0 ? fmin((double)width / (double)pipe.processed_width, max_scale) : max_scale;
   const double scaley = height > 0 ? fmin((double)height / (double)pipe.processed_height, max_scale) : max_scale;
@@ -876,19 +883,15 @@ int dt_imageio_export_with_flags(const int32_t imgid, const char *filename,
     scale = fmin(width >  0 ? fmin((double)width / (double)pipe.processed_width, max_scale) : max_scale,
                  height > 0 ? fmin((double)height / (double)pipe.processed_height, max_scale) : max_scale);
 
-    const gboolean is_scaling =
-      dt_conf_is_equal("plugins/lighttable/export/resizing", "scaling");
-
-    if (is_scaling)
+    if(is_scaling)
     {
       // scaling
-      double scale_factor = 1;
       double _num, _denum;
       dt_imageio_resizing_factor_get_and_parsing(&_num, &_denum);
 
-      scale_factor = _num / _denum;
+      const double scale_factor = _num / _denum;
 
-      if (!thumbnail_export)
+      if(!thumbnail_export)
       {
         scale = fmin(scale_factor, max_scale);
       }
@@ -919,16 +922,16 @@ int dt_imageio_export_with_flags(const int32_t imgid, const char *filename,
       }
     }
 
-    dt_print(DT_DEBUG_IMAGEIO,"[dt_imageio_export] imgid %d, pipe %ix%i, range %ix%i --> exact %i, upscale %i, corrected %i, scale %.7f, corr %.6f, size %ix%i\n",
+    dt_print(DT_DEBUG_IMAGEIO,"[dt_imageio_export] imgid %d, pipe %ix%i, range %ix%i --> exact %i, upscale %i, hq %i, corrected %i, scale %.7f, corr %.6f, size %ix%i\n",
              imgid, pipe.processed_width, pipe.processed_height, format_params->max_width, format_params->max_height,
-             exact_size, upscale, corrected, scale, corrscale, processed_width, processed_height);
+             exact_size, upscale, high_quality_processing, corrected, scale, corrscale, processed_width, processed_height);
   }
   else
   {
     processed_width = floor(scale * pipe.processed_width);
     processed_height = floor(scale * pipe.processed_height);
-    dt_print(DT_DEBUG_IMAGEIO,"[dt_imageio_export] (direct) imgid %d, pipe %ix%i, range %ix%i --> size %ix%i / %ix%i\n",
-             imgid, pipe.processed_width, pipe.processed_height, format_params->max_width, format_params->max_height,
+    dt_print(DT_DEBUG_IMAGEIO,"[dt_imageio_export] (direct) imgid %d, hq %i, pipe %ix%i, range %ix%i --> size %ix%i / %ix%i\n",
+             imgid, high_quality_processing, pipe.processed_width, pipe.processed_height, format_params->max_width, format_params->max_height,
              processed_width, processed_height, width, height);
   }
 
@@ -977,6 +980,11 @@ int dt_imageio_export_with_flags(const int32_t imgid, const char *filename,
                                          : "[dev_process_export] pixel pipeline processing");
 
   uint8_t *outbuf = pipe.backbuf;
+  if(outbuf == NULL)
+  {
+    dt_print(DT_DEBUG_IMAGEIO, "[dt_imageio_export_with_flags] no valid output buffer\n");
+    goto error;
+  }
 
   // downconversion to low-precision formats:
   if(bpp == 8)
@@ -1104,7 +1112,7 @@ int dt_imageio_export_with_flags(const int32_t imgid, const char *filename,
 
     luaA_push_type(L, format->parameter_lua_type, format_params);
 
-    if (storage)
+    if(storage)
       luaA_push_type(L, storage->parameter_lua_type, storage_params);
     else
       lua_pushnil(L);
