@@ -77,7 +77,7 @@ static inline void dt_imageio_dng_write_tiff_header(
     float f, float iso, uint32_t filter,
     const uint8_t xtrans[6][6],
     const float whitelevel,
-    const float wb_coeffs[3],
+    const dt_aligned_pixel_t wb_coeffs,
     const char camera_makermodel[128])
 {
   const uint32_t channels = 1;
@@ -85,7 +85,7 @@ static inline void dt_imageio_dng_write_tiff_header(
   // uint32_t exif_offs;
   uint8_t buf[1024];
   uint8_t cnt = 0;
-  float coeff[3];
+  dt_aligned_pixel_t coeff;
   float XYZ_CAM[12];
   // this matrix is generic for XYZ->sRGB / D65
   int m[9] = { 3240454, -1537138, -498531, -969266, 1876010, 41556, 55643, -204025, 1057225 };
@@ -206,13 +206,13 @@ static inline void dt_imageio_write_dng(
     const int ht, void *exif, const int exif_len, const uint32_t filter,
     const uint8_t xtrans[6][6],
     const float whitelevel,
-    const float wb_coeffs[3],
-    const char camera_model[24])
+    const dt_aligned_pixel_t wb_coeffs,
+    const char camera_makermodel[128])
 {
   FILE *f = g_fopen(filename, "wb");
   if(f)
   {
-    dt_imageio_dng_write_tiff_header(f, wd, ht, 1.0f / 100.0f, 1.0f / 4.0f, 50.0f, 100.0f, filter, xtrans, whitelevel, wb_coeffs, camera_model);
+    dt_imageio_dng_write_tiff_header(f, wd, ht, 1.0f / 100.0f, 1.0f / 4.0f, 50.0f, 100.0f, filter, xtrans, whitelevel, wb_coeffs, camera_makermodel);
     const int k = fwrite(pixel, sizeof(float), (size_t)wd * ht, f);
     if(k != wd * ht) fprintf(stderr, "[dng_write] Error writing image data to %s\n", filename);
     fclose(f);
