@@ -166,7 +166,7 @@ dt_colorspaces_color_profile_type_t dt_mipmap_cache_get_colorspace();
 void dt_mipmap_cache_copy_thumbnails(const dt_mipmap_cache_t *cache, const uint32_t dst_imgid, const uint32_t src_imgid);
 
 // return the mipmap corresponding to text value saved in prefs
-dt_mipmap_size_t dt_mipmap_cache_get_min_mip_from_pref(char *value);
+dt_mipmap_size_t dt_mipmap_cache_get_min_mip_from_pref(const char *value);
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
 // kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
