@@ -98,8 +98,9 @@ void dt_style_item_free(gpointer data)
 static gboolean _apply_style_shortcut_callback(GtkAccelGroup *accel_group, GObject *acceleratable,
                                                guint keyval, GdkModifierType modifier, gpointer data)
 {
-  const GList *imgs = dt_view_get_images_to_act_on(TRUE, TRUE, FALSE);
+  GList *imgs = dt_act_on_get_images(TRUE, TRUE, FALSE);
   dt_styles_apply_to_list(data, imgs, FALSE);
+  g_list_free(imgs);
   return TRUE;
 }
 
@@ -1110,14 +1111,12 @@ GList *dt_styles_get_item_list(const char *name, gboolean params, int imgid)
 
         if(multi_name && *multi_name && strcmp(multi_name, "0") != 0) has_multi_name = TRUE;
 
+        const gchar *itname = dt_iop_get_localized_name((char *)sqlite3_column_text(stmt, 3));
+
         if(has_multi_name)
-          g_snprintf(iname, sizeof(iname), "%s %s (%s)",
-                     dt_iop_get_localized_name((gchar *)sqlite3_column_text(stmt, 3)), multi_name,
-                     (sqlite3_column_int(stmt, 4) != 0) ? _("on") : _("off"));
+          g_snprintf(iname, sizeof(iname), "%s %s", itname, multi_name);
         else
-          g_snprintf(iname, sizeof(iname), "%s (%s)",
-                     dt_iop_get_localized_name((gchar *)sqlite3_column_text(stmt, 3)),
-                     (sqlite3_column_int(stmt, 4) != 0) ? _("on") : _("off"));
+          g_snprintf(iname, sizeof(iname), "%s", itname);
 
         item->params = NULL;
         item->blendop_params = NULL;
@@ -1570,8 +1569,10 @@ void dt_init_styles_key_accels()
     for(GList *res_iter = result; res_iter; res_iter = g_list_next(res_iter))
     {
       dt_style_t *style = (dt_style_t *)res_iter->data;
+      gchar* tmp_name = g_strdelimit(g_strdup(style->name), "/", '-');
       char tmp_accel[1024];
-      snprintf(tmp_accel, sizeof(tmp_accel), C_("accel", "styles/apply %s"), style->name);
+      snprintf(tmp_accel, sizeof(tmp_accel), C_("accel", "styles/apply %s"), tmp_name);
+      g_free(tmp_name);
       dt_accel_register_global(tmp_accel, 0, 0);
     }
     g_list_free_full(result, dt_style_free);
@@ -1589,8 +1590,10 @@ void dt_connect_styles_key_accels()
       dt_style_t *style = (dt_style_t *)res_iter->data;
       closure = g_cclosure_new(G_CALLBACK(_apply_style_shortcut_callback), g_strdup(style->name),
                                _destroy_style_shortcut_callback);
+      gchar* tmp_name = g_strdelimit(g_strdup(style->name), "/", '-');
       char tmp_accel[1024];
-      snprintf(tmp_accel, sizeof(tmp_accel), C_("accel", "styles/apply %s"), style->name);
+      snprintf(tmp_accel, sizeof(tmp_accel), C_("accel", "styles/apply %s"), tmp_name);
+      g_free(tmp_name);
       dt_accel_connect_global(tmp_accel, closure);
     }
     g_list_free_full(result, dt_style_free);
