@@ -20,6 +20,7 @@
 
 #include <gtk/gtk.h>
 #include <string.h>
+#include <librsvg/rsvg.h>
 
 /** dynamically allocate and concatenate string */
 gchar *dt_util_dstrcat(gchar *str, const gchar *format, ...) __attribute__((format(printf, 2, 3)));
@@ -76,6 +77,14 @@ gboolean dt_util_gps_elevation_to_number(const double r_1, const double r_2, cha
 // make paths absolute and try to normalize on Windows. also deal with character encoding on Windows.
 gchar *dt_util_normalize_path(const gchar *input);
 
+#ifdef WIN32
+// returns TRUE if the path is a Windows UNC (\\server\share\...\file)
+const gboolean dt_util_path_is_UNC(const gchar *filename);
+#endif
+
+// gets the directory components of a file name, like g_path_get_dirname(), but works also with Windows networks paths (\\hostname\share\file)
+gchar *dt_util_path_get_dirname(const gchar *filename);
+
 // format exposure time string
 gchar *dt_util_format_exposure(const float exposuretime);
 
@@ -89,6 +98,21 @@ void dt_copy_file(const char *src, const char *dst);
 // copy the contents of a file in dt's data directory to a new file
 void dt_copy_resource_file(const char *src, const char *dst);
 
+// returns the RsvgDimensionData of a supplied RsvgHandle
+RsvgDimensionData dt_get_svg_dimension(RsvgHandle *svg);
+
+// renders svg data
+void dt_render_svg(RsvgHandle *svg, cairo_t *cr, double width, double height, double offset_x, double offset_y);
+
+// check if the path + basenames are the same (<=> only differ by the extension)
+gboolean dt_has_same_path_basename(const char *filename1, const char *filename2);
+
+// set the filename2 extension to filename1 - return NULL if fails - result should be freed
+char *dt_copy_filename_extension(const char *filename1, const char *filename2);
+
+// replaces all occurences of a substring in a string
+gchar *dt_str_replace(const char *string, const char *search, const char *replace);
+
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
 // kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
