@@ -52,6 +52,8 @@ void dt_variables_params_init(dt_variables_params_t **params);
 void dt_variables_params_destroy(dt_variables_params_t *params);
 /** set max image width and height defined for an export session in a dt_variables_params_t. */
 void dt_variables_set_max_width_height(dt_variables_params_t *params, int max_width, int max_height);
+/** set upscale allowed flag for an export session in a dt_variables_params_t. */
+void dt_variables_set_upscale(dt_variables_params_t *params, gboolean upscale);
 /** set the time in a dt_variables_params_t. */
 void dt_variables_set_time(dt_variables_params_t *params, time_t time);
 /** set the time to use for EXIF variables */
