@@ -25,6 +25,7 @@
 #include "common/dtpthread.h"
 
 #include <glib.h>
+#include <gtk/gtk.h>
 #include <inttypes.h>
 
 typedef enum dt_confgen_type_t
@@ -33,6 +34,7 @@ typedef enum dt_confgen_type_t
   DT_INT64,
   DT_FLOAT,
   DT_BOOL,
+  DT_PATH,
   DT_STRING,
   DT_ENUM
 } dt_confgen_type_t;
@@ -76,6 +78,7 @@ void dt_conf_set_int64(const char *name, int64_t val);
 void dt_conf_set_float(const char *name, float val);
 void dt_conf_set_bool(const char *name, int val);
 void dt_conf_set_string(const char *name, const char *val);
+void dt_conf_set_folder_from_file_chooser(const char *name, GtkFileChooser *chooser);
 int dt_conf_get_int_fast(const char *name);
 int dt_conf_get_int(const char *name);
 int64_t dt_conf_get_int64_fast(const char *name);
@@ -86,7 +89,12 @@ int dt_conf_get_and_sanitize_int(const char *name, int min, int max);
 int64_t dt_conf_get_and_sanitize_int64(const char *name, int64_t min, int64_t max);
 float dt_conf_get_and_sanitize_float(const char *name, float min, float max);
 int dt_conf_get_bool(const char *name);
+// get the configuration string without duplicating it; the returned string will be invalidated by any
+// subsequent dt_conf_set_string call
+const char *dt_conf_get_string_const(const char *name);
+// get a freshly-allocated duplicate of the configuration string; safe to use even if calling dt_conf_set_string
 gchar *dt_conf_get_string(const char *name);
+gboolean dt_conf_get_folder_to_file_chooser(const char *name, GtkFileChooser *chooser);
 gboolean dt_conf_is_equal(const char *name, const char *value);
 void dt_conf_init(dt_conf_t *cf, const char *filename, GSList *override_entries);
 void dt_conf_cleanup(dt_conf_t *cf);
@@ -115,6 +123,7 @@ const char *dt_confgen_get_label(const char *name);
 const char *dt_confgen_get_tooltip(const char *name);
 
 gboolean dt_conf_is_default(const char *name);
+gchar* dt_conf_expand_default_dir(const char *dir);
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
