@@ -553,14 +553,18 @@ void dt_control_log(const char *msg, ...)
   va_list ap;
   va_start(ap, msg);
   char *escaped_msg = g_markup_vprintf_escaped(msg, ap);
+  const int msglen = strlen(escaped_msg);
   g_strlcpy(darktable.control->log_message[darktable.control->log_pos], escaped_msg, DT_CTL_LOG_MSG_SIZE);
   g_free(escaped_msg);
   va_end(ap);
-  if(darktable.control->log_message_timeout_id) g_source_remove(darktable.control->log_message_timeout_id);
+  if(darktable.control->log_message_timeout_id)
+    g_source_remove(darktable.control->log_message_timeout_id);
   darktable.control->log_ack = darktable.control->log_pos;
   darktable.control->log_pos = (darktable.control->log_pos + 1) % DT_CTL_LOG_SIZE;
+
   darktable.control->log_message_timeout_id
-      = g_timeout_add(DT_CTL_LOG_TIMEOUT, _dt_ctl_log_message_timeout_callback, NULL);
+    = g_timeout_add(DT_CTL_LOG_TIMEOUT + 1000 * (msglen / 40),
+                    _dt_ctl_log_message_timeout_callback, NULL);
   dt_pthread_mutex_unlock(&darktable.control->log_mutex);
   // redraw center later in gui thread:
   g_idle_add(_redraw_center, 0);
