@@ -359,9 +359,8 @@ dt_job_t *dt_camera_import_job_create(GList *images, struct dt_camera_t *camera,
 
   /* initialize import session for camera import job */
   if(time_override != 0) dt_import_session_set_time(params->shared.session, time_override);
-  char *jobcode = dt_conf_get_string("ui_last/import_jobcode");
+  const char *jobcode = dt_conf_get_string_const("ui_last/import_jobcode");
   dt_import_session_set_name(params->shared.session, jobcode);
-  g_free(jobcode);
 
   params->fraction = 0;
   params->images = images;
