@@ -33,7 +33,7 @@ void dt_control_datetime(const long int offset, const char *datetime, GList *img
 void dt_control_write_sidecar_files();
 void dt_control_delete_images();
 void dt_control_delete_image(int imgid);
-void dt_control_duplicate_images();
+void dt_control_duplicate_images(gboolean virgin);
 void dt_control_flip_images(const int32_t cw);
 void dt_control_monochrome_images(const int32_t mode);
 gboolean dt_control_remove_images();
