@@ -24,14 +24,15 @@
 typedef struct dt_film_import1_t
 {
   dt_film_t *film;
+  GList *imagelist;
 } dt_film_import1_t;
 
-static void dt_film_import1(dt_job_t *job, dt_film_t *film);
+static void _film_import1(dt_job_t *job, dt_film_t *film, GList *images);
 
 static int32_t dt_film_import1_run(dt_job_t *job)
 {
   dt_film_import1_t *params = dt_control_job_get_params(job);
-  dt_film_import1(job, params->film);
+  _film_import1(job, params->film, NULL); // import the given film, collecting its images
   dt_pthread_mutex_lock(&params->film->images_mutex);
   params->film->ref--;
   dt_pthread_mutex_unlock(&params->film->images_mutex);
@@ -78,6 +79,72 @@ dt_job_t *dt_film_import1_create(dt_film_t *film)
   return job;
 }
 
+static int32_t _pathlist_import_run(dt_job_t *job)
+{
+  dt_film_import1_t *params = dt_control_job_get_params(job);
+  _film_import1(job, NULL, params->imagelist); // import the specified images, creating filmrolls as needed
+  params->imagelist = NULL;  // the import will have freed the image list
+
+  // notify the user via the window manager
+  dt_ui_notify_user();
+  return 0;
+}
+
+static void _pathlist_import_cleanup(void *p)
+{
+  dt_film_import1_t *params = p;
+  free(params);
+}
+
+dt_job_t *dt_pathlist_import_create(int argc, char *argv[])
+{
+  dt_job_t *job = dt_control_job_create(&_pathlist_import_run, "import commandline images");
+  if(!job) return NULL;
+  dt_film_import1_t *params = (dt_film_import1_t *)calloc(1, sizeof(dt_film_import1_t));
+  if(!params)
+  {
+    dt_control_job_dispose(job);
+    return NULL;
+  }
+  dt_control_job_add_progress(job, _("import images"), FALSE);
+  dt_control_job_set_params(job, params, _pathlist_import_cleanup);
+  params->film = NULL;
+  // now collect all of the images to be imported
+  params->imagelist = NULL;
+  for(int i = 1; i < argc; i++)
+  {
+    char *path = dt_util_normalize_path(argv[i]);
+    if(!g_file_test(path, G_FILE_TEST_IS_DIR))
+    {
+      // add just the given name to the list of images to import
+      params->imagelist = g_list_prepend(params->imagelist, path);
+    }
+    else
+    {
+      // iterate over the directory, extracting image files
+      GDir *cdir = g_dir_open(path, 0, NULL);
+      if (cdir)
+      {
+        while(TRUE)
+        {
+          const gchar *fname = g_dir_read_name(cdir);
+          if(!fname) break;  			// no more files in directory
+          if(fname[0] == '.') continue; 	// skip hidden files
+          gchar *fullname = g_build_filename(path, fname, NULL);
+          if(!g_file_test(fullname, G_FILE_TEST_IS_DIR) && dt_supported_image(fname))
+            params->imagelist = g_list_prepend(params->imagelist, fullname);
+          else
+            g_free(fullname);
+        }
+      }
+      g_dir_close(cdir);
+      g_free(path);
+    }
+  }
+  params->imagelist = g_list_reverse(params->imagelist);
+  return job;
+}
+
 static GList *_film_recursive_get_files(const gchar *path, gboolean recursive, GList **result)
 {
   gchar *fullname;
@@ -153,28 +220,31 @@ static int _film_filename_cmp(gchar *a, gchar *b)
 {
   gchar *a_basename = g_path_get_basename(a);
   gchar *b_basename = g_path_get_basename(b);
-  int ret = g_strcmp0(a_basename, b_basename);
+  const int ret = g_strcmp0(a_basename, b_basename);
   g_free(a_basename);
   g_free(b_basename);
   return ret;
 }
 
-static void dt_film_import1(dt_job_t *job, dt_film_t *film)
+static void _film_import1(dt_job_t *job, dt_film_t *film, GList *images)
 {
-  gboolean recursive = dt_conf_get_bool("ui_last/import_recursive");
-
-  /* first of all gather all images to import */
-  GList *images = NULL;
-  images = _film_recursive_get_files(film->dirname, recursive, &images);
-  if(images == NULL)
+  // first, gather all images to import if not already given
+  if (!images)
   {
-    dt_control_log(_("no supported images were found to be imported"));
-    return;
+    const gboolean recursive = dt_conf_get_bool("ui_last/import_recursive");
+
+    images = _film_recursive_get_files(film->dirname, recursive, &images);
+    if(images == NULL)
+    {
+      dt_control_log(_("no supported images were found to be imported"));
+      return;
+    }
   }
 
 #ifdef USE_LUA
   /* pre-sort image list for easier handling in Lua code */
   images = g_list_sort(images, (GCompareFunc)_film_filename_cmp);
+  int image_count = 1;
 
   dt_lua_lock();
   lua_State *L = darktable.lua_state.state;
@@ -183,7 +253,8 @@ static void dt_film_import1(dt_job_t *job, dt_film_t *film)
     for(GList *elt = images; elt; elt = g_list_next(elt))
     {
       lua_pushstring(L, elt->data);
-      luaL_ref(L, -2);
+      lua_seti(L, -2, image_count);
+      image_count++;
     }
   }
   lua_pushvalue(L, -1);
@@ -192,13 +263,16 @@ static void dt_film_import1(dt_job_t *job, dt_film_t *film)
     g_list_free_full(images, g_free);
     // recreate list of images
     images = NULL;
-    lua_pushnil(L); /* first key */
-    while(lua_next(L, -2) != 0)
+    for(int i = 1; i < image_count; i++)
     {
-      /* uses 'key' (at index -2) and 'value' (at index -1) */
-      void *filename = strdup(luaL_checkstring(L, -1));
+      //get entry I from table at index -1.  Push the result on the stack
+      lua_geti(L, -1, i);
+      if(lua_isstring(L, -1)) //images to ignore are set to nil
+      {
+        void *filename = strdup(luaL_checkstring(L, -1));
+        images = g_list_prepend(images, filename);
+      }
       lua_pop(L, 1);
-      images = g_list_prepend(images, filename);
     }
   }
 
@@ -267,7 +341,7 @@ static void dt_film_import1(dt_job_t *job, dt_film_t *film)
 
     all_imgs = g_list_prepend(all_imgs, GINT_TO_POINTER(imgid));
     imgs = g_list_append(imgs, GINT_TO_POINTER(imgid));
-    double curr_time = dt_get_wtime();
+    const double curr_time = dt_get_wtime();
     // if we've imported at least four images without an update, and it's been at least half a second since the last
     //   one, update the interface
     if(pending >= 4 && curr_time - last_update > 0.5)
@@ -289,8 +363,9 @@ static void dt_film_import1(dt_job_t *job, dt_film_t *film)
   dt_control_queue_redraw_center();
   DT_DEBUG_CONTROL_SIGNAL_RAISE(darktable.signals, DT_SIGNAL_TAG_CHANGED);
 
-  DT_DEBUG_CONTROL_SIGNAL_RAISE(darktable.signals, DT_SIGNAL_FILMROLLS_IMPORTED, film->id);
+  DT_DEBUG_CONTROL_SIGNAL_RAISE(darktable.signals, DT_SIGNAL_FILMROLLS_IMPORTED, film ? film->id : cfr->id);
 
+  //QUESTION: should this come after _apply_filmroll_gpx, since that can change geotags again?
   DT_DEBUG_CONTROL_SIGNAL_RAISE(darktable.signals, DT_SIGNAL_GEOTAG_CHANGED, all_imgs, 0);
 
   _apply_filmroll_gpx(cfr);
