@@ -39,7 +39,7 @@
 
 typedef void(_blend_row_func)(const float *const restrict a, const float *const restrict b,
                               float *const restrict out, const float *const restrict mask, const size_t stride,
-                              const float *const restrict min, const float *const restrict max);
+                              const dt_aligned_pixel_t min, const dt_aligned_pixel_t max);
 
 
 #ifdef _OPENMP
@@ -53,8 +53,7 @@ static inline float _CLAMP(const float x, const float min, const float max)
 #ifdef _OPENMP
 #pragma omp declare simd aligned(XYZ, min, max: 16)
 #endif
-static inline void _CLAMP_XYZ(float *const restrict XYZ, const float *const restrict min,
-                              const float *const restrict max)
+static inline void _CLAMP_XYZ(dt_aligned_pixel_t XYZ, const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for_each_channel(i) XYZ[i] = fminf(fmaxf(XYZ[i], min[i]), max[i]);
 }
@@ -143,7 +142,7 @@ static inline void _blendif_lch(const float *const restrict pixels, float *const
   const float c_scale = 1.0f / (128.0f * sqrtf(2.0f));
   for(size_t x = 0, j = 0; x < stride; x++, j += DT_BLENDIF_LAB_CH)
   {
-    float LCH[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t LCH;
     dt_Lab_2_LCH(pixels + j, LCH);
     float factor = 1.0f;
     factor *= _blendif_compute_factor(LCH[1] * c_scale, invert_mask[0], parameters);
@@ -352,7 +351,7 @@ void dt_develop_blendif_lab_make_mask(struct dt_dev_pixelpipe_iop_t *piece, cons
 #endif
 static inline void _blend_Lab_scale(const float *i, float *o)
 {
-  const float DT_ALIGNED_PIXEL scale[4] = { 1/100.0f, 1/128.0f, 1/128.0f, 1.0f };
+  const dt_aligned_pixel_t scale = { 1/100.0f, 1/128.0f, 1/128.0f, 1.0f };
   for_each_channel(c)
     o[c] = i[c] * scale[c];
 }
@@ -362,7 +361,7 @@ static inline void _blend_Lab_scale(const float *i, float *o)
 #endif
 static inline void _blend_Lab_rescale(const float *i, float *o)
 {
-  const float DT_ALIGNED_PIXEL scale[4] = { 100.0f, 128.0f, 128.0f, 1.0f };
+  const dt_aligned_pixel_t scale = { 100.0f, 128.0f, 128.0f, 1.0f };
   for_each_channel(c)
     o[c] = i[c] * scale[c];
 }
@@ -374,14 +373,13 @@ static inline void _blend_Lab_rescale(const float *i, float *o)
 #endif
 static void _blend_normal_bounded(const float *const restrict a, const float *const restrict b,
                                   float *const restrict out, const float *const restrict mask, const size_t stride,
-                                  const float *const restrict min, const float *const restrict max)
+                                  const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0; i < stride; i++)
   {
     size_t j = i * DT_BLENDIF_LAB_CH;
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -401,14 +399,13 @@ static void _blend_normal_bounded(const float *const restrict a, const float *co
 static void _blend_normal_unbounded(const float *const restrict a, const float *const restrict b,
                                     float *const restrict out,
                                     const float *const restrict mask, const size_t stride,
-                                    const float *const restrict min, const float *const restrict max)
+                                    const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0; i < stride; i++)
   {
     size_t j = i * DT_BLENDIF_LAB_CH;
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -427,13 +424,12 @@ static void _blend_normal_unbounded(const float *const restrict a, const float *
 #endif
 static void _blend_lighten(const float *const restrict a, const float *const restrict b,
                            float *const restrict out, const float *const restrict mask, const size_t stride,
-                           const float *const restrict min, const float *const restrict max)
+                           const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -456,13 +452,12 @@ static void _blend_lighten(const float *const restrict a, const float *const res
 #endif
 static void _blend_darken(const float *const restrict a, const float *const restrict b,
                           float *const restrict out, const float *const restrict mask, const size_t stride,
-                          const float *const restrict min, const float *const restrict max)
+                          const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -485,13 +480,12 @@ static void _blend_darken(const float *const restrict a, const float *const rest
 #endif
 static void _blend_multiply(const float *const restrict a, const float *const restrict b,
                             float *const restrict out, const float *const restrict mask, const size_t stride,
-                            const float *const restrict min, const float *const restrict max)
+                            const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -513,14 +507,13 @@ static void _blend_multiply(const float *const restrict a, const float *const re
 #endif
 static void _blend_average(const float *const restrict a, const float *const restrict b,
                            float *const restrict out, const float *const restrict mask, const size_t stride,
-                           const float *const restrict min, const float *const restrict max)
+                           const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0; i < stride; i++)
   {
     size_t j = i * DT_BLENDIF_LAB_CH;
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -539,14 +532,13 @@ static void _blend_average(const float *const restrict a, const float *const res
 #endif
 static void _blend_add(const float *const restrict a, const float *const restrict b,
                        float *const restrict out, const float *const restrict mask, const size_t stride,
-                       const float *const restrict min, const float *const restrict max)
+                       const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0; i < stride; i++)
   {
     size_t j = i * DT_BLENDIF_LAB_CH;
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -565,14 +557,13 @@ static void _blend_add(const float *const restrict a, const float *const restric
 #endif
 static void _blend_subtract(const float *const restrict a, const float *const restrict b,
                             float *const restrict out, const float *const restrict mask, const size_t stride,
-                            const float *const restrict min, const float *const restrict max)
+                            const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0; i < stride; i++)
   {
     size_t j = i * DT_BLENDIF_LAB_CH;
     float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -592,13 +583,12 @@ static void _blend_subtract(const float *const restrict a, const float *const re
 #endif
 static void _blend_difference(const float *const restrict a, const float *const restrict b,
                               float *const restrict out, const float *const restrict mask, const size_t stride,
-                              const float *const restrict min, const float *const restrict max)
+                              const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -623,13 +613,12 @@ static void _blend_difference(const float *const restrict a, const float *const
 #endif
 static void _blend_difference2(const float *const restrict a, const float *const restrict b,
                                float *const restrict out, const float *const restrict mask, const size_t stride,
-                               const float *const restrict min, const float *const restrict max)
+                               const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -653,13 +642,12 @@ static void _blend_difference2(const float *const restrict a, const float *const
 #endif
 static void _blend_screen(const float *const restrict a, const float *const restrict b,
                           float *const restrict out, const float *const restrict mask, const size_t stride,
-                          const float *const restrict min, const float *const restrict max)
+                          const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -689,14 +677,13 @@ static void _blend_screen(const float *const restrict a, const float *const rest
 #endif
 static void _blend_overlay(const float *const restrict a, const float *const restrict b,
                            float *const restrict out, const float *const restrict mask, const size_t stride,
-                           const float *const restrict min, const float *const restrict max)
+                           const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
     const float local_opacity2 = local_opacity * local_opacity;
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(&a[j], ta);
     _blend_Lab_scale(&b[j], tb);
@@ -729,14 +716,13 @@ static void _blend_overlay(const float *const restrict a, const float *const res
 #endif
 static void _blend_softlight(const float *const restrict a, const float *const restrict b,
                              float *const restrict out, const float *const restrict mask, const size_t stride,
-                             const float *const restrict min, const float *const restrict max)
+                             const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
     const float local_opacity2 = local_opacity * local_opacity;
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -768,14 +754,13 @@ static void _blend_softlight(const float *const restrict a, const float *const r
 #endif
 static void _blend_hardlight(const float *const restrict a, const float *const restrict b,
                              float *const restrict out, const float *const restrict mask, const size_t stride,
-                             const float *const restrict min, const float *const restrict max)
+                             const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
     const float local_opacity2 = local_opacity * local_opacity;
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -808,14 +793,13 @@ static void _blend_hardlight(const float *const restrict a, const float *const r
 #endif
 static void _blend_vividlight(const float *const restrict a, const float *const restrict b,
                               float *const restrict out, const float *const restrict mask, const size_t stride,
-                              const float *const restrict min, const float *const restrict max)
+                              const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
     const float local_opacity2 = local_opacity * local_opacity;
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -848,14 +832,13 @@ static void _blend_vividlight(const float *const restrict a, const float *const
 #endif
 static void _blend_linearlight(const float *const restrict a, const float *const restrict b,
                                float *const restrict out, const float *const restrict mask, const size_t stride,
-                               const float *const restrict min, const float *const restrict max)
+                               const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
     const float local_opacity2 = local_opacity * local_opacity;
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -884,14 +867,13 @@ static void _blend_linearlight(const float *const restrict a, const float *const
 #endif
 static void _blend_pinlight(const float *const restrict a, const float *const restrict b,
                             float *const restrict out, const float *const restrict mask, const size_t stride,
-                            const float *const restrict min, const float *const restrict max)
+                            const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
     const float local_opacity2 = local_opacity * local_opacity;
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -923,13 +905,12 @@ static void _blend_pinlight(const float *const restrict a, const float *const re
 #endif
 static void _blend_lightness(const float *const restrict a, const float *const restrict b,
                              float *const restrict out, const float *const restrict mask, const size_t stride,
-                             const float *const restrict min, const float *const restrict max)
+                             const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -951,15 +932,13 @@ static void _blend_lightness(const float *const restrict a, const float *const r
 #endif
 static void _blend_chromaticity(const float *const restrict a, const float *const restrict b,
                                 float *const restrict out, const float *const restrict mask, const size_t stride,
-                                const float *const restrict min, const float *const restrict max)
+                                const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
-    float tta[4] DT_ALIGNED_PIXEL;
-    float ttb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
+    dt_aligned_pixel_t tta, ttb;
 
     _blend_Lab_scale(a + j, ta);
     _CLAMP_XYZ(ta, min, max);
@@ -986,15 +965,13 @@ static void _blend_chromaticity(const float *const restrict a, const float *cons
 #endif
 static void _blend_hue(const float *const restrict a, const float *const restrict b,
                        float *const restrict out, const float *const restrict mask, const size_t stride,
-                       const float *const restrict min, const float *const restrict max)
+                       const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
-    float tta[4] DT_ALIGNED_PIXEL;
-    float ttb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
+    dt_aligned_pixel_t tta, ttb;
 
     _blend_Lab_scale(a + j, ta);
     _CLAMP_XYZ(ta, min, max);
@@ -1024,15 +1001,13 @@ static void _blend_hue(const float *const restrict a, const float *const restric
 #endif
 static void _blend_color(const float *const restrict a, const float *const restrict b,
                          float *const restrict out, const float *const restrict mask, const size_t stride,
-                         const float *const restrict min, const float *const restrict max)
+                         const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
-    float tta[4] DT_ALIGNED_PIXEL;
-    float ttb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
+    dt_aligned_pixel_t tta, ttb;
 
     _blend_Lab_scale(a + j, ta);
     _CLAMP_XYZ(ta, min, max);
@@ -1063,15 +1038,13 @@ static void _blend_color(const float *const restrict a, const float *const restr
 #endif
 static void _blend_coloradjust(const float *const restrict a, const float *const restrict b,
                                float *const restrict out, const float *const restrict mask, const size_t stride,
-                               const float *const restrict min, const float *const restrict max)
+                               const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
-    float tta[4] DT_ALIGNED_PIXEL;
-    float ttb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
+    dt_aligned_pixel_t tta, ttb;
 
     _blend_Lab_scale(a + j, ta);
     _CLAMP_XYZ(ta, min, max);
@@ -1102,13 +1075,12 @@ static void _blend_coloradjust(const float *const restrict a, const float *const
 #endif
 static void _blend_Lab_lightness(const float *const restrict a, const float *const restrict b,
                                  float *const restrict out, const float *const restrict mask, const size_t stride,
-                                 const float *const restrict min, const float *const restrict max)
+                                 const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -1128,13 +1100,12 @@ static void _blend_Lab_lightness(const float *const restrict a, const float *con
 #endif
 static void _blend_Lab_a(const float *const restrict a, const float *const restrict b,
                          float *const restrict out, const float *const restrict mask, const size_t stride,
-                         const float *const restrict min, const float *const restrict max)
+                         const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -1154,13 +1125,12 @@ static void _blend_Lab_a(const float *const restrict a, const float *const restr
 #endif
 static void _blend_Lab_b(const float *const restrict a, const float *const restrict b,
                          float *const restrict out, const float *const restrict mask, const size_t stride,
-                         const float *const restrict min, const float *const restrict max)
+                         const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     const float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -1181,13 +1151,12 @@ static void _blend_Lab_b(const float *const restrict a, const float *const restr
 #endif
 static void _blend_Lab_color(const float *const restrict a, const float *const restrict b,
                              float *const restrict out, const float *const restrict mask, const size_t stride,
-                             const float *const restrict min, const float *const restrict max)
+                             const dt_aligned_pixel_t min, const dt_aligned_pixel_t max)
 {
   for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
   {
     float local_opacity = mask[i];
-    float ta[4] DT_ALIGNED_PIXEL;
-    float tb[4] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t ta, tb;
 
     _blend_Lab_scale(a + j, ta);
     _blend_Lab_scale(b + j, tb);
@@ -1300,7 +1269,7 @@ static _blend_row_func *_choose_blend_func(const unsigned int blend_mode)
 #ifdef _OPENMP
 #pragma omp declare simd aligned(out:16)
 #endif
-static inline void _display_channel_value(float *const restrict out, const float value, const float mask)
+static inline void _display_channel_value(dt_aligned_pixel_t out, const float value, const float mask)
 {
   out[0] = value;
   out[1] = value;
@@ -1382,7 +1351,7 @@ static void _display_channel(const float *const restrict a, float *const restric
       const float factor = 1.0f / (128.0f * sqrtf(2.0f) * exp2f(boost_factors[DEVELOP_BLENDIF_C_in]));
       for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
       {
-        float LCH[4] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t LCH;
         dt_Lab_2_LCH(a + j, LCH);
         const float c = clamp_simd(LCH[1] * factor);
         _display_channel_value(b + j, c, mask[i]);
@@ -1394,7 +1363,7 @@ static void _display_channel(const float *const restrict a, float *const restric
       const float factor = 1.0f / (128.0f * sqrtf(2.0f) * exp2f(boost_factors[DEVELOP_BLENDIF_C_out]));
       for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
       {
-        float LCH[4] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t LCH;
         dt_Lab_2_LCH(b + j, LCH);
         const float c = clamp_simd(LCH[1] * factor);
         _display_channel_value(b + j, c, mask[i]);
@@ -1405,7 +1374,7 @@ static void _display_channel(const float *const restrict a, float *const restric
       // no boost factor for hues
       for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
       {
-        float LCH[4] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t LCH;
         dt_Lab_2_LCH(a + j, LCH);
         const float c = clamp_simd(LCH[2]);
         _display_channel_value(b + j, c, mask[i]);
@@ -1415,7 +1384,7 @@ static void _display_channel(const float *const restrict a, float *const restric
       // no boost factor for hues
       for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_LAB_CH)
       {
-        float LCH[4] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t LCH;
         dt_Lab_2_LCH(b + j, LCH);
         const float c = clamp_simd(LCH[2]);
         _display_channel_value(b + j, c, mask[i]);
@@ -1443,7 +1412,7 @@ static inline void _copy_mask(const float *const restrict a, float *const restri
 }
 
 void dt_develop_blendif_lab_blend(struct dt_dev_pixelpipe_iop_t *piece,
-                                  const float *const restrict a, float *const restrict b,
+                                  const float *const a, float *const b,
                                   const struct dt_iop_roi_t *const roi_in,
                                   const struct dt_iop_roi_t *const roi_out,
                                   const float *const restrict mask,
@@ -1489,17 +1458,18 @@ void dt_develop_blendif_lab_blend(struct dt_dev_pixelpipe_iop_t *piece,
     if(profile)
     {
 #ifdef _OPENMP
-#pragma omp parallel for simd schedule(static) default(none) aligned(b:64) \
+#pragma omp parallel for schedule(static) default(none) \
   dt_omp_firstprivate(b, buffsize, profile)
 #endif
       for(size_t j = 0; j < buffsize; j += DT_BLENDIF_LAB_CH)
       {
-        float pixel[4] DT_ALIGNED_PIXEL;
-        pixel[0] = b[j + 0];
-        pixel[1] = b[j + 1];
-        pixel[2] = b[j + 2];
-        dt_ioppr_rgb_matrix_to_lab(pixel, b + j, profile->matrix_in, profile->lut_in,
+        dt_aligned_pixel_t pixel;
+        for_each_channel(c,aligned(b))
+          pixel[c] = b[j+c];
+        const float yellow_mask = b[j+3]; // preserve alpha for code which does in-place conversion
+        dt_ioppr_rgb_matrix_to_lab(pixel, b + j, profile->matrix_in_transposed, profile->lut_in,
                                    profile->unbounded_coeffs_in, profile->lutsize, profile->nonlinearlut);
+        b[j+3] = yellow_mask;
       }
     }
     else
@@ -1510,9 +1480,11 @@ void dt_develop_blendif_lab_blend(struct dt_dev_pixelpipe_iop_t *piece,
 #endif
       for(size_t j = 0; j < buffsize; j += DT_BLENDIF_LAB_CH)
       {
-        float XYZ[4] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t XYZ;
+        const float yellow_mask = b[j+3]; // preserve alpha for code which does in-place conversion
         dt_Rec709_to_XYZ_D50(b + j, XYZ);
         dt_XYZ_to_Lab(XYZ, b + j);
+        b[j+3] = yellow_mask;
       }
     }
   }
@@ -1520,13 +1492,13 @@ void dt_develop_blendif_lab_blend(struct dt_dev_pixelpipe_iop_t *piece,
   {
     _blend_row_func *const blend = _choose_blend_func(d->blend_mode);
     // minimum and maximum values after scaling !!!
-    const float min[4] DT_ALIGNED_PIXEL = { 0.0f, -1.0f, -1.0f, 0.0f };
-    const float max[4] DT_ALIGNED_PIXEL = { 1.0f, 1.0f, 1.0f, 1.0f };
+    const dt_aligned_pixel_t min = { 0.0f, -1.0f, -1.0f, 0.0f };
+    const dt_aligned_pixel_t max = { 1.0f, 1.0f, 1.0f, 1.0f };
 
-    float *tmp_buffer = dt_alloc_align_float(owidth * oheight * DT_BLENDIF_LAB_CH);
+    float *tmp_buffer = dt_alloc_align_float((size_t)owidth * oheight * DT_BLENDIF_LAB_CH);
     if (tmp_buffer != NULL)
     {
-      dt_iop_image_copy(tmp_buffer, b, owidth * oheight * DT_BLENDIF_LAB_CH);
+      dt_iop_image_copy(tmp_buffer, b, (size_t)owidth * oheight * DT_BLENDIF_LAB_CH);
       if((d->blend_mode & DEVELOP_BLEND_REVERSE) == DEVELOP_BLEND_REVERSE)
       {
 #ifdef _OPENMP
