@@ -416,10 +416,10 @@ void dt_develop_blendif_raw_blend(struct dt_dev_pixelpipe_iop_t *piece,
   {
     _blend_row_func *const blend = _choose_blend_func(d->blend_mode);
 
-    float *tmp_buffer = dt_alloc_align_float(owidth * oheight);
+    float *tmp_buffer = dt_alloc_align_float((size_t)owidth * oheight);
     if (tmp_buffer != NULL)
     {
-      dt_iop_image_copy(tmp_buffer, b, owidth * oheight);
+      dt_iop_image_copy(tmp_buffer, b, (size_t)owidth * oheight);
       if((d->blend_mode & DEVELOP_BLEND_REVERSE) == DEVELOP_BLEND_REVERSE)
       {
 #ifdef _OPENMP
