@@ -141,13 +141,13 @@ static inline void _blendif_jzczhz(const float *const restrict pixels, float *co
 {
   for(size_t x = 0, j = 0; x < stride; x++, j += DT_BLENDIF_RGB_CH)
   {
-    float XYZ_D65[3] DT_ALIGNED_PIXEL;
-    float JzAzBz[3] DT_ALIGNED_PIXEL;
-    float JzCzhz[3] DT_ALIGNED_PIXEL;
+    dt_aligned_pixel_t XYZ_D65;
+    dt_aligned_pixel_t JzAzBz;
+    dt_aligned_pixel_t JzCzhz;
 
     // use the matrix_out of the hacked profile for blending to use the
     // conversion from RGB to XYZ D65 (instead of XYZ D50)
-    dt_ioppr_rgb_matrix_to_xyz(pixels + j, XYZ_D65, profile->matrix_out, profile->lut_in,
+    dt_ioppr_rgb_matrix_to_xyz(pixels + j, XYZ_D65, profile->matrix_out_transposed, profile->lut_in,
                                profile->unbounded_coeffs_in, profile->lutsize, profile->nonlinearlut);
 
     dt_XYZ_2_JzAzBz(XYZ_D65, JzAzBz);
@@ -746,17 +746,17 @@ static inline float _rgb_luminance(const float *const restrict rgb,
 #ifdef _OPENMP
 #pragma omp declare simd aligned(rgb, JzCzhz: 16) uniform(profile)
 #endif
-static inline void _rgb_to_JzCzhz(const float *const restrict rgb, float *const restrict JzCzhz,
+static inline void _rgb_to_JzCzhz(const dt_aligned_pixel_t rgb, dt_aligned_pixel_t JzCzhz,
                                   const dt_iop_order_iccprofile_info_t *const restrict profile)
 {
-  float JzAzBz[3] DT_ALIGNED_PIXEL = { 0.0f, 0.0f, 0.0f };
+  dt_aligned_pixel_t JzAzBz = { 0.0f, 0.0f, 0.0f };
 
   if(profile)
   {
-    float XYZ_D65[3] DT_ALIGNED_PIXEL = { 0.0f, 0.0f, 0.0f };
+    dt_aligned_pixel_t XYZ_D65 = { 0.0f, 0.0f, 0.0f };
     // use the matrix_out of the hacked profile for blending to use the
     // conversion from RGB to XYZ D65 (instead of XYZ D50)
-    dt_ioppr_rgb_matrix_to_xyz(rgb, XYZ_D65, profile->matrix_out, profile->lut_in, profile->unbounded_coeffs_in,
+    dt_ioppr_rgb_matrix_to_xyz(rgb, XYZ_D65, profile->matrix_out_transposed, profile->lut_in, profile->unbounded_coeffs_in,
                                profile->lutsize, profile->nonlinearlut);
     dt_XYZ_2_JzAzBz(XYZ_D65, JzAzBz);
   }
@@ -873,7 +873,7 @@ static void _display_channel(const float *const restrict a, float *const restric
       const float factor = 1.0f / exp2f(boost_factors[DEVELOP_BLENDIF_Jz_in]);
       for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_RGB_CH)
       {
-        float JzCzhz[3] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t JzCzhz;
         _rgb_to_JzCzhz(a + j, JzCzhz, profile);
         const float c = clamp_simd(JzCzhz[0] * factor);
         for(int k = 0; k < DT_BLENDIF_RGB_BCH; k++) b[j + k] = c;
@@ -886,7 +886,7 @@ static void _display_channel(const float *const restrict a, float *const restric
       const float factor = 1.0f / exp2f(boost_factors[DEVELOP_BLENDIF_Jz_out]);
       for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_RGB_CH)
       {
-        float JzCzhz[3] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t JzCzhz;
         _rgb_to_JzCzhz(b + j, JzCzhz, profile);
         const float c = clamp_simd(JzCzhz[0] * factor);
         for(int k = 0; k < DT_BLENDIF_RGB_BCH; k++) b[j + k] = c;
@@ -899,7 +899,7 @@ static void _display_channel(const float *const restrict a, float *const restric
       const float factor = 1.0f / exp2f(boost_factors[DEVELOP_BLENDIF_Cz_in]);
       for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_RGB_CH)
       {
-        float JzCzhz[3] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t JzCzhz;
         _rgb_to_JzCzhz(a + j, JzCzhz, profile);
         const float c = clamp_simd(JzCzhz[1] * factor);
         for(int k = 0; k < DT_BLENDIF_RGB_BCH; k++) b[j + k] = c;
@@ -912,7 +912,7 @@ static void _display_channel(const float *const restrict a, float *const restric
       const float factor = 1.0f / exp2f(boost_factors[DEVELOP_BLENDIF_Cz_out]);
       for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_RGB_CH)
       {
-        float JzCzhz[3] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t JzCzhz;
         _rgb_to_JzCzhz(b + j, JzCzhz, profile);
         const float c = clamp_simd(JzCzhz[1] * factor);
         for(int k = 0; k < DT_BLENDIF_RGB_BCH; k++) b[j + k] = c;
@@ -924,7 +924,7 @@ static void _display_channel(const float *const restrict a, float *const restric
       // no boost factor for hues
       for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_RGB_CH)
       {
-        float JzCzhz[3] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t JzCzhz;
         _rgb_to_JzCzhz(a + j, JzCzhz, profile);
         const float c = clamp_simd(JzCzhz[2]);
         for(int k = 0; k < DT_BLENDIF_RGB_BCH; k++) b[j + k] = c;
@@ -935,7 +935,7 @@ static void _display_channel(const float *const restrict a, float *const restric
       // no boost factor for hues
       for(size_t i = 0, j = 0; i < stride; i++, j += DT_BLENDIF_RGB_CH)
       {
-        float JzCzhz[3] DT_ALIGNED_PIXEL;
+        dt_aligned_pixel_t JzCzhz;
         _rgb_to_JzCzhz(b + j, JzCzhz, profile);
         const float c = clamp_simd(JzCzhz[2]);
         for(int k = 0; k < DT_BLENDIF_RGB_BCH; k++) b[j + k] = c;
@@ -1009,10 +1009,10 @@ void dt_develop_blendif_rgb_jzczhz_blend(struct dt_dev_pixelpipe_iop_t *piece, c
     const float p = exp2f(d->blend_parameter);
     _blend_row_func *const blend = _choose_blend_func(d->blend_mode);
 
-    float *tmp_buffer = dt_alloc_align_float(owidth * oheight * DT_BLENDIF_RGB_CH);
+    float *tmp_buffer = dt_alloc_align_float((size_t)owidth * oheight * DT_BLENDIF_RGB_CH);
     if (tmp_buffer != NULL)
     {
-      dt_iop_image_copy(tmp_buffer, b, owidth * oheight * DT_BLENDIF_RGB_CH);
+      dt_iop_image_copy(tmp_buffer, b, (size_t)owidth * oheight * DT_BLENDIF_RGB_CH);
       if((d->blend_mode & DEVELOP_BLEND_REVERSE) == DEVELOP_BLEND_REVERSE)
       {
 #ifdef _OPENMP
