@@ -247,6 +247,8 @@ typedef struct dt_develop_t
       void (*search_text_focus)(struct dt_lib_module_t *self);
       /* test if module is preset in one of the current groups */
       gboolean (*test_visible)(struct dt_lib_module_t *self, gchar *module);
+      /* add or remove module or widget in current quick access list */
+      gboolean (*basics_module_toggle)(struct dt_lib_module_t *self, GtkWidget *widget, gboolean doit);
     } modulegroups;
 
     // snapshots plugin hooks
@@ -267,7 +269,7 @@ typedef struct dt_develop_t
       void (*list_remove)(struct dt_lib_module_t *self, int formid, int parentid);
       void (*list_update)(struct dt_lib_module_t *self);
       /* selected forms change */
-      void (*selection_change)(struct dt_lib_module_t *self, int selectid, int throw_event);
+      void (*selection_change)(struct dt_lib_module_t *self, struct dt_iop_module_t *module, const int selectid, const int throw_event);
     } masks;
 
     // what is the ID of the module currently doing pipeline chromatic adaptation ?
@@ -277,14 +279,13 @@ typedef struct dt_develop_t
 
     // is the WB module using D65 illuminant and not doing full chromatic adaptation ?
     gboolean wb_is_D65;
-    float wb_coeffs[4];
+    dt_aligned_pixel_t wb_coeffs;
 
   } proxy;
 
   // for the overexposure indicator
   struct
   {
-    guint timeout;
     GtkWidget *floating_window, *button; // yes, having gtk stuff in here is ugly. live with it.
 
     gboolean enabled;
@@ -297,7 +298,6 @@ typedef struct dt_develop_t
   // for the raw overexposure indicator
   struct
   {
-    guint timeout;
     GtkWidget *floating_window, *button; // yes, having gtk stuff in here is ugly. live with it.
 
     gboolean enabled;
@@ -306,16 +306,6 @@ typedef struct dt_develop_t
     float threshold;
   } rawoverexposed;
 
-  // for the overlay color indicator
-  struct
-  {
-    guint timeout;
-    GtkWidget *floating_window, *button, *colors; // yes, having gtk stuff in here is ugly. live with it.
-
-    gboolean enabled;
-    dt_dev_overlay_colors_t color;
-  } overlay_color;
-
   // ISO 12646-compliant colour assessment conditions
   struct
   {
@@ -326,7 +316,6 @@ typedef struct dt_develop_t
   // the display profile related things (softproof, gamut check, profiles ...)
   struct
   {
-    guint timeout;
     GtkWidget *floating_window, *softproof_button, *gamut_button;
   } profile;
 
@@ -369,6 +358,7 @@ void dt_dev_load_image(dt_develop_t *dev, const uint32_t imgid);
 void dt_dev_reload_image(dt_develop_t *dev, const uint32_t imgid);
 /** checks if provided imgid is the image currently in develop */
 int dt_dev_is_current_image(dt_develop_t *dev, uint32_t imgid);
+const dt_dev_history_item_t *dt_dev_get_history_item(dt_develop_t *dev, const char *op);
 void dt_dev_add_history_item_ext(dt_develop_t *dev, struct dt_iop_module_t *module, gboolean enable, gboolean no_image);
 void dt_dev_add_history_item(dt_develop_t *dev, struct dt_iop_module_t *module, gboolean enable);
 void dt_dev_add_new_history_item(dt_develop_t *dev, struct dt_iop_module_t *module, gboolean enable);
@@ -442,6 +432,8 @@ gboolean dt_dev_modulegroups_test(dt_develop_t *dev, uint32_t group, struct dt_i
 void dt_dev_reorder_gui_module_list(dt_develop_t *dev);
 /** test if the iop is visible in current groups layout **/
 gboolean dt_dev_modulegroups_is_visible(dt_develop_t *dev, gchar *module);
+/** add or remove module or widget in current quick access list **/
+int dt_dev_modulegroups_basics_module_toggle(dt_develop_t *dev, GtkWidget *widget, gboolean doit);
 
 /** request snapshot */
 void dt_dev_snapshot_request(dt_develop_t *dev, const char *filename);
@@ -455,7 +447,7 @@ void dt_dev_average_delay_update(const dt_times_t *start, uint32_t *average_dela
 void dt_dev_masks_list_change(dt_develop_t *dev);
 void dt_dev_masks_list_update(dt_develop_t *dev);
 void dt_dev_masks_list_remove(dt_develop_t *dev, int formid, int parentid);
-void dt_dev_masks_selection_change(dt_develop_t *dev, int selectid, int throw_event);
+void dt_dev_masks_selection_change(dt_develop_t *dev, struct dt_iop_module_t *module, const int selectid, const int throw_event);
 
 /*
  * multi instances
