@@ -348,19 +348,18 @@ GtkWidget *dt_bauhaus_toggle_from_params(dt_iop_module_t *self, const char *para
   dt_iop_params_t *p = (dt_iop_params_t *)self->params;
   dt_introspection_field_t *f = self->so->get_f(param);
 
-  GtkWidget *button, *label;
-  gchar *str;
+  GtkWidget *button = NULL;
+  gchar *str = NULL;
 
   if(f && f->header.type == DT_INTROSPECTION_TYPE_BOOL)
   {
     // we do not want to support a context as it break all translations see #5498
     // button = gtk_check_button_new_with_label(g_dpgettext2(NULL, "introspection description", f->header.description));
-      label = gtk_label_new(gettext(f->header.description));
     str = *f->header.description
         ? g_strdup(f->header.description)
         : dt_util_str_replace(f->header.field_name, "_", " ");
 
-    label = gtk_label_new(_(str));
+    GtkWidget *label = gtk_label_new(_(str));
     gtk_label_set_ellipsize(GTK_LABEL(label), PANGO_ELLIPSIZE_END);
     button = gtk_check_button_new();
     gtk_container_add(GTK_CONTAINER(button), label);
