@@ -1101,6 +1101,13 @@ static int _ellipse_events_button_released(struct dt_iop_module_t *module, float
       darktable.develop->form_gui->creation = TRUE;
       darktable.develop->form_gui->creation_module = gui->creation_continuous_module;
     }
+
+    // and select the source as default, if the mouse is not moved we are inside the
+    // source and so want to move the source.
+    gui->form_selected = TRUE;
+    gui->source_selected = TRUE;
+    gui->border_selected = FALSE;
+
     return 1;
   }
   return 0;
@@ -1651,7 +1658,7 @@ static void _fill_mask(const size_t numpoints, float *const bufptr, const float
   const float sin_alpha = sinf(alpha);
 
   // Determine the strength of the mask for each of the distorted points.  If inside the border of the ellipse,
-  // the strength is always 1.0; if outside the fallow region, it is 0.0, and in between it falls off quadratically.
+  // the strength is always 1.0; if outside the falloff region, it is 0.0, and in between it falls off quadratically.
   // To compute this, we need to do the equivalent of projecting the vector from the center of the ellipse to the
   // given point until it intersect the ellipse and the outer edge of the falloff, respectively.  The ellipse can
   // be rotated, but we can compensate for that by applying a rotation matrix for the same rotation in the opposite
