@@ -53,7 +53,7 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t* Data, size_t Size) {
     c.decode(slicing);
 
     mRaw->checkMemIsInitialized();
-  } catch (rawspeed::RawspeedException&) {
+  } catch (const rawspeed::RawspeedException&) {
     // Exceptions are good, crashes are bad.
   }
 
