@@ -62,7 +62,7 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t* Data, size_t Size) {
     mRaw->createData();
 
     // no image data was actually be decoded, so don't check for initialization
-  } catch (rawspeed::RawspeedException&) {
+  } catch (const rawspeed::RawspeedException&) {
     // Exceptions are good, crashes are bad.
   }
 
