@@ -54,7 +54,7 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t* Data, size_t Size) {
     // VC5Decompressor is special
     // It is expected to be the only DNG tile, and to fill the entire image.
     mRaw->checkMemIsInitialized();
-  } catch (rawspeed::RawspeedException&) {
+  } catch (const rawspeed::RawspeedException&) {
     // Exceptions are good, crashes are bad.
   }
 
