@@ -65,14 +65,14 @@ class DngOpcodes::FixBadPixelsConstant final : public DngOpcodes::DngOpcode {
   uint32_t value;
 
 public:
-  explicit FixBadPixelsConstant(const RawImage& ri, ByteStream* bs)
-      : value(bs->getU32()) {
-    bs->getU32(); // Bayer Phase not used
+  explicit FixBadPixelsConstant(const RawImage& ri, ByteStream& bs)
+      : value(bs.getU32()) {
+    bs.getU32(); // Bayer Phase not used
   }
 
   void setup(const RawImage& ri) override {
     // These limitations are present within the DNG SDK as well.
-    if (ri->getDataType() != TYPE_USHORT16)
+    if (ri->getDataType() != RawImageType::UINT16)
       ThrowRDE("Only 16 bit images supported");
 
     if (ri->getCpp() > 1)
@@ -81,13 +81,13 @@ public:
 
   void apply(const RawImage& ri) override {
     MutexLocker guard(&ri->mBadPixelMutex);
+    const CroppedArray2DRef<uint16_t> img(ri->getU16DataAsCroppedArray2DRef());
     iPoint2D crop = ri->getCropOffset();
     uint32_t offset = crop.x | (crop.y << 16);
-    for (auto y = 0; y < ri->dim.y; ++y) {
-      auto* src = reinterpret_cast<uint16_t*>(ri->getData(0, y));
-      for (auto x = 0; x < ri->dim.x; ++x) {
-        if (src[x] == value)
-          ri->mBadPixelPositions.push_back(offset + (y << 16 | x));
+    for (auto row = 0; row < img.croppedHeight; ++row) {
+      for (auto col = 0; col < img.croppedWidth; ++col) {
+        if (img(row, col) == value)
+          ri->mBadPixelPositions.push_back(offset + (row << 16 | col));
       }
     }
   }
@@ -99,15 +99,15 @@ class DngOpcodes::ROIOpcode : public DngOpcodes::DngOpcode {
   iRectangle2D roi;
 
 protected:
-  explicit ROIOpcode(const RawImage& ri, ByteStream* bs, bool minusOne) {
+  explicit ROIOpcode(const RawImage& ri, ByteStream& bs, bool minusOne) {
     const iRectangle2D fullImage =
         minusOne ? iRectangle2D(0, 0, ri->dim.x - 1, ri->dim.y - 1)
                  : iRectangle2D(0, 0, ri->dim.x, ri->dim.y);
 
-    uint32_t top = bs->getU32();
-    uint32_t left = bs->getU32();
-    uint32_t bottom = bs->getU32();
-    uint32_t right = bs->getU32();
+    uint32_t top = bs.getU32();
+    uint32_t left = bs.getU32();
+    uint32_t bottom = bs.getU32();
+    uint32_t right = bs.getU32();
 
     const iPoint2D topLeft(left, top);
     const iPoint2D bottomRight(right, bottom);
@@ -126,21 +126,23 @@ protected:
     assert(roi.isThisInside(fullImage));
   }
 
-  const iRectangle2D& __attribute__((pure)) getRoi() const { return roi; }
+  [[nodiscard]] const iRectangle2D& __attribute__((pure)) getRoi() const {
+    return roi;
+  }
 };
 
 // ****************************************************************************
 
 class DngOpcodes::DummyROIOpcode final : public ROIOpcode {
 public:
-  explicit DummyROIOpcode(const RawImage& ri, ByteStream* bs)
+  explicit DummyROIOpcode(const RawImage& ri, ByteStream& bs)
       : ROIOpcode(ri, bs, true) {}
 
-  const iRectangle2D& __attribute__((pure)) getRoi() const {
+  [[nodiscard]] const iRectangle2D& __attribute__((pure)) getRoi() const {
     return ROIOpcode::getRoi();
   }
 
-  [[noreturn]] void apply(const RawImage& ri) final {
+  [[noreturn]] void apply(const RawImage& ri) override {
     // NOLINTNEXTLINE: https://bugs.llvm.org/show_bug.cgi?id=50532
     assert(false && "You should not be calling this.");
     __builtin_unreachable();
@@ -153,28 +155,28 @@ class DngOpcodes::FixBadPixelsList final : public DngOpcodes::DngOpcode {
   std::vector<uint32_t> badPixels;
 
 public:
-  explicit FixBadPixelsList(const RawImage& ri, ByteStream* bs) {
+  explicit FixBadPixelsList(const RawImage& ri, ByteStream& bs) {
     const iRectangle2D fullImage(0, 0, ri->getUncroppedDim().x - 1,
                                  ri->getUncroppedDim().y - 1);
 
-    bs->getU32(); // Skip phase - we don't care
-    auto badPointCount = bs->getU32();
-    auto badRectCount = bs->getU32();
+    bs.getU32(); // Skip phase - we don't care
+    auto badPointCount = bs.getU32();
+    auto badRectCount = bs.getU32();
 
     // first, check that we indeed have much enough data
-    const auto origPos = bs->getPosition();
-    bs->skipBytes(badPointCount, 2 * 4);
-    bs->skipBytes(badRectCount, 4 * 4);
-    bs->setPosition(origPos);
+    const auto origPos = bs.getPosition();
+    bs.skipBytes(badPointCount, 2 * 4);
+    bs.skipBytes(badRectCount, 4 * 4);
+    bs.setPosition(origPos);
 
     // Read points
     badPixels.reserve(badPixels.size() + badPointCount);
     for (auto i = 0U; i < badPointCount; ++i) {
-      auto y = bs->getU32();
-      auto x = bs->getU32();
+      auto y = bs.getU32();
+      auto x = bs.getU32();
 
-      const iPoint2D badPoint(x, y);
-      if (!fullImage.isPointInsideInclusive(badPoint))
+      if (const iPoint2D badPoint(x, y);
+          !fullImage.isPointInsideInclusive(badPoint))
         ThrowRDE("Bad point not inside image.");
 
       badPixels.emplace_back(y << 16 | x);
@@ -208,7 +210,7 @@ public:
 
 class DngOpcodes::TrimBounds final : public ROIOpcode {
 public:
-  explicit TrimBounds(const RawImage& ri, ByteStream* bs)
+  explicit TrimBounds(const RawImage& ri, ByteStream& bs)
       : ROIOpcode(ri, bs, false) {}
 
   void apply(const RawImage& ri) override { ri->subFrame(getRoi()); }
@@ -223,9 +225,8 @@ class DngOpcodes::PixelOpcode : public ROIOpcode {
   uint32_t colPitch;
 
 protected:
-  explicit PixelOpcode(const RawImage& ri, ByteStream* bs)
-      : ROIOpcode(ri, bs, false), firstPlane(bs->getU32()),
-        planes(bs->getU32()) {
+  explicit PixelOpcode(const RawImage& ri, ByteStream& bs)
+      : ROIOpcode(ri, bs, false), firstPlane(bs.getU32()), planes(bs.getU32()) {
 
     if (planes == 0 || firstPlane > ri->getCpp() || planes > ri->getCpp() ||
         firstPlane + planes > ri->getCpp()) {
@@ -233,8 +234,8 @@ protected:
                firstPlane, planes, ri->getCpp());
     }
 
-    rowPitch = bs->getU32();
-    colPitch = bs->getU32();
+    rowPitch = bs.getU32();
+    colPitch = bs.getU32();
 
     const iRectangle2D& ROI = getRoi();
 
@@ -269,18 +270,19 @@ class DngOpcodes::LookupOpcode : public PixelOpcode {
 protected:
   vector<uint16_t> lookup;
 
-  explicit LookupOpcode(const RawImage& ri, ByteStream* bs)
+  explicit LookupOpcode(const RawImage& ri, ByteStream& bs)
       : PixelOpcode(ri, bs), lookup(65536) {}
 
   void setup(const RawImage& ri) override {
     PixelOpcode::setup(ri);
-    if (ri->getDataType() != TYPE_USHORT16)
+    if (ri->getDataType() != RawImageType::UINT16)
       ThrowRDE("Only 16 bit images supported");
   }
 
   void apply(const RawImage& ri) override {
-    applyOP<uint16_t>(
-        ri, [this](uint32_t x, uint32_t y, uint16_t v) { return lookup[v]; });
+    applyOP<uint16_t>(ri, [this]([[maybe_unused]] uint32_t x,
+                                 [[maybe_unused]] uint32_t y,
+                                 uint16_t v) { return lookup[v]; });
   }
 };
 
@@ -288,14 +290,14 @@ protected:
 
 class DngOpcodes::TableMap final : public LookupOpcode {
 public:
-  explicit TableMap(const RawImage& ri, ByteStream* bs) : LookupOpcode(ri, bs) {
-    auto count = bs->getU32();
+  explicit TableMap(const RawImage& ri, ByteStream& bs) : LookupOpcode(ri, bs) {
+    auto count = bs.getU32();
 
     if (count == 0 || count > 65536)
       ThrowRDE("Invalid size of lookup table");
 
     for (auto i = 0U; i < count; ++i)
-      lookup[i] = bs->getU16();
+      lookup[i] = bs.getU16();
 
     if (count < lookup.size())
       fill_n(&lookup[count], lookup.size() - count, lookup[count - 1]);
@@ -306,18 +308,18 @@ public:
 
 class DngOpcodes::PolynomialMap final : public LookupOpcode {
 public:
-  explicit PolynomialMap(const RawImage& ri, ByteStream* bs)
+  explicit PolynomialMap(const RawImage& ri, ByteStream& bs)
       : LookupOpcode(ri, bs) {
     vector<double> polynomial;
 
-    const auto polynomial_size = bs->getU32() + 1UL;
-    bs->check(8UL * polynomial_size);
+    const auto polynomial_size = bs.getU32() + 1UL;
+    (void)bs.check(8UL * polynomial_size);
     if (polynomial_size > 9)
       ThrowRDE("A polynomial with more than 8 degrees not allowed");
 
     polynomial.reserve(polynomial_size);
     std::generate_n(std::back_inserter(polynomial), polynomial_size,
-                    [&bs]() { return bs->get<double>(); });
+                    [&bs]() { return bs.get<double>(); });
 
     // Create lookup
     lookup.resize(65536);
@@ -343,7 +345,7 @@ public:
   };
 
 protected:
-  DeltaRowOrColBase(const RawImage& ri, ByteStream* bs) : PixelOpcode(ri, bs) {}
+  DeltaRowOrColBase(const RawImage& ri, ByteStream& bs) : PixelOpcode(ri, bs) {}
 };
 
 template <typename S>
@@ -353,7 +355,7 @@ public:
     PixelOpcode::setup(ri);
 
     // If we are working on a float image, no need to convert to int
-    if (ri->getDataType() != TYPE_USHORT16)
+    if (ri->getDataType() != RawImageType::UINT16)
       return;
 
     deltaI.reserve(deltaF.size());
@@ -372,25 +374,25 @@ protected:
   // only meaningful for uint16_t images!
   virtual bool valueIsOk(float value) = 0;
 
-  DeltaRowOrCol(const RawImage& ri, ByteStream* bs, float f2iScale_)
+  DeltaRowOrCol(const RawImage& ri, ByteStream& bs, float f2iScale_)
       : DeltaRowOrColBase(ri, bs), f2iScale(f2iScale_) {
-    const auto deltaF_count = bs->getU32();
-    bs->check(deltaF_count, 4);
+    const auto deltaF_count = bs.getU32();
+    (void)bs.check(deltaF_count, 4);
 
     // See PixelOpcode::applyOP(). We will access deltaF/deltaI up to (excl.)
     // either ROI.getRight() or ROI.getBottom() index. Thus, we need to have
     // either ROI.getRight() or ROI.getBottom() elements in there.
     // FIXME: i guess not strictly true with pitch != 1.
-    const auto expectedSize =
-        S::select(getRoi().getRight(), getRoi().getBottom());
-    if (expectedSize != deltaF_count) {
+    if (const auto expectedSize =
+            S::select(getRoi().getRight(), getRoi().getBottom());
+        expectedSize != deltaF_count) {
       ThrowRDE("Got unexpected number of elements (%u), expected %u.",
                expectedSize, deltaF_count);
     }
 
     deltaF.reserve(deltaF_count);
     std::generate_n(std::back_inserter(deltaF), deltaF_count, [&bs]() {
-      const auto F = bs->get<float>();
+      const auto F = bs.get<float>();
       if (!std::isfinite(F))
         ThrowRDE("Got bad float %f.", F);
       return F;
@@ -408,16 +410,16 @@ class DngOpcodes::OffsetPerRowOrCol final : public DeltaRowOrCol<S> {
   // by f2iScale before applying, we need to divide by f2iScale here.
   const double absLimit;
 
-  bool valueIsOk(float value) final { return std::abs(value) <= absLimit; }
+  bool valueIsOk(float value) override { return std::abs(value) <= absLimit; }
 
 public:
-  explicit OffsetPerRowOrCol(const RawImage& ri, ByteStream* bs)
+  explicit OffsetPerRowOrCol(const RawImage& ri, ByteStream& bs)
       : DeltaRowOrCol<S>(ri, bs, 65535.0F),
         absLimit(double(std::numeric_limits<uint16_t>::max()) /
                  this->f2iScale) {}
 
   void apply(const RawImage& ri) override {
-    if (ri->getDataType() == TYPE_USHORT16) {
+    if (ri->getDataType() == RawImageType::UINT16) {
       this->template applyOP<uint16_t>(
           ri, [this](uint32_t x, uint32_t y, uint16_t v) {
             return clampBits(this->deltaI[S::select(x, y)] + v, 16);
@@ -443,19 +445,19 @@ class DngOpcodes::ScalePerRowOrCol final : public DeltaRowOrCol<S> {
   static constexpr int rounding = 512;
   const double maxLimit;
 
-  bool valueIsOk(float value) final {
+  bool valueIsOk(float value) override {
     return value >= minLimit && value <= maxLimit;
   }
 
 public:
-  explicit ScalePerRowOrCol(const RawImage& ri, ByteStream* bs)
+  explicit ScalePerRowOrCol(const RawImage& ri, ByteStream& bs)
       : DeltaRowOrCol<S>(ri, bs, 1024.0F),
         maxLimit((double(std::numeric_limits<int>::max() - rounding) /
                   double(std::numeric_limits<uint16_t>::max())) /
                  this->f2iScale) {}
 
   void apply(const RawImage& ri) override {
-    if (ri->getDataType() == TYPE_USHORT16) {
+    if (ri->getDataType() == RawImageType::UINT16) {
       this->template applyOP<uint16_t>(ri, [this](uint32_t x, uint32_t y,
                                                   uint16_t v) {
         return clampBits((this->deltaI[S::select(x, y)] * v + 512) >> 10, 16);
@@ -471,7 +473,7 @@ public:
 
 // ****************************************************************************
 
-DngOpcodes::DngOpcodes(const RawImage& ri, TiffEntry* entry) {
+DngOpcodes::DngOpcodes(const RawImage& ri, const TiffEntry* entry) {
   ByteStream bs = entry->getData();
 
   // DNG opcodes are always stored in big-endian byte order.
@@ -509,12 +511,12 @@ DngOpcodes::DngOpcodes(const RawImage& ri, TiffEntry* entry) {
     constructor_t opConstructor = nullptr;
     try {
       std::tie(opName, opConstructor) = Map.at(code);
-    } catch (std::out_of_range&) {
+    } catch (const std::out_of_range&) {
       ThrowRDE("Unknown unhandled Opcode: %d", code);
     }
 
     if (opConstructor != nullptr)
-      opcodes.emplace_back(opConstructor(ri, &opcode_bs));
+      opcodes.emplace_back(opConstructor(ri, opcode_bs));
     else {
 #ifndef DEBUG
       // Throw Error if not marked as optional
@@ -536,7 +538,7 @@ DngOpcodes::DngOpcodes(const RawImage& ri, TiffEntry* entry) {
 // of the DngOpcode type in DngOpcodes.h
 DngOpcodes::~DngOpcodes() = default;
 
-void DngOpcodes::applyOpCodes(const RawImage& ri) {
+void DngOpcodes::applyOpCodes(const RawImage& ri) const {
   for (const auto& code : opcodes) {
     code->setup(ri);
     code->apply(ri);
@@ -545,7 +547,7 @@ void DngOpcodes::applyOpCodes(const RawImage& ri) {
 
 template <class Opcode>
 std::unique_ptr<DngOpcodes::DngOpcode>
-DngOpcodes::constructor(const RawImage& ri, ByteStream* bs) {
+DngOpcodes::constructor(const RawImage& ri, ByteStream& bs) {
   return std::make_unique<Opcode>(ri, bs);
 }
 
