@@ -45,17 +45,17 @@ public:
   RawImage decodeRawInternal() override;
   void decodeMetaDataInternal(const CameraMetaData* meta) override;
 
-protected:
-  void ParseA100WB();
+private:
+  void ParseA100WB() const;
 
   [[nodiscard]] int getDecoderVersion() const override { return 1; }
   RawImage decodeSRF(const TiffIFD* raw);
   void DecodeARW2(const ByteStream& input, uint32_t w, uint32_t h,
                   uint32_t bpp);
-  void DecodeUncompressed(const TiffIFD* raw);
+  void DecodeUncompressed(const TiffIFD* raw) const;
   static void SonyDecrypt(const uint32_t* ibuf, uint32_t* obuf, uint32_t len,
                           uint32_t key);
-  void GetWB();
+  void GetWB() const;
   ByteStream in;
   int mShiftDownScale = 0;
 };
