@@ -30,9 +30,9 @@
 #include "io/ByteStream.h"                     // for ByteStream
 #include "io/Endianness.h"                     // for Endianness, Endiannes...
 #include "metadata/Camera.h"                   // for Hints
-#include "metadata/ColorFilterArray.h"         // for CFA_GREEN, CFA_BLUE
+#include "metadata/ColorFilterArray.h" // for CFAColor::GREEN, CFAColor::BLUE
 #include "parsers/TiffParserException.h"       // for ThrowTPE
-#include "tiff/TiffEntry.h"                    // for TiffEntry, TIFF_SHORT
+#include "tiff/TiffEntry.h" // for TiffEntry, TiffDataType::SHORT
 #include "tiff/TiffTag.h"                      // for TiffTag, CANONCOLORDATA
 #include <array>                               // for array
 #include <cassert>                             // for assert
@@ -42,12 +42,10 @@
 #include <vector>                              // for vector
 // IWYU pragma: no_include <ext/alloc_traits.h>
 
-using std::string;
-
 namespace rawspeed {
 
 bool Cr2Decoder::isAppropriateDecoder(const TiffRootIFD* rootIFD,
-                                      const Buffer& file) {
+                                      [[maybe_unused]] const Buffer& file) {
   const auto id = rootIFD->getID();
   const std::string& make = id.make;
   const std::string& model = id.model;
@@ -60,15 +58,16 @@ bool Cr2Decoder::isAppropriateDecoder(const TiffRootIFD* rootIFD,
 
 RawImage Cr2Decoder::decodeOldFormat() {
   uint32_t offset = 0;
-  if (mRootIFD->getEntryRecursive(CANON_RAW_DATA_OFFSET))
-    offset = mRootIFD->getEntryRecursive(CANON_RAW_DATA_OFFSET)->getU32();
-  else {
+  if (mRootIFD->getEntryRecursive(TiffTag::CANON_RAW_DATA_OFFSET)) {
+    offset =
+        mRootIFD->getEntryRecursive(TiffTag::CANON_RAW_DATA_OFFSET)->getU32();
+  } else {
     // D2000 is oh so special...
-    const auto* ifd = mRootIFD->getIFDWithTag(CFAPATTERN);
-    if (! ifd->hasEntry(STRIPOFFSETS))
+    const auto* ifd = mRootIFD->getIFDWithTag(TiffTag::CFAPATTERN);
+    if (!ifd->hasEntry(TiffTag::STRIPOFFSETS))
       ThrowRDE("Couldn't find offset");
 
-    offset = ifd->getEntry(STRIPOFFSETS)->getU32();
+    offset = ifd->getEntry(TiffTag::STRIPOFFSETS)->getU32();
   }
 
   ByteStream b(DataBuffer(mFile.getSubView(offset), Endianness::big));
@@ -96,8 +95,9 @@ RawImage Cr2Decoder::decodeOldFormat() {
   l.decode(slicing);
 
   // deal with D2000 GrayResponseCurve
-  TiffEntry* curve = mRootIFD->getEntryRecursive(static_cast<TiffTag>(0x123));
-  if (curve && curve->type == TIFF_SHORT && curve->count == 4096) {
+  if (const TiffEntry* curve =
+          mRootIFD->getEntryRecursive(static_cast<TiffTag>(0x123));
+      curve && curve->type == TiffDataType::SHORT && curve->count == 4096) {
     auto table = curve->getU16Array(curve->count);
     RawImageCurveGuard curveHandler(&mRaw, table, uncorrectedRawValues);
 
@@ -112,7 +112,8 @@ RawImage Cr2Decoder::decodeOldFormat() {
 // for technical details about Cr2 mRAW/sRAW, see http://lclevy.free.fr/cr2/
 
 RawImage Cr2Decoder::decodeNewFormat() {
-  TiffEntry* sensorInfoE = mRootIFD->getEntryRecursive(CANON_SENSOR_INFO);
+  const TiffEntry* sensorInfoE =
+      mRootIFD->getEntryRecursive(TiffTag::CANON_SENSOR_INFO);
   if (!sensorInfoE)
     ThrowTPE("failed to get SensorInfo from MakerNote");
 
@@ -142,7 +143,7 @@ RawImage Cr2Decoder::decodeNewFormat() {
     mRaw->dim.x *= 2 + subSampling.x * subSampling.y;
   }
 
-  TiffIFD* raw = mRootIFD->getSubIFDs()[3].get();
+  const TiffIFD* raw = mRootIFD->getSubIFDs()[3].get();
 
   Cr2Slicing slicing;
   // there are four cases:
@@ -154,8 +155,9 @@ RawImage Cr2Decoder::decodeNewFormat() {
   // * there is a tag with not three components, the image is considered
   // corrupt. $ there is no tag, we let Cr2Decompressor guess it (it'll throw if
   // fails)
-  TiffEntry* cr2SliceEntry = raw->getEntryRecursive(CANONCR2SLICE);
-  if (cr2SliceEntry) {
+  if (const TiffEntry* cr2SliceEntry =
+          raw->getEntryRecursive(TiffTag::CANONCR2SLICE);
+      cr2SliceEntry) {
     if (cr2SliceEntry->count != 3) {
       ThrowRDE("Found RawImageSegmentation tag with %d elements, should be 3.",
                cr2SliceEntry->count);
@@ -176,8 +178,8 @@ RawImage Cr2Decoder::decodeNewFormat() {
     }
   } // EOS 20D, EOS-1D Mark II, let Cr2Decompressor guess.
 
-  const uint32_t offset = raw->getEntry(STRIPOFFSETS)->getU32();
-  const uint32_t count = raw->getEntry(STRIPBYTECOUNTS)->getU32();
+  const uint32_t offset = raw->getEntry(TiffTag::STRIPOFFSETS)->getU32();
+  const uint32_t count = raw->getEntry(TiffTag::STRIPBYTECOUNTS)->getU32();
 
   const ByteStream bs(
       DataBuffer(mFile.getSubView(offset, count), Endianness::little));
@@ -214,9 +216,10 @@ void Cr2Decoder::checkSupportInternal(const CameraMetaData* meta) {
 
 void Cr2Decoder::decodeMetaDataInternal(const CameraMetaData* meta) {
   int iso = 0;
-  mRaw->cfa.setCFA(iPoint2D(2,2), CFA_RED, CFA_GREEN, CFA_GREEN, CFA_BLUE);
+  mRaw->cfa.setCFA(iPoint2D(2, 2), CFAColor::RED, CFAColor::GREEN,
+                   CFAColor::GREEN, CFAColor::BLUE);
 
-  string mode;
+  std::string mode;
 
   if (mRaw->metadata.subsampling.y == 2 && mRaw->metadata.subsampling.x == 2)
     mode = "sRaw1";
@@ -224,19 +227,21 @@ void Cr2Decoder::decodeMetaDataInternal(const CameraMetaData* meta) {
   if (mRaw->metadata.subsampling.y == 1 && mRaw->metadata.subsampling.x == 2)
     mode = "sRaw2";
 
-  if (mRootIFD->hasEntryRecursive(ISOSPEEDRATINGS))
-    iso = mRootIFD->getEntryRecursive(ISOSPEEDRATINGS)->getU32();
+  if (mRootIFD->hasEntryRecursive(TiffTag::ISOSPEEDRATINGS))
+    iso = mRootIFD->getEntryRecursive(TiffTag::ISOSPEEDRATINGS)->getU32();
   if(65535 == iso) {
     // ISOSPEEDRATINGS is a SHORT EXIF value. For larger values, we have to look
     // at RECOMMENDEDEXPOSUREINDEX (maybe Canon specific).
-    if (mRootIFD->hasEntryRecursive(RECOMMENDEDEXPOSUREINDEX))
-      iso = mRootIFD->getEntryRecursive(RECOMMENDEDEXPOSUREINDEX)->getU32();
+    if (mRootIFD->hasEntryRecursive(TiffTag::RECOMMENDEDEXPOSUREINDEX))
+      iso = mRootIFD->getEntryRecursive(TiffTag::RECOMMENDEDEXPOSUREINDEX)
+                ->getU32();
   }
 
   // Fetch the white balance
   try{
-    if (mRootIFD->hasEntryRecursive(CANONCOLORDATA)) {
-      TiffEntry *wb = mRootIFD->getEntryRecursive(CANONCOLORDATA);
+    if (mRootIFD->hasEntryRecursive(TiffTag::CANONCOLORDATA)) {
+      const TiffEntry* wb =
+          mRootIFD->getEntryRecursive(TiffTag::CANONCOLORDATA);
       // this entry is a big table, and different cameras store used WB in
       // different parts, so find the offset, default is the most common one
       int offset = hints.get("wb_offset", 126);
@@ -246,10 +251,12 @@ void Cr2Decoder::decodeMetaDataInternal(const CameraMetaData* meta) {
       mRaw->metadata.wbCoeffs[1] = static_cast<float>(wb->getU16(offset + 1));
       mRaw->metadata.wbCoeffs[2] = static_cast<float>(wb->getU16(offset + 3));
     } else {
-      if (mRootIFD->hasEntryRecursive(CANONSHOTINFO) &&
-          mRootIFD->hasEntryRecursive(CANONPOWERSHOTG9WB)) {
-        TiffEntry *shot_info = mRootIFD->getEntryRecursive(CANONSHOTINFO);
-        TiffEntry *g9_wb = mRootIFD->getEntryRecursive(CANONPOWERSHOTG9WB);
+      if (mRootIFD->hasEntryRecursive(TiffTag::CANONSHOTINFO) &&
+          mRootIFD->hasEntryRecursive(TiffTag::CANONPOWERSHOTG9WB)) {
+        const TiffEntry* shot_info =
+            mRootIFD->getEntryRecursive(TiffTag::CANONSHOTINFO);
+        const TiffEntry* g9_wb =
+            mRootIFD->getEntryRecursive(TiffTag::CANONPOWERSHOTG9WB);
 
         uint16_t wb_index = shot_info->getU16(7);
         int wb_offset = (wb_index < 18) ? "012347800000005896"[wb_index]-'0' : 0;
@@ -265,7 +272,8 @@ void Cr2Decoder::decodeMetaDataInternal(const CameraMetaData* meta) {
             static_cast<float>(g9_wb->getU32(wb_offset + 2));
       } else if (mRootIFD->hasEntryRecursive(static_cast<TiffTag>(0xa4))) {
         // WB for the old 1D and 1DS
-        TiffEntry* wb = mRootIFD->getEntryRecursive(static_cast<TiffTag>(0xa4));
+        const TiffEntry* wb =
+            mRootIFD->getEntryRecursive(static_cast<TiffTag>(0xa4));
         if (wb->count >= 3) {
           mRaw->metadata.wbCoeffs[0] = wb->getFloat(0);
           mRaw->metadata.wbCoeffs[1] = wb->getFloat(1);
@@ -273,7 +281,7 @@ void Cr2Decoder::decodeMetaDataInternal(const CameraMetaData* meta) {
         }
       }
     }
-  } catch (RawspeedException& e) {
+  } catch (const RawspeedException& e) {
     mRaw->setError(e.what());
     // We caught an exception reading WB, just ignore it
   }
@@ -283,17 +291,18 @@ void Cr2Decoder::decodeMetaDataInternal(const CameraMetaData* meta) {
 bool Cr2Decoder::isSubSampled() const {
   if (mRootIFD->getSubIFDs().size() != 4)
     return false;
-  TiffEntry* typeE =
-      mRootIFD->getSubIFDs()[3]->getEntryRecursive(CANON_SRAWTYPE);
+  const TiffEntry* typeE =
+      mRootIFD->getSubIFDs()[3]->getEntryRecursive(TiffTag::CANON_SRAWTYPE);
   return typeE && typeE->getU32() == 4;
 }
 
 iPoint2D Cr2Decoder::getSubSampling() const {
-  TiffEntry* CCS = mRootIFD->getEntryRecursive(CANON_CAMERA_SETTINGS);
+  const TiffEntry* CCS =
+      mRootIFD->getEntryRecursive(TiffTag::CANON_CAMERA_SETTINGS);
   if (!CCS)
     ThrowRDE("CanonCameraSettings entry not found.");
 
-  if (CCS->type != TIFF_SHORT)
+  if (CCS->type != TiffDataType::SHORT)
     ThrowRDE("Unexpected CanonCameraSettings entry type encountered ");
 
   if (CCS->count < 47)
@@ -311,16 +320,17 @@ iPoint2D Cr2Decoder::getSubSampling() const {
   }
 }
 
-int Cr2Decoder::getHue() {
+int Cr2Decoder::getHue() const {
   if (hints.has("old_sraw_hue"))
     return (mRaw->metadata.subsampling.y * mRaw->metadata.subsampling.x);
 
   if (!mRootIFD->hasEntryRecursive(static_cast<TiffTag>(0x10))) {
     return 0;
   }
-  uint32_t model_id =
-      mRootIFD->getEntryRecursive(static_cast<TiffTag>(0x10))->getU32();
-  if (model_id >= 0x80000281 || model_id == 0x80000218 || (hints.has("force_new_sraw_hue")))
+  if (uint32_t model_id =
+          mRootIFD->getEntryRecursive(static_cast<TiffTag>(0x10))->getU32();
+      model_id >= 0x80000281 || model_id == 0x80000218 ||
+      (hints.has("force_new_sraw_hue")))
     return ((mRaw->metadata.subsampling.y * mRaw->metadata.subsampling.x) - 1) >> 1;
 
   return (mRaw->metadata.subsampling.y * mRaw->metadata.subsampling.x);
@@ -328,7 +338,7 @@ int Cr2Decoder::getHue() {
 
 // Interpolate and convert sRaw data.
 void Cr2Decoder::sRawInterpolate() {
-  TiffEntry* wb = mRootIFD->getEntryRecursive(CANONCOLORDATA);
+  const TiffEntry* wb = mRootIFD->getEntryRecursive(TiffTag::CANONCOLORDATA);
   if (!wb)
     ThrowRDE("Unable to locate WB info.");
 
@@ -361,7 +371,7 @@ void Cr2Decoder::sRawInterpolate() {
                     subsampledRaw->metadata.subsampling.y)),
       subsampledRaw->metadata.subsampling.y * subsampledRaw->dim.y};
 
-  mRaw = RawImage::create(interpolatedDims, TYPE_USHORT16, 3);
+  mRaw = RawImage::create(interpolatedDims, RawImageType::UINT16, 3);
   mRaw->metadata.subsampling = subsampledRaw->metadata.subsampling;
   mRaw->isCFA = false;
 
