@@ -43,14 +43,14 @@ public:
   void checkSupportInternal(const CameraMetaData* meta) override;
   void decodeMetaDataInternal(const CameraMetaData* meta) override;
 
-protected:
+private:
   [[nodiscard]] int getDecoderVersion() const override { return 9; }
   RawImage decodeOldFormat();
   RawImage decodeNewFormat();
   void sRawInterpolate();
   [[nodiscard]] bool isSubSampled() const;
   [[nodiscard]] iPoint2D getSubSampling() const;
-  int getHue();
+  [[nodiscard]] int getHue() const;
 };
 
 } // namespace rawspeed
