@@ -70,7 +70,7 @@ bool IiqDecoder::isAppropriateDecoder(const TiffRootIFD* rootIFD,
 // FIXME: this is very close to SamsungV0Decompressor::computeStripes()
 std::vector<PhaseOneStrip>
 IiqDecoder::computeSripes(const Buffer& raw_data,
-                          std::vector<IiqOffset>&& offsets, uint32_t height) {
+                          std::vector<IiqOffset> offsets, uint32_t height) {
   assert(height > 0);
   assert(offsets.size() == (1 + height));
 
@@ -273,7 +273,7 @@ void IiqDecoder::CorrectPhaseOneC(ByteStream meta_data, uint32_t split_row,
 // curve's control points share the same seven X-coordinates.
 void IiqDecoder::CorrectQuadrantMultipliersCombined(ByteStream data,
                                                     uint32_t split_row,
-                                                    uint32_t split_col) {
+                                                    uint32_t split_col) const {
   std::array<uint32_t, 9> shared_x_coords;
 
   // Read the middle seven points from the file
@@ -359,7 +359,7 @@ void IiqDecoder::decodeMetaDataInternal(const CameraMetaData* meta) {
     mRaw->blackLevel = black_level;
 }
 
-void IiqDecoder::correctSensorDefects(ByteStream data) {
+void IiqDecoder::correctSensorDefects(ByteStream data) const {
   while (data.getRemainSize() != 0) {
     const uint16_t col = data.getU16();
     const uint16_t row = data.getU16();
@@ -382,17 +382,17 @@ void IiqDecoder::correctSensorDefects(ByteStream data) {
   }
 }
 
-void IiqDecoder::handleBadPixel(const uint16_t col, const uint16_t row) {
+void IiqDecoder::handleBadPixel(const uint16_t col, const uint16_t row) const {
   MutexLocker guard(&mRaw->mBadPixelMutex);
   mRaw->mBadPixelPositions.insert(mRaw->mBadPixelPositions.end(),
                                   (static_cast<uint32_t>(row) << 16) + col);
 }
 
-void IiqDecoder::correctBadColumn(const uint16_t col) {
+void IiqDecoder::correctBadColumn(const uint16_t col) const {
   const Array2DRef<uint16_t> img(mRaw->getU16DataAsUncroppedArray2DRef());
 
   for (int row = 2; row < mRaw->dim.y - 2; row++) {
-    if (mRaw->cfa.getColorAt(col, row) == CFA_GREEN) {
+    if (mRaw->cfa.getColorAt(col, row) == CFAColor::GREEN) {
       /* Do green pixels. Let's pretend we are in "G" pixel, in the middle:
        *   G=G
        *   BGB
