@@ -45,7 +45,7 @@ class IiqDecoder final : public AbstractTiffDecoder {
   };
 
   static std::vector<PhaseOneStrip>
-  computeSripes(const Buffer& raw_data, std::vector<IiqOffset>&& offsets,
+  computeSripes(const Buffer& raw_data, std::vector<IiqOffset> offsets,
                 uint32_t height);
 
 public:
@@ -60,16 +60,16 @@ public:
   void checkSupportInternal(const CameraMetaData* meta) override;
   void decodeMetaDataInternal(const CameraMetaData* meta) override;
 
-protected:
+private:
   [[nodiscard]] int getDecoderVersion() const override { return 0; }
   uint32_t black_level = 0;
   void CorrectPhaseOneC(ByteStream meta_data, uint32_t split_row,
                         uint32_t split_col);
   void CorrectQuadrantMultipliersCombined(ByteStream data, uint32_t split_row,
-                                          uint32_t split_col);
-  void correctSensorDefects(ByteStream data);
-  void correctBadColumn(uint16_t col);
-  void handleBadPixel(uint16_t col, uint16_t row);
+                                          uint32_t split_col) const;
+  void correctSensorDefects(ByteStream data) const;
+  void correctBadColumn(uint16_t col) const;
+  void handleBadPixel(uint16_t col, uint16_t row) const;
 };
 
 } // namespace rawspeed
