@@ -42,7 +42,7 @@
 namespace rawspeed {
 
 bool KdcDecoder::isAppropriateDecoder(const TiffRootIFD* rootIFD,
-                                      const Buffer& file) {
+                                      [[maybe_unused]] const Buffer& file) {
   const auto id = rootIFD->getID();
   const std::string& make = id.make;
 
@@ -51,8 +51,9 @@ bool KdcDecoder::isAppropriateDecoder(const TiffRootIFD* rootIFD,
   return make == "EASTMAN KODAK COMPANY";
 }
 
-Buffer KdcDecoder::getInputBuffer() {
-  TiffEntry* offset = mRootIFD->getEntryRecursive(KODAK_KDC_OFFSET);
+Buffer KdcDecoder::getInputBuffer() const {
+  const TiffEntry* offset =
+      mRootIFD->getEntryRecursive(TiffTag::KODAK_KDC_OFFSET);
   if (!offset || offset->count < 13)
     ThrowRDE("Couldn't find the KDC offset");
 
@@ -81,14 +82,15 @@ Buffer KdcDecoder::getInputBuffer() {
 }
 
 RawImage KdcDecoder::decodeRawInternal() {
-  if (!mRootIFD->hasEntryRecursive(COMPRESSION))
+  if (!mRootIFD->hasEntryRecursive(TiffTag::COMPRESSION))
     ThrowRDE("Couldn't find compression setting");
 
-  auto compression = mRootIFD->getEntryRecursive(COMPRESSION)->getU32();
-  if (7 != compression)
+  if (auto compression =
+          mRootIFD->getEntryRecursive(TiffTag::COMPRESSION)->getU32();
+      7 != compression)
     ThrowRDE("Unsupported compression %d", compression);
 
-  TiffEntry* ifdoffset = mRootIFD->getEntryRecursive(KODAK_IFD2);
+  const TiffEntry* ifdoffset = mRootIFD->getEntryRecursive(TiffTag::KODAK_IFD2);
   if (!ifdoffset)
     ThrowRDE("Couldn't find the Kodak IFD offset");
 
@@ -98,16 +100,16 @@ RawImage KdcDecoder::decodeRawInternal() {
   TiffRootIFD kodakifd(nullptr, &ifds, ifdoffset->getRootIfdData(),
                        ifdoffset->getU32());
 
-  uint32_t width = 0;
-  uint32_t height = 0;
-  TiffEntry* ew = kodakifd.getEntryRecursive(KODAK_KDC_SENSOR_WIDTH);
-  TiffEntry* eh = kodakifd.getEntryRecursive(KODAK_KDC_SENSOR_HEIGHT);
-  if (ew && eh) {
-    width = ew->getU32();
-    height = eh->getU32();
-  } else
+  const TiffEntry* ew =
+      kodakifd.getEntryRecursive(TiffTag::KODAK_KDC_SENSOR_WIDTH);
+  const TiffEntry* eh =
+      kodakifd.getEntryRecursive(TiffTag::KODAK_KDC_SENSOR_HEIGHT);
+  if (!ew || !eh)
     ThrowRDE("Unable to retrieve image size");
 
+  uint32_t width = ew->getU32();
+  uint32_t height = eh->getU32();
+
   mRaw->dim = iPoint2D(width, height);
 
   const Buffer inputBuffer = KdcDecoder::getInputBuffer();
@@ -126,30 +128,31 @@ void KdcDecoder::decodeMetaDataInternal(const CameraMetaData* meta) {
   setMetaData(meta, "", 0);
 
   // Try the kodak hidden IFD for WB
-  if (mRootIFD->hasEntryRecursive(KODAK_IFD2)) {
-    TiffEntry *ifdoffset = mRootIFD->getEntryRecursive(KODAK_IFD2);
+  if (mRootIFD->hasEntryRecursive(TiffTag::KODAK_IFD2)) {
+    const TiffEntry* ifdoffset =
+        mRootIFD->getEntryRecursive(TiffTag::KODAK_IFD2);
     try {
       NORangesSet<Buffer> ifds;
 
       TiffRootIFD kodakifd(nullptr, &ifds, ifdoffset->getRootIfdData(),
                            ifdoffset->getU32());
 
-      if (kodakifd.hasEntryRecursive(KODAK_KDC_WB)) {
-        TiffEntry *wb = kodakifd.getEntryRecursive(KODAK_KDC_WB);
+      if (kodakifd.hasEntryRecursive(TiffTag::KODAK_KDC_WB)) {
+        const TiffEntry* wb = kodakifd.getEntryRecursive(TiffTag::KODAK_KDC_WB);
         if (wb->count == 3) {
           mRaw->metadata.wbCoeffs[0] = wb->getFloat(0);
           mRaw->metadata.wbCoeffs[1] = wb->getFloat(1);
           mRaw->metadata.wbCoeffs[2] = wb->getFloat(2);
         }
       }
-    } catch (TiffParserException &e) {
+    } catch (const TiffParserException& e) {
       mRaw->setError(e.what());
     }
   }
 
   // Use the normal WB if available
-  if (mRootIFD->hasEntryRecursive(KODAKWB)) {
-    TiffEntry *wb = mRootIFD->getEntryRecursive(KODAKWB);
+  if (mRootIFD->hasEntryRecursive(TiffTag::KODAKWB)) {
+    const TiffEntry* wb = mRootIFD->getEntryRecursive(TiffTag::KODAKWB);
     if (wb->count == 734 || wb->count == 1502) {
       mRaw->metadata.wbCoeffs[0] =
           static_cast<float>(((static_cast<uint16_t>(wb->getByte(148))) << 8) |
