@@ -42,8 +42,6 @@
 #include <string>                                   // for string, allocator
 #include <utility>                                  // for move
 
-using std::string;
-
 namespace rawspeed {
 
 class CameraMetaData;
@@ -60,40 +58,41 @@ bool MosDecoder::isAppropriateDecoder(const TiffRootIFD* rootIFD,
   } catch (const TiffParserException&) {
     // Last ditch effort to identify Leaf cameras that don't have a Tiff Make
     // set
-    TiffEntry* softwareIFD = rootIFD->getEntryRecursive(SOFTWARE);
+    const TiffEntry* softwareIFD =
+        rootIFD->getEntryRecursive(TiffTag::SOFTWARE);
     if (!softwareIFD)
       return false;
 
-    const string software = trimSpaces(softwareIFD->getString());
+    const std::string software = trimSpaces(softwareIFD->getString());
     return software == "Camera Library";
   }
 }
 
 MosDecoder::MosDecoder(TiffRootIFDOwner&& rootIFD, const Buffer& file)
     : AbstractTiffDecoder(move(rootIFD), file) {
-  if (mRootIFD->getEntryRecursive(MAKE)) {
+  if (mRootIFD->getEntryRecursive(TiffTag::MAKE)) {
     auto id = mRootIFD->getID();
     make = id.make;
     model = id.model;
   } else {
-    TiffEntry *xmp = mRootIFD->getEntryRecursive(XMP);
+    const TiffEntry* xmp = mRootIFD->getEntryRecursive(TiffTag::XMP);
     if (!xmp)
       ThrowRDE("Couldn't find the XMP");
 
     assert(xmp != nullptr);
-    string xmpText = xmp->getString();
+    std::string xmpText = xmp->getString();
     make = getXMPTag(xmpText, "Make");
     model = getXMPTag(xmpText, "Model");
   }
 }
 
-string MosDecoder::getXMPTag(const string &xmp, const string &tag) {
-  string::size_type start = xmp.find("<tiff:"+tag+">");
-  string::size_type end = xmp.find("</tiff:"+tag+">");
-  if (start == string::npos || end == string::npos || end <= start)
-    ThrowRDE("Couldn't find tag '%s' in the XMP", tag.c_str());
+std::string MosDecoder::getXMPTag(std::string_view xmp, std::string_view tag) {
+  std::string::size_type start = xmp.find("<tiff:" + std::string(tag) + ">");
+  std::string::size_type end = xmp.find("</tiff:" + std::string(tag) + ">");
+  if (start == std::string::npos || end == std::string::npos || end <= start)
+    ThrowRDE("Couldn't find tag '%s' in the XMP", tag.data());
   int startlen = tag.size()+7;
-  return xmp.substr(start+startlen, end-start-startlen);
+  return std::string(xmp.substr(start + startlen, end - start - startlen));
 }
 
 RawImage MosDecoder::decodeRawInternal() {
@@ -101,16 +100,16 @@ RawImage MosDecoder::decodeRawInternal() {
 
   const TiffIFD *raw = nullptr;
 
-  if (mRootIFD->hasEntryRecursive(TILEOFFSETS)) {
-    raw = mRootIFD->getIFDWithTag(TILEOFFSETS);
-    off = raw->getEntry(TILEOFFSETS)->getU32();
+  if (mRootIFD->hasEntryRecursive(TiffTag::TILEOFFSETS)) {
+    raw = mRootIFD->getIFDWithTag(TiffTag::TILEOFFSETS);
+    off = raw->getEntry(TiffTag::TILEOFFSETS)->getU32();
   } else {
-    raw = mRootIFD->getIFDWithTag(CFAPATTERN);
-    off = raw->getEntry(STRIPOFFSETS)->getU32();
+    raw = mRootIFD->getIFDWithTag(TiffTag::CFAPATTERN);
+    off = raw->getEntry(TiffTag::STRIPOFFSETS)->getU32();
   }
 
-  uint32_t width = raw->getEntry(IMAGEWIDTH)->getU32();
-  uint32_t height = raw->getEntry(IMAGELENGTH)->getU32();
+  uint32_t width = raw->getEntry(TiffTag::IMAGEWIDTH)->getU32();
+  uint32_t height = raw->getEntry(TiffTag::IMAGELENGTH)->getU32();
 
   // FIXME: could be wrong. max "active pixels" - "80 MP"
   if (width == 0 || height == 0 || width > 10328 || height > 7760)
@@ -125,8 +124,8 @@ RawImage MosDecoder::decodeRawInternal() {
 
   UncompressedDecompressor u(bs, mRaw);
 
-  int compression = raw->getEntry(COMPRESSION)->getU32();
-  if (1 == compression) {
+  if (int compression = raw->getEntry(TiffTag::COMPRESSION)->getU32();
+      1 == compression) {
     const Endianness endianness =
         getTiffByteOrder(ByteStream(DataBuffer(mFile, Endianness::little)), 0);
 
@@ -134,8 +133,7 @@ RawImage MosDecoder::decodeRawInternal() {
       u.decodeRawUnpacked<16, Endianness::big>(width, height);
     else
       u.decodeRawUnpacked<16, Endianness::little>(width, height);
-  }
-  else if (99 == compression || 7 == compression) {
+  } else if (99 == compression || 7 == compression) {
     ThrowRDE("Leaf LJpeg not yet supported");
     // LJpegPlain l(mFile, mRaw);
     // l.startDecoder(off, mFile.getSize()-off, 0, 0);
@@ -153,8 +151,9 @@ void MosDecoder::decodeMetaDataInternal(const CameraMetaData* meta) {
   RawDecoder::setMetaData(meta, make, model, "", 0);
 
   // Fetch the white balance (see dcraw.c parse_mos for more metadata that can be gotten)
-  if (mRootIFD->hasEntryRecursive(LEAFMETADATA)) {
-    ByteStream bs = mRootIFD->getEntryRecursive(LEAFMETADATA)->getData();
+  if (mRootIFD->hasEntryRecursive(TiffTag::LEAFMETADATA)) {
+    ByteStream bs =
+        mRootIFD->getEntryRecursive(TiffTag::LEAFMETADATA)->getData();
 
     // We need at least a couple of bytes:
     // "NeutObj_neutrals" + 28 bytes binary + 4x uint as strings + 3x space + \0
