@@ -42,10 +42,11 @@ public:
   void checkSupportInternal(const CameraMetaData* meta) override;
   void decodeMetaDataInternal(const CameraMetaData* meta) override;
 
-protected:
+private:
   [[nodiscard]] int getDecoderVersion() const override { return 0; }
-  std::string make, model;
-  static std::string getXMPTag(const std::string& xmp, const std::string& tag);
+  std::string make;
+  std::string model;
+  static std::string getXMPTag(std::string_view xmp, std::string_view tag);
 };
 
 } // namespace rawspeed
