@@ -28,9 +28,7 @@ namespace rawspeed {
 
 class RawDecoderException : public RawspeedException {
 public:
-  explicit RAWSPEED_UNLIKELY_FUNCTION RAWSPEED_NOINLINE
-  RawDecoderException(const char* msg)
-      : RawspeedException(msg) {}
+  using RawspeedException::RawspeedException;
 };
 
 #define ThrowRDE(...)                                                          \
