@@ -43,7 +43,7 @@ public:
   struct FujiHeader {
     FujiHeader() = default;
 
-    explicit FujiHeader(ByteStream* input_);
+    explicit FujiHeader(ByteStream& input_);
     explicit __attribute__((pure)) operator bool() const; // validity check
 
     uint16_t signature;
@@ -70,6 +70,12 @@ public:
     // the compressed data of this strip
     const ByteStream bs;
 
+    FujiStrip() = delete;
+    FujiStrip(const FujiStrip&) = default;
+    FujiStrip(FujiStrip&&) = default;
+    FujiStrip& operator=(const FujiStrip&) noexcept = delete;
+    FujiStrip& operator=(FujiStrip&&) noexcept = delete;
+
     FujiStrip(const FujiHeader& h_, int block, ByteStream bs_)
         : h(h_), n(block), bs(std::move(bs_)) {
       assert(n >= 0 && n < h.blocks_in_row);
@@ -79,10 +85,10 @@ public:
     static int lineHeight() { return 6; }
 
     // how many vertical lines does this block encode?
-    int height() const { return h.total_lines; }
+    [[nodiscard]] int height() const { return h.total_lines; }
 
     // how many horizontal pixels does this block encode?
-    int width() const {
+    [[nodiscard]] int width() const {
       // if this is not the last block, we are good.
       if ((n + 1) != h.blocks_in_row)
         return h.block_size;
@@ -94,14 +100,14 @@ public:
     }
 
     // where vertically does this block start?
-    int offsetY(int line = 0) const {
+    [[nodiscard]] int offsetY(int line = 0) const {
       (void)height(); // A note for NDEBUG builds that *this is used.
       assert(line >= 0 && line < height());
       return lineHeight() * line;
     }
 
     // where horizontally does this block start?
-    int offsetX() const { return h.block_size * n; }
+    [[nodiscard]] int offsetX() const { return h.block_size * n; }
   };
 
   FujiDecompressor(const RawImage& img, ByteStream input);
@@ -110,7 +116,7 @@ public:
 
   void decompress() const;
 
-protected:
+private:
   struct fuji_compressed_params {
     fuji_compressed_params() = default;
 
@@ -170,7 +176,6 @@ protected:
     std::array<uint16_t*, ltotal> linebuf;
   };
 
-private:
   ByteStream input;
 
   std::array<std::array<CFAColor, 6>, 6> CFA;
@@ -189,7 +194,7 @@ private:
   void copy_line_to_bayer(fuji_compressed_block* info, const FujiStrip& strip,
                           int cur_line) const;
 
-  static inline void fuji_zerobits(BitPumpMSB* pump, int* count);
+  static inline void fuji_zerobits(BitPumpMSB& pump, int* count);
   static int bitDiff(int value1, int value2);
 
   template <typename T1, typename T2>
@@ -203,13 +208,13 @@ private:
 
   static void fuji_decode_interpolation_even(int line_width, uint16_t* line_buf,
                                              int* pos);
-  static void fuji_extend_generic(std::array<uint16_t*, ltotal> linebuf,
+  static void fuji_extend_generic(const std::array<uint16_t*, ltotal>& linebuf,
                                   int line_width, int start, int end);
-  static void fuji_extend_red(std::array<uint16_t*, ltotal> linebuf,
+  static void fuji_extend_red(const std::array<uint16_t*, ltotal>& linebuf,
                               int line_width);
-  static void fuji_extend_green(std::array<uint16_t*, ltotal> linebuf,
+  static void fuji_extend_green(const std::array<uint16_t*, ltotal>& linebuf,
                                 int line_width);
-  static void fuji_extend_blue(std::array<uint16_t*, ltotal> linebuf,
+  static void fuji_extend_blue(const std::array<uint16_t*, ltotal>& linebuf,
                                int line_width);
   void xtrans_decode_block(fuji_compressed_block* info, int cur_line) const;
   void fuji_bayer_decode_block(fuji_compressed_block* info, int cur_line) const;
