@@ -36,13 +36,11 @@
 
 namespace rawspeed {
 
-constexpr int KodakDecompressor::segment_size;
-
 KodakDecompressor::KodakDecompressor(const RawImage& img, ByteStream bs,
                                      int bps_, bool uncorrectedRawValues_)
     : mRaw(img), input(std::move(bs)), bps(bps_),
       uncorrectedRawValues(uncorrectedRawValues_) {
-  if (mRaw->getCpp() != 1 || mRaw->getDataType() != TYPE_USHORT16 ||
+  if (mRaw->getCpp() != 1 || mRaw->getDataType() != RawImageType::UINT16 ||
       mRaw->getBpp() != sizeof(uint16_t))
     ThrowRDE("Unexpected component count / data type");
 
@@ -56,7 +54,7 @@ KodakDecompressor::KodakDecompressor(const RawImage& img, ByteStream bs,
 
   // Lower estimate: this decompressor requires *at least* half a byte
   // per output pixel
-  input.check(mRaw->dim.area() / 2ULL);
+  (void)input.check(mRaw->dim.area() / 2ULL);
 }
 
 KodakDecompressor::segment
