@@ -41,7 +41,7 @@ SamsungV0Decompressor::SamsungV0Decompressor(const RawImage& image,
                                              const ByteStream& bso,
                                              const ByteStream& bsr)
     : AbstractSamsungDecompressor(image) {
-  if (mRaw->getCpp() != 1 || mRaw->getDataType() != TYPE_USHORT16 ||
+  if (mRaw->getCpp() != 1 || mRaw->getDataType() != RawImageType::UINT16 ||
       mRaw->getBpp() != sizeof(uint16_t))
     ThrowRDE("Unexpected component count / data type");
 
