@@ -214,6 +214,11 @@ public:
   }
 };
 
+// WARNING: both buffers must belong to the same allocation, else this is UB!
+inline bool operator<(const Buffer& lhs, const Buffer& rhs) {
+  return std::pair(lhs.begin(), lhs.end()) < std::pair(rhs.begin(), rhs.end());
+}
+
 /*
  * DataBuffer is a simple extension to Buffer. It knows about the byte order
  * of its contents and can therefore provide save access to larger than
