@@ -149,7 +149,7 @@ const Camera* CameraMetaData::addCamera(std::unique_ptr<Camera> cam) {
 void CameraMetaData::disableMake(std::string_view make) const {
   for (const auto& cam : cameras) {
     if (cam.second->make == make)
-      cam.second->supported = false;
+      cam.second->supportStatus = Camera::SupportStatus::Unsupported;
   }
 }
 
@@ -157,7 +157,7 @@ void CameraMetaData::disableCamera(std::string_view make,
                                    std::string_view model) const {
   for (const auto& cam : cameras) {
     if (cam.second->make == make && cam.second->model == model)
-      cam.second->supported = false;
+      cam.second->supportStatus = Camera::SupportStatus::Unsupported;
   }
 }
 
