@@ -30,9 +30,7 @@ namespace rawspeed {
 
 class CiffParserException final : public RawParserException {
 public:
-  explicit RAWSPEED_UNLIKELY_FUNCTION RAWSPEED_NOINLINE
-  CiffParserException(const char* msg)
-      : RawParserException(msg) {}
+  using RawParserException::RawParserException;
 };
 
 #define ThrowCPE(...)                                                          \
