@@ -28,9 +28,7 @@ namespace rawspeed {
 
 class FiffParserException final : public RawParserException {
 public:
-  explicit RAWSPEED_UNLIKELY_FUNCTION RAWSPEED_NOINLINE
-  FiffParserException(const char* msg)
-      : RawParserException(msg) {}
+  using RawParserException::RawParserException;
 };
 
 #define ThrowFPE(...)                                                          \
