@@ -35,7 +35,7 @@ class CameraMetaData;
 
 class TiffParser final : public RawParser {
 public:
-  explicit TiffParser(const Buffer* file);
+  explicit TiffParser(const Buffer& file);
 
   std::unique_ptr<RawDecoder>
   getDecoder(const CameraMetaData* meta = nullptr) override;
@@ -50,10 +50,10 @@ public:
 
   template <class Decoder>
   static std::unique_ptr<RawDecoder> constructor(TiffRootIFDOwner&& root,
-                                                 const Buffer* data);
-  using checker_t = bool (*)(const TiffRootIFD* root, const Buffer* data);
+                                                 const Buffer& data);
+  using checker_t = bool (*)(const TiffRootIFD* root, const Buffer& data);
   using constructor_t = std::unique_ptr<RawDecoder> (*)(TiffRootIFDOwner&& root,
-                                                        const Buffer* data);
+                                                        const Buffer& data);
   static const std::array<std::pair<checker_t, constructor_t>, 16> Map;
 };
 
