@@ -37,14 +37,14 @@ class CiffIFD; // IWYU pragma: keep
 /*
  * Tag data type information.
  */
-enum CiffDataType {
-	CIFF_BYTE  = 0x0000,	/* 8-bit unsigned integer */
-	CIFF_ASCII = 0x0800,	/* 8-bit bytes w/ last byte null */
-	CIFF_SHORT = 0x1000,	/* 16-bit unsigned integer */
-	CIFF_LONG  = 0x1800,	/* 32-bit unsigned integer */
-	CIFF_MIX   = 0x2000,	/* 32-bit unsigned integer */
-	CIFF_SUB1  = 0x2800,	/* 32-bit unsigned integer */
-	CIFF_SUB2  = 0x3000,	/* 32-bit unsigned integer */
+enum class CiffDataType {
+  BYTE = 0x0000,  /* 8-bit unsigned integer */
+  ASCII = 0x0800, /* 8-bit bytes w/ last byte null */
+  SHORT = 0x1000, /* 16-bit unsigned integer */
+  LONG = 0x1800,  /* 32-bit unsigned integer */
+  MIX = 0x2000,   /* 32-bit unsigned integer */
+  SUB1 = 0x2800,  /* 32-bit unsigned integer */
+  SUB2 = 0x3000,  /* 32-bit unsigned integer */
 
 };
 
