@@ -31,23 +31,23 @@ enum
 };
 
 /* drag & drop for internal image ids */
-static const GtkTargetEntry target_list_internal[] = { { "image-id", 0, DND_TARGET_IMGID } };
+static const GtkTargetEntry target_list_internal[] = { { "image-id", GTK_TARGET_SAME_APP, DND_TARGET_IMGID } };
 static const guint n_targets_internal = G_N_ELEMENTS(target_list_internal);
 
 /* drag & drop for global uris */
-static const GtkTargetEntry target_list_external[] = { { "text/uri-list", 0, DND_TARGET_URI } };
+static const GtkTargetEntry target_list_external[] = { { "text/uri-list", GTK_TARGET_OTHER_APP, DND_TARGET_URI } };
 static const guint n_targets_external = G_N_ELEMENTS(target_list_external);
 
 /* drag & drop for both internal image ids and global uris */
 static const GtkTargetEntry target_list_all[]
-    = { { "image-id", 0, DND_TARGET_IMGID }, { "text/uri-list", 0, DND_TARGET_URI } };
+    = { { "image-id", GTK_TARGET_SAME_APP, DND_TARGET_IMGID }, { "text/uri-list", GTK_TARGET_OTHER_APP, DND_TARGET_URI } };
 static const guint n_targets_all = G_N_ELEMENTS(target_list_all);
 
 static const GtkTargetEntry target_list_tags[] = { { "tags-dnd", GTK_TARGET_SAME_WIDGET, DND_TARGET_TAG } };
 static const guint n_targets_tags = G_N_ELEMENTS(target_list_tags);
 
 static const GtkTargetEntry target_list_tags_dest[]
-    = { { "image-id", 0, DND_TARGET_IMGID }, { "tags-dnd", GTK_TARGET_SAME_WIDGET, DND_TARGET_TAG } };
+    = { { "image-id", GTK_TARGET_SAME_APP, DND_TARGET_IMGID }, { "tags-dnd", GTK_TARGET_SAME_WIDGET, DND_TARGET_TAG } };
 static const guint n_targets_tags_dest = G_N_ELEMENTS(target_list_tags_dest);
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
