@@ -176,6 +176,7 @@ const dt_gtkentry_completion_spec *dt_gtkentry_get_default_path_compl_list()
           { "VERSION", N_("$(VERSION) - duplicate version") },
           { "VERSION_IF_MULTI", N_("$(VERSION_IF_MULTI) - same as $(VERSION) but null string if only one version exists") },
           { "VERSION_NAME", N_("$(VERSION_NAME) - version name from metadata") },
+          { "JOBCODE", N_("$(JOBCODE) - job code for import") },
           { "SEQUENCE", N_("$(SEQUENCE) - sequence number") },
           { "MAX_WIDTH", N_("$(MAX_WIDTH) - maximum image export width") },
           { "MAX_HEIGHT", N_("$(MAX_HEIGHT) - maximum image export height") },
@@ -208,22 +209,27 @@ const dt_gtkentry_completion_spec *dt_gtkentry_get_default_path_compl_list()
           { "LONGITUDE", N_("$(LONGITUDE) - longitude") },
           { "LATITUDE", N_("$(LATITUDE) - latitude") },
           { "ELEVATION", N_("$(ELEVATION) - elevation") },
-          { "STARS", N_("$(STARS) - star rating") },
-          { "LABELS", N_("$(LABELS) - colorlabels") },
+          { "STARS", N_("$(STARS) - star rating as number (-1 for rejected)") },
+          { "RATING_ICONS", N_("$(RATING_ICONS) - star/reject rating in icon form") },
+          { "LABELS", N_("$(LABELS) - color labels as text") },
+          { "LABELS_ICONS", N_("$(LABELS_ICONS) - color labels as icons") },
           { "MAKER", N_("$(MAKER) - camera maker") },
           { "MODEL", N_("$(MODEL) - camera model") },
           { "LENS", N_("$(LENS) - lens") },
+          { "ID", N_("$(ID) - image ID") },
           { "TITLE", N_("$(TITLE) - title from metadata") },
           { "DESCRIPTION", N_("$(DESCRIPTION) - description from metadata") },
           { "CREATOR", N_("$(CREATOR) - creator from metadata") },
           { "PUBLISHER", N_("$(PUBLISHER) - publisher from metadata") },
           { "RIGHTS", N_("$(RIGHTS) - rights from metadata") },
+          { "USERNAME", N_("$(USERNAME) - login name") },
           { "PICTURES_FOLDER", N_("$(PICTURES_FOLDER) - pictures folder") },
           { "HOME", N_("$(HOME) - home folder") },
           { "DESKTOP", N_("$(DESKTOP) - desktop folder") },
-          { "OPENCL", N_("$(OPENCL_ACTIVATED) - whether OpenCL is activated") },
+          { "OPENCL_ACTIVATED", N_("$(OPENCL_ACTIVATED) - whether OpenCL is activated") },
           { "CATEGORY", N_("$(CATEGORY0(category)) - subtag of level 0 in hierarchical tags") },
           { "TAGS", N_("$(TAGS) - tags as set in metadata settings") },
+          { "DARKTABLE_VERSION", N_("$(DARKTABLE_VERSION) - current darktable version") },
           { NULL, NULL } };
 
   return default_path_compl_list;
