@@ -19,6 +19,7 @@
 #pragma once
 
 #include "develop/imageop.h"
+#include "views/view.h"
 
 typedef void (*dt_guides_draw_callback)(cairo_t *cr, const float x, const float y,
                                         const float w, const float h,
@@ -41,6 +42,25 @@ void dt_guides_cleanup(GList *guides);
 
 void dt_guides_add_guide(const char *name, dt_guides_draw_callback draw, dt_guides_widget_callback widget, void *user_data, GDestroyNotify free);
 
+// create the popover to setup the guides
+GtkWidget *dt_guides_popover(dt_view_t *self, GtkWidget *button);
+void dt_guides_update_popover_values();
+
+// draw the guide on screen
+void dt_guides_draw(cairo_t *cr, const float left, const float top, const float width, const float height,
+                    const float zoom_scale);
+
+// routines for the module toolbar button
+void dt_guides_update_button_state();
+void dt_guides_button_toggled(gboolean active);
+
+// show the menuitem for modules
+void dt_guides_add_module_menuitem(void *menu, struct dt_iop_module_t *module);
+
+// show the line in UI modules
+void dt_guides_init_module_widget(GtkWidget *box, struct dt_iop_module_t *module);
+void dt_guides_update_module_widget(struct dt_iop_module_t *module);
+
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
 // kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
