@@ -20,14 +20,15 @@ typedef struct dt_import_metadata_t
 {
   GtkWidget *box;   // widget where to put the metadata widgets
   GtkWidget *apply_metadata;
-  GtkWidget *presets;
-  GtkWidget *metadata[DT_METADATA_NUMBER];
-  GtkWidget *imported[DT_METADATA_NUMBER];
-  GtkWidget *tags;
+  GtkWidget *grid;
+  GtkListStore *m_model;
+  GtkListStore *t_model;
 } dt_import_metadata_t;
 
-void dt_import_metadata_dialog_new(dt_import_metadata_t *metadata);
-void dt_import_metadata_evaluate(dt_import_metadata_t *metadata);
+void dt_import_metadata_init(dt_import_metadata_t *metadata);
+void dt_import_metadata_update(dt_import_metadata_t *metadata);
+void dt_import_metadata_cleanup(dt_import_metadata_t *metadata);
+void dt_import_metadata_reset(dt_import_metadata_t *metadata);
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
