@@ -112,7 +112,8 @@ static void write_icc_profile(j_compress_ptr cinfo, const JOCTET *icc_data_ptr,
   {
     /* length of profile to put in this marker */
     unsigned int length = icc_data_len;
-    if(length > MAX_DATA_BYTES_IN_MARKER) length = MAX_DATA_BYTES_IN_MARKER;
+    if(length > MAX_DATA_BYTES_IN_MARKER)
+      length = MAX_DATA_BYTES_IN_MARKER;
     icc_data_len -= length;
 
     /* Write the JPEG marker header (APP2 code and marker length) */
@@ -213,11 +214,7 @@ read_icc_profile (j_decompress_ptr cinfo,
                   JOCTET **icc_data_ptr,
                   unsigned int *icc_data_len)
 {
-  jpeg_saved_marker_ptr marker;
   int num_markers = 0;
-  int seq_no;
-  JOCTET *icc_data;
-  unsigned int total_length;
 #define MAX_SEQ_NO 255 /* sufficient since marker numbers are bytes */
   char marker_present[MAX_SEQ_NO+1];    /* 1 if marker found */
   unsigned int data_length[MAX_SEQ_NO+1]; /* size of profile data in marker */
@@ -230,63 +227,60 @@ read_icc_profile (j_decompress_ptr cinfo,
    * any ICC markers and verifies the consistency of the marker numbering.
    */
 
-  for (seq_no = 1; seq_no <= MAX_SEQ_NO; seq_no++)
+  for(int seq_no = 1; seq_no <= MAX_SEQ_NO; seq_no++)
     marker_present[seq_no] = 0;
 
-  for (marker = cinfo->marker_list; marker != NULL; marker = marker->next)
+  for(jpeg_saved_marker_ptr marker = cinfo->marker_list; marker != NULL; marker = marker->next)
   {
-    if (marker_is_icc(marker))
+    if(marker_is_icc(marker))
     {
-      if (num_markers == 0)
+      if(num_markers == 0)
         num_markers = GETJOCTET(marker->data[13]);
-      else if (num_markers != GETJOCTET(marker->data[13]))
+      else if(num_markers != GETJOCTET(marker->data[13]))
         return FALSE;   /* inconsistent num_markers fields */
-      seq_no = GETJOCTET(marker->data[12]);
-      if (seq_no <= 0 || seq_no > num_markers)
+      const int seq_no = GETJOCTET(marker->data[12]);
+      if(seq_no <= 0 || seq_no > num_markers)
         return FALSE;   /* bogus sequence number */
-      if (marker_present[seq_no])
+      if(marker_present[seq_no])
         return FALSE;   /* duplicate sequence numbers */
       marker_present[seq_no] = 1;
       data_length[seq_no] = marker->data_length - ICC_OVERHEAD_LEN;
     }
   }
 
-  if (num_markers == 0)
+  if(num_markers == 0)
     return FALSE;
 
   /* Check for missing markers, count total space needed,
    * compute offset of each marker's part of the data.
    */
 
-  total_length = 0;
-  for (seq_no = 1; seq_no <= num_markers; seq_no++)
+  unsigned int total_length = 0;
+  for(int seq_no = 1; seq_no <= num_markers; seq_no++)
   {
-    if (marker_present[seq_no] == 0)
+    if(marker_present[seq_no] == 0)
       return FALSE;   /* missing sequence number */
     data_offset[seq_no] = total_length;
     total_length += data_length[seq_no];
   }
 
-  if (total_length <= 0)
+  if(total_length <= 0)
     return FALSE;   /* found only empty markers? */
 
   /* Allocate space for assembled data */
-  icc_data = (JOCTET *) calloc(total_length, sizeof(JOCTET));
-  if (icc_data == NULL)
+  JOCTET *icc_data = (JOCTET *)calloc(total_length, sizeof(JOCTET));
+  if(icc_data == NULL)
     return FALSE;   /* oops, out of memory */
 
   /* and fill it in */
-  for (marker = cinfo->marker_list; marker != NULL; marker = marker->next)
+  for(jpeg_saved_marker_ptr marker = cinfo->marker_list; marker != NULL; marker = marker->next)
   {
-    if (marker_is_icc(marker))
+    if(marker_is_icc(marker))
     {
-      JOCTET FAR *src_ptr;
-      JOCTET *dst_ptr;
-      unsigned int length;
-      seq_no = GETJOCTET(marker->data[12]);
-      dst_ptr = icc_data + data_offset[seq_no];
-      src_ptr = marker->data + ICC_OVERHEAD_LEN;
-      length = data_length[seq_no];
+      const int seq_no = GETJOCTET(marker->data[12]);
+      JOCTET *dst_ptr = icc_data + data_offset[seq_no];
+      JOCTET FAR *src_ptr = marker->data + ICC_OVERHEAD_LEN;
+      unsigned int length = data_length[seq_no];
       while (length--)
       {
         *dst_ptr++ = *src_ptr++;
