@@ -104,20 +104,16 @@ static void button_clicked(GtkWidget *widget, dt_imageio_module_storage_t *self)
 {
   gallery_t *d = (gallery_t *)self->gui_data;
   GtkWidget *win = dt_ui_main_window(darktable.gui->ui);
-  GtkWidget *filechooser = gtk_file_chooser_dialog_new(
-      _("select directory"), GTK_WINDOW(win), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, _("_cancel"),
-      GTK_RESPONSE_CANCEL, _("_select as output destination"), GTK_RESPONSE_ACCEPT, (char *)NULL);
-#ifdef GDK_WINDOWING_QUARTZ
-  dt_osx_disallow_fullscreen(filechooser);
-#endif
+  GtkFileChooserNative *filechooser = gtk_file_chooser_native_new(
+         _("select directory"), GTK_WINDOW(win), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+         _("_select as output destination"), _("_cancel"));
 
-  gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(filechooser), FALSE);
   gchar *old = g_strdup(gtk_entry_get_text(d->entry));
   char *c = g_strstr_len(old, -1, "$");
   if(c) *c = '\0';
   gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(filechooser), old);
   g_free(old);
-  if(gtk_dialog_run(GTK_DIALOG(filechooser)) == GTK_RESPONSE_ACCEPT)
+  if(gtk_native_dialog_run(GTK_NATIVE_DIALOG(filechooser)) == GTK_RESPONSE_ACCEPT)
   {
     gchar *dir = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(filechooser));
     char *composed = g_build_filename(dir, "$(FILE_NAME)", NULL);
@@ -132,7 +128,7 @@ static void button_clicked(GtkWidget *widget, dt_imageio_module_storage_t *self)
     g_free(composed);
     g_free(escaped);
   }
-  gtk_widget_destroy(filechooser);
+  g_object_unref(filechooser);
 }
 
 static void entry_changed_callback(GtkEntry *entry, gpointer user_data)
@@ -157,14 +153,12 @@ void gui_init(dt_imageio_module_storage_t *self)
   widget = gtk_entry_new();
   gtk_entry_set_width_chars(GTK_ENTRY(widget), 0);
   gtk_box_pack_start(GTK_BOX(hbox), widget, TRUE, TRUE, 0);
-  gchar *dir = dt_conf_get_string("plugins/imageio/storage/gallery/file_directory");
+  const char *dir = dt_conf_get_string_const("plugins/imageio/storage/gallery/file_directory");
   if(dir)
   {
     gtk_entry_set_text(GTK_ENTRY(widget), dir);
-    g_free(dir);
   }
   d->entry = GTK_ENTRY(widget);
-  dt_gui_key_accel_block_on_focus_connect(GTK_WIDGET(d->entry));
 
   dt_gtkentry_setup_completion(GTK_ENTRY(widget), dt_gtkentry_get_default_path_compl_list());
 
@@ -188,22 +182,17 @@ void gui_init(dt_imageio_module_storage_t *self)
   d->title_entry = GTK_ENTRY(gtk_entry_new());
   gtk_entry_set_width_chars(d->title_entry, 0);
   gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(d->title_entry), TRUE, TRUE, 0);
-  dt_gui_key_accel_block_on_focus_connect(GTK_WIDGET(d->title_entry));
   gtk_widget_set_tooltip_text(GTK_WIDGET(d->title_entry), _("enter the title of the website"));
-  dir = dt_conf_get_string("plugins/imageio/storage/gallery/title");
+  dir = dt_conf_get_string_const("plugins/imageio/storage/gallery/title");
   if(dir)
   {
     gtk_entry_set_text(GTK_ENTRY(d->title_entry), dir);
-    g_free(dir);
   }
   g_signal_connect(G_OBJECT(d->title_entry), "changed", G_CALLBACK(title_changed_callback), self);
 }
 
 void gui_cleanup(dt_imageio_module_storage_t *self)
 {
-  gallery_t *d = (gallery_t *)self->gui_data;
-  dt_gui_key_accel_block_on_focus_disconnect(GTK_WIDGET(d->entry));
-  dt_gui_key_accel_block_on_focus_disconnect(GTK_WIDGET(d->title_entry));
   free(self->gui_data);
 }
 
@@ -236,6 +225,10 @@ int store(dt_imageio_module_storage_t *self, dt_imageio_module_data_t *sdata, co
 
   char tmp_dir[PATH_MAX] = { 0 };
 
+  // set variable values to expand them afterwards in darktable variables
+  dt_variables_set_max_width_height(d->vp, fdata->max_width, fdata->max_height);
+  dt_variables_set_upscale(d->vp, upscale);
+
   d->vp->filename = dirname;
   d->vp->jobcode = "export";
   d->vp->imgid = imgid;
@@ -569,13 +562,11 @@ void *get_params(dt_imageio_module_storage_t *self)
   d->l = NULL;
   dt_variables_params_init(&d->vp);
 
-  char *text = dt_conf_get_string("plugins/imageio/storage/gallery/file_directory");
+  const char *text = dt_conf_get_string_const("plugins/imageio/storage/gallery/file_directory");
   g_strlcpy(d->filename, text, sizeof(d->filename));
-  g_free(text);
 
-  text = dt_conf_get_string("plugins/imageio/storage/gallery/title");
+  text = dt_conf_get_string_const("plugins/imageio/storage/gallery/title");
   g_strlcpy(d->title, text, sizeof(d->title));
-  g_free(text);
 
   return d;
 }
