@@ -308,7 +308,7 @@ static ntuple_list new_ntuple_list(unsigned int dim)
   n_tuple->dim = dim;
 
   /* get memory for tuples */
-  n_tuple->values = (double *) malloc( dim*n_tuple->max_size * sizeof(double) );
+  n_tuple->values = (double *) malloc(sizeof(double) * dim * n_tuple->max_size);
   if( n_tuple->values == NULL ) error("not enough memory.");
 
   return n_tuple;
@@ -328,7 +328,7 @@ static void enlarge_ntuple_list(ntuple_list n_tuple)
 
   /* realloc memory */
   n_tuple->values = (double *) realloc( (void *) n_tuple->values,
-                      n_tuple->dim * n_tuple->max_size * sizeof(double) );
+                      sizeof(double) * n_tuple->dim * n_tuple->max_size );
   if( n_tuple->values == NULL ) error("not enough memory.");
 }
 
