@@ -62,7 +62,7 @@ typedef struct dt_iop_basicadj_gui_data_t
   int call_auto_exposure;                       // should we calculate exposure automatically?
   int draw_selected_region;                     // are we drawing the selected region?
   float posx_from, posx_to, posy_from, posy_to; // coordinates of the area
-  float box_cood[4];                            // normalized coordinates
+  dt_boundingbox_t box_cood;                    // normalized coordinates
   int button_down;                              // user pressed the mouse button?
 
   GtkWidget *bt_auto_levels;
@@ -1211,7 +1211,7 @@ static void _get_selected_area(struct dt_iop_module_t *self, dt_dev_pixelpipe_io
   {
     const int width = roi_in->width;
     const int height = roi_in->height;
-    float box_cood[4] = { g->box_cood[0], g->box_cood[1], g->box_cood[2], g->box_cood[3] };
+    dt_boundingbox_t box_cood = { g->box_cood[0], g->box_cood[1], g->box_cood[2], g->box_cood[3] };
 
     box_cood[0] *= piece->pipe->iwidth;
     box_cood[1] *= piece->pipe->iheight;
