@@ -156,7 +156,7 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
   const float scale = fmaxf(piece->iscale / roi_in->scale, 1.f);
   const float noise = data->noise / scale;
 
-  float RGBmax[4], RGBmin[4];
+  dt_aligned_pixel_t RGBmax, RGBmin;
   for(int k = 0; k < 4; k++)
   {
     RGBmax[k] = INFINITY;
@@ -186,9 +186,8 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
     const size_t pixels_y = height / (2 * pixel_radius);
 
 #ifdef _OPENMP
-#pragma omp parallel for simd default(none) \
+#pragma omp parallel for default(none) \
   dt_omp_firstprivate(width, height, ch, input, output, pixel_radius, pixels_y, pixels_x) \
-  aligned(input, output:64) \
   schedule(simd:static) collapse(2)
 #endif
     for(size_t j = 0; j < pixels_y + 1; j++)
@@ -208,11 +207,12 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
         const point_t box[5] = { tl, { br.x, tl.y }, cc, { tl.x, br.y }, br };
 
         // find the average color over the big pixel
-        float DT_ALIGNED_PIXEL RGB[4] = { 0.f };
+        dt_aligned_pixel_t RGB = { 0.f };
         for(size_t k = 0; k < 5; k++)
         {
           const float *const restrict pix_in = __builtin_assume_aligned(input + (width * box[k].y + box[k].x) * 4, 16);
-          for(size_t c = 0; c < 4; c++) RGB[c] += pix_in[c] / 5.f;
+          for_four_channels(c)
+            RGB[c] += pix_in[c] / 5.f;
         }
 
         // paint the big pixel with solid color == average
@@ -220,7 +220,8 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
           for(size_t ii = tl.x; ii < br.x; ii++)
           {
             float *const restrict pix_out = __builtin_assume_aligned(output + (jj * width + ii) * 4, 16);
-            for(size_t c = 0; c < 4; c++) pix_out[c] = RGB[c];
+            for_four_channels(c)
+              pix_out[c] = RGB[c];
           }
       }
 
