@@ -195,9 +195,9 @@ typedef struct dt_iop_colorreconstruct_bilateral_t
 
 static inline float hue_conversion(const float HSL_Hue)
 {
-  float DT_ALIGNED_PIXEL rgb[4] = { 0 };
-  float DT_ALIGNED_PIXEL XYZ[4] = { 0 };
-  float DT_ALIGNED_PIXEL Lab[4] = { 0 };
+  dt_aligned_pixel_t rgb = { 0 };
+  dt_aligned_pixel_t XYZ = { 0 };
+  dt_aligned_pixel_t Lab = { 0 };
 
   hsl2rgb(rgb, HSL_Hue, 1.0f, 0.5f);
 
@@ -603,7 +603,7 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
   const float sigma_s = fmax(data->spatial, 1.0f) / scale;
   const float hue = hue_conversion(data->hue); // convert to LCH hue which better fits to Lab colorspace
 
-  const float params[4] = { hue, M_PI*M_PI/8, 0.0f, 0.0f };
+  const dt_aligned_pixel_t params = { hue, M_PI*M_PI/8, 0.0f, 0.0f };
 
   dt_iop_colorreconstruct_bilateral_t *b;
   dt_iop_colorreconstruct_bilateral_frozen_t *can = NULL;
@@ -1288,6 +1288,8 @@ void gui_init(struct dt_iop_module_t *self)
   dt_bauhaus_slider_set_step(g->range, 0.1f);
   g->precedence = dt_bauhaus_combobox_from_params(self, N_("precedence"));
   g->hue = dt_bauhaus_slider_from_params(self, N_("hue"));
+  dt_bauhaus_slider_set_factor(g->hue, 360.0f);
+  dt_bauhaus_slider_set_format(g->hue, "%.2f°");
   dt_bauhaus_slider_set_feedback(g->hue, 0);
   dt_bauhaus_slider_set_stop(g->hue, 0.0f,   1.0f, 0.0f, 0.0f);
   dt_bauhaus_slider_set_stop(g->hue, 0.166f, 1.0f, 1.0f, 0.0f);
