@@ -179,6 +179,9 @@ static void _commit_box(dt_iop_module_t *self, dt_iop_crop_gui_data_t *g, dt_iop
 {
   if(darktable.gui->reset) return;
   g->cropping = 0;
+  const dt_boundingbox_t old = { p->cx, p->cy, p->cw, p->ch };
+  const float eps = 1e-6f; // threshold to avoid rounding errors
+
   if(!self->enabled)
   {
     // first time crop, if any data is stored in p, it's obsolete:
@@ -206,7 +209,9 @@ static void _commit_box(dt_iop_module_t *self, dt_iop_crop_gui_data_t *g, dt_iop
       p->ch = CLAMPF(p->ch, 0.1f, 1.0f);
     }
   }
-  dt_dev_add_history_item(darktable.develop, self, TRUE);
+  const gboolean changed = fabs(p->cx - old[0]) > eps || fabs(p->cy - old[1]) > eps || fabs(p->cw - old[2]) > eps || fabs(p->ch - old[3]) > eps;
+  // fprintf(stderr, "[crop commit box] %i:  %e %e %e %e\n", changed, p->cx - old[0], p->cy - old[1], p->cw - old[2], p->ch - old[3]);
+  if(changed) dt_dev_add_history_item(darktable.develop, self, TRUE);
 }
 
 static int _set_max_clip(struct dt_iop_module_t *self)
@@ -1580,7 +1585,7 @@ int mouse_moved(struct dt_iop_module_t *self, double x, double y, double pressur
       dt_control_change_cursor(GDK_BOTTOM_LEFT_CORNER);
     else if(grab == GRAB_NONE)
     {
-      dt_control_hinter_message(darktable.control, _("<b>commit</b>: double click"));
+      dt_control_hinter_message(darktable.control, "");
       dt_control_change_cursor(GDK_LEFT_PTR);
     }
     if(grab != GRAB_NONE)
@@ -1591,8 +1596,7 @@ int mouse_moved(struct dt_iop_module_t *self, double x, double y, double pressur
   {
     dt_control_change_cursor(GDK_FLEUR);
     g->cropping = 0;
-    dt_control_hinter_message(darktable.control, _("<b>move</b>: drag, <b>move vertically</b>: shift+drag, <b>move horizontally</b>: ctrl+drag\n"
-                                                   "<b>commit</b>: double click"));
+    dt_control_hinter_message(darktable.control, _("<b>move</b>: drag, <b>move vertically</b>: shift+drag, <b>move horizontally</b>: ctrl+drag"));
     dt_control_queue_redraw_center();
   }
   return 0;
