@@ -129,8 +129,8 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
   const float threshold = 0.01f;
 
   // scotopic white, blue saturated
-  float Lab_sw[3] = { 100.0f, 0, -d->blueness };
-  float XYZ_sw[3];
+  dt_aligned_pixel_t Lab_sw = { 100.0f, 0, -d->blueness };
+  dt_aligned_pixel_t XYZ_sw;
 
   dt_Lab_to_XYZ(Lab_sw, XYZ_sw);
 
@@ -144,7 +144,7 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
   {
     float *in = (float *)i + ch * k;
     float *out = (float *)o + ch * k;
-    float DT_ALIGNED_PIXEL XYZ[4], XYZ_s[4];
+    dt_aligned_pixel_t XYZ, XYZ_s;
     float V;
     float w;
 
@@ -197,8 +197,8 @@ int process_cl(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, cl_m
   const int height = roi_out->height;
 
   // scotopic white, blue saturated
-  float Lab_sw[3] = { 100.0f, 0.0f, -d->blueness };
-  float XYZ_sw[4];
+  dt_aligned_pixel_t Lab_sw = { 100.0f, 0.0f, -d->blueness };
+  dt_aligned_pixel_t XYZ_sw;
 
   dt_Lab_to_XYZ(Lab_sw, XYZ_sw);
 
@@ -832,12 +832,13 @@ void gui_init(struct dt_iop_module_t *self)
 
   const float aspect = dt_conf_get_int("plugins/darkroom/lowlight/aspect_percent") / 100.0;
   c->area = GTK_DRAWING_AREA(dtgtk_drawing_area_new_with_aspect_ratio(aspect));
-
+  g_object_set_data(G_OBJECT(c->area), "iop-instance", self);
+  dt_action_define_iop(self, NULL, N_("graph"), GTK_WIDGET(c->area), NULL);
   gtk_box_pack_start(GTK_BOX(self->widget), GTK_WIDGET(c->area), FALSE, FALSE, 0);
 
-  gtk_widget_add_events(GTK_WIDGET(c->area), GDK_POINTER_MOTION_MASK
-                                             | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
-                                             | GDK_LEAVE_NOTIFY_MASK | darktable.gui->scroll_mask);
+  gtk_widget_add_events(GTK_WIDGET(c->area), GDK_POINTER_MOTION_MASK | darktable.gui->scroll_mask
+                                           | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
+                                           | GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
   g_signal_connect(G_OBJECT(c->area), "draw", G_CALLBACK(lowlight_draw), self);
   g_signal_connect(G_OBJECT(c->area), "button-press-event", G_CALLBACK(lowlight_button_press), self);
   g_signal_connect(G_OBJECT(c->area), "button-release-event", G_CALLBACK(lowlight_button_release), self);
