@@ -107,9 +107,9 @@ typedef struct dt_iop_negadoctor_params_t
 
 typedef struct dt_iop_negadoctor_data_t
 {
-  float DT_ALIGNED_PIXEL Dmin[4];         // color of film substrate
-  float DT_ALIGNED_PIXEL wb_high[4];      // white balance RGB coeffs / Dmax
-  float DT_ALIGNED_PIXEL offset[4];       // inversion offset
+  dt_aligned_pixel_t Dmin;                // color of film substrate
+  dt_aligned_pixel_t wb_high;             // white balance RGB coeffs / Dmax
+  dt_aligned_pixel_t offset;              // inversion offset
   float black;                            // display black level
   float gamma;                            // display gamma
   float soft_clip;                        // highlights roll-off
@@ -184,9 +184,9 @@ int legacy_params(dt_iop_module_t *self, const void *const old_params, const int
     typedef struct dt_iop_negadoctor_params_v1_t
     {
       dt_iop_negadoctor_filmstock_t film_stock;
-      float DT_ALIGNED_PIXEL Dmin[4];         // color of film substrate
-      float DT_ALIGNED_PIXEL wb_high[4];      // white balance RGB coeffs (illuminant)
-      float DT_ALIGNED_PIXEL wb_low[4];       // white balance RGB offsets (base light)
+      dt_aligned_pixel_t Dmin;                // color of film substrate
+      dt_aligned_pixel_t wb_high;             // white balance RGB coeffs (illuminant)
+      dt_aligned_pixel_t wb_low;              // white balance RGB offsets (base light)
       float D_max;                            // max density of film
       float offset;                           // inversion offset
       float black;                            // display black level
@@ -510,7 +510,7 @@ static void WB_low_picker_update(dt_iop_module_t *self)
   GdkRGBA color;
   color.alpha = 1.0f;
 
-  float WB_low_invert[3];
+  dt_aligned_pixel_t WB_low_invert;
   for(size_t c = 0; c < 3; ++c) WB_low_invert[c] = 2.0f - p->wb_low[c];
   const float WB_low_max = v_maxf(WB_low_invert);
   for(size_t c = 0; c < 3; ++c) WB_low_invert[c] /= WB_low_max;
@@ -533,10 +533,7 @@ static void WB_low_picker_callback(GtkColorButton *widget, dt_iop_module_t *self
   GdkRGBA c;
   gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(widget), &c);
 
-  float RGB[3];
-  RGB[0] = 2.0f - c.red;
-  RGB[1] = 2.0f - c.green;
-  RGB[2] = 2.0f - c.blue;
+  dt_aligned_pixel_t RGB = { 2.0f - c.red, 2.0f - c.green, 2.0f - c.blue };
 
   float RGB_min = v_minf(RGB);
   for(size_t k = 0; k < 3; k++) p->wb_low[k] = RGB[k] / RGB_min;
@@ -561,7 +558,7 @@ static void WB_high_picker_update(dt_iop_module_t *self)
   GdkRGBA color;
   color.alpha = 1.0f;
 
-  float WB_high_invert[3];
+  dt_aligned_pixel_t WB_high_invert;
   for(size_t c = 0; c < 3; ++c) WB_high_invert[c] = 2.0f - p->wb_high[c];
   const float WB_high_max = v_maxf(WB_high_invert);
   for(size_t c = 0; c < 3; ++c) WB_high_invert[c] /= WB_high_max;
@@ -584,11 +581,7 @@ static void WB_high_picker_callback(GtkColorButton *widget, dt_iop_module_t *sel
   GdkRGBA c;
   gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(widget), &c);
 
-  float RGB[3];
-  RGB[0] = 2.0f - c.red;
-  RGB[1] = 2.0f - c.green;
-  RGB[2] = 2.0f - c.blue;
-
+  dt_aligned_pixel_t RGB = { 2.0f - c.red, 2.0f - c.green, 2.0f - c.blue };
   float RGB_min = v_minf(RGB);
   for(size_t k = 0; k < 3; k++) p->wb_high[k] = RGB[k] / RGB_min;
 
@@ -633,7 +626,7 @@ static void apply_auto_Dmax(dt_iop_module_t *self)
   dt_iop_negadoctor_gui_data_t *g = (dt_iop_negadoctor_gui_data_t *)self->gui_data;
   dt_iop_negadoctor_params_t *p = (dt_iop_negadoctor_params_t *)self->params;
 
-  float RGB[3];
+  dt_aligned_pixel_t RGB;
   for(int c = 0; c < 3; c++)
   {
     RGB[c] = log10f(p->Dmin[c] / fmaxf(self->picked_color_min[c], THRESHOLD));
@@ -657,7 +650,7 @@ static void apply_auto_offset(dt_iop_module_t *self)
   dt_iop_negadoctor_gui_data_t *g = (dt_iop_negadoctor_gui_data_t *)self->gui_data;
   dt_iop_negadoctor_params_t *p = (dt_iop_negadoctor_params_t *)self->params;
 
-  float RGB[3];
+  dt_aligned_pixel_t RGB;
   for(int c = 0; c < 3; c++)
     RGB[c] = log10f(p->Dmin[c] / fmaxf(self->picked_color_max[c], THRESHOLD)) / p->D_max;
 
@@ -680,7 +673,7 @@ static void apply_auto_WB_low(dt_iop_module_t *self)
   dt_iop_negadoctor_gui_data_t *g = (dt_iop_negadoctor_gui_data_t *)self->gui_data;
   dt_iop_negadoctor_params_t *p = (dt_iop_negadoctor_params_t *)self->params;
 
-  float RGB_min[3];
+  dt_aligned_pixel_t RGB_min;
   for(int c = 0; c < 3; c++)
     RGB_min[c] = log10f(p->Dmin[c] / fmaxf(self->picked_color[c], THRESHOLD)) / p->D_max;
 
@@ -706,7 +699,7 @@ static void apply_auto_WB_high(dt_iop_module_t *self)
   dt_iop_negadoctor_gui_data_t *g = (dt_iop_negadoctor_gui_data_t *)self->gui_data;
   dt_iop_negadoctor_params_t *p = (dt_iop_negadoctor_params_t *)self->params;
 
-  float RGB_min[3];
+  dt_aligned_pixel_t RGB_min;
   for(int c = 0; c < 3; c++)
     RGB_min[c] = fabsf(-1.0f / (p->offset * p->wb_low[c] - log10f(p->Dmin[c] / fmaxf(self->picked_color[c], THRESHOLD)) / p->D_max));
 
@@ -732,7 +725,7 @@ static void apply_auto_black(dt_iop_module_t *self)
   dt_iop_negadoctor_gui_data_t *g = (dt_iop_negadoctor_gui_data_t *)self->gui_data;
   dt_iop_negadoctor_params_t *p = (dt_iop_negadoctor_params_t *)self->params;
 
-  float RGB[3];
+  dt_aligned_pixel_t RGB;
   for(int c = 0; c < 3; c++)
   {
     RGB[c] = -log10f(p->Dmin[c] / fmaxf(self->picked_color_max[c], THRESHOLD));
@@ -758,7 +751,7 @@ static void apply_auto_exposure(dt_iop_module_t *self)
   dt_iop_negadoctor_gui_data_t *g = (dt_iop_negadoctor_gui_data_t *)self->gui_data;
   dt_iop_negadoctor_params_t *p = (dt_iop_negadoctor_params_t *)self->params;
 
-  float RGB[3];
+  dt_aligned_pixel_t RGB;
   for(int c = 0; c < 3; c++)
   {
     RGB[c] = -log10f(p->Dmin[c] / fmaxf(self->picked_color_min[c], THRESHOLD));
@@ -804,10 +797,12 @@ void gui_init(dt_iop_module_t *self)
 {
   dt_iop_negadoctor_gui_data_t *g = IOP_GUI_ALLOC(negadoctor);
 
-  g->notebook = GTK_NOTEBOOK(gtk_notebook_new());
+  static dt_action_def_t notebook_def = { };
+  g->notebook = dt_ui_notebook_new(&notebook_def);
+  dt_action_define_iop(self, NULL, N_("page"), GTK_WIDGET(g->notebook), &notebook_def);
 
   // Page FILM PROPERTIES
-  GtkWidget *page1 = self->widget = dt_ui_notebook_page(g->notebook, _("film properties"), NULL);
+  GtkWidget *page1 = self->widget = dt_ui_notebook_page(g->notebook, N_("film properties"), NULL);
 
   // Dmin
 
@@ -878,7 +873,7 @@ void gui_init(dt_iop_module_t *self)
                                            "before the inversion, so blacks are neither clipped or too pale."));
 
   // Page CORRECTIONS
-  GtkWidget *page2 = self->widget = dt_ui_notebook_page(g->notebook, _("corrections"), NULL);
+  GtkWidget *page2 = self->widget = dt_ui_notebook_page(g->notebook, N_("corrections"), NULL);
 
   // WB shadows
   gtk_box_pack_start(GTK_BOX(page2), dt_ui_section_label_new(_("shadows color cast")), FALSE, FALSE, 0);
@@ -955,7 +950,7 @@ void gui_init(dt_iop_module_t *self)
                                               "recovering the global white balance in difficult cases."));
 
   // Page PRINT PROPERTIES
-  GtkWidget *page3 = self->widget = dt_ui_notebook_page(g->notebook, _("print properties"), NULL);
+  GtkWidget *page3 = self->widget = dt_ui_notebook_page(g->notebook, N_("print properties"), NULL);
 
   // print corrections
   gtk_box_pack_start(GTK_BOX(page3), dt_ui_section_label_new(_("virtual paper properties")), FALSE, FALSE, 0);
@@ -979,7 +974,7 @@ void gui_init(dt_iop_module_t *self)
   dt_bauhaus_slider_set_digits(g->soft_clip, 4);
   dt_bauhaus_slider_set_format(g->soft_clip, "%.2f %%");
   gtk_widget_set_tooltip_text(g->soft_clip, _("gradually compress specular highlights past this value\n"
-                                              "to avoid clipping while pushing the exposure for midtones.\n"
+                                              "to avoid clipping while pushing the exposure for mid-tones.\n"
                                               "this somewhat reproduces the behaviour of matte paper."));
 
   gtk_box_pack_start(GTK_BOX(page3), dt_ui_section_label_new(_("virtual print emulation")), FALSE, FALSE, 0);
@@ -1047,10 +1042,6 @@ void gui_update(dt_iop_module_t *const self)
 
   dt_iop_color_picker_reset(self, TRUE);
 
-  self->color_picker_box[0] = self->color_picker_box[1] = .10f;
-  self->color_picker_box[2] = self->color_picker_box[3] = .50f;
-  self->color_picker_point[0] = self->color_picker_point[1] = 0.5f;
-
   dt_bauhaus_combobox_set(g->film_stock, p->film_stock);
 
   // Dmin
