@@ -26,8 +26,9 @@
 #include "develop/imageop.h"
 #include "develop/imageop_gui.h"
 #include "dtgtk/drawingarea.h"
-#include "gui/color_picker_proxy.h"
 #include "gui/accelerators.h"
+#include "gui/color_picker_proxy.h"
+#include "libs/colorpicker.h"
 
 #define DT_GUI_CURVE_EDITOR_INSET DT_PIXEL_APPLY_DPI(5)
 
@@ -72,7 +73,7 @@ typedef struct dt_iop_rgblevels_gui_data_t
   int call_auto_levels;                         // should we calculate levels automatically?
   int draw_selected_region;                     // are we drawing the selected region?
   float posx_from, posx_to, posy_from, posy_to; // coordinates of the area
-  float box_cood[4];                            // normalized coordinates
+  dt_boundingbox_t box_cood;                    // normalized coordinates
   int button_down;                              // user pressed the mouse button?
 
   double mouse_x, mouse_y;
@@ -372,7 +373,7 @@ static gboolean _area_draw_callback(GtkWidget *widget, cairo_t *crf, dt_iop_modu
 {
   dt_iop_rgblevels_gui_data_t *c = (dt_iop_rgblevels_gui_data_t *)self->gui_data;
   dt_iop_rgblevels_params_t *p = (dt_iop_rgblevels_params_t *)self->params;
-  
+
   const int inset = DT_GUI_CURVE_EDITOR_INSET;
   GtkAllocation allocation;
   gtk_widget_get_allocation(GTK_WIDGET(c->area), &allocation);
@@ -535,6 +536,10 @@ static void _rgblevels_move_handle(dt_iop_module_t *self, const int handle_move,
   if(handle_move != 1) levels[1] = levels[0] + (drag_start_percentage * (levels[2] - levels[0]));
 
   c->last_picked_color = -1;
+
+  dt_dev_add_history_item(darktable.develop, self, TRUE);
+
+  gtk_widget_queue_draw(GTK_WIDGET(c->area));
 }
 
 static gboolean _area_motion_notify_callback(GtkWidget *widget, GdkEventMotion *event, dt_iop_module_t *self)
@@ -560,7 +565,6 @@ static gboolean _area_motion_notify_callback(GtkWidget *widget, GdkEventMotion *
 
       _rgblevels_move_handle(self, c->handle_move, mx, p->levels[c->channel], c->drag_start_percentage);
     }
-    dt_dev_add_history_item(darktable.develop, self, TRUE);
   }
   else
   {
@@ -576,8 +580,11 @@ static gboolean _area_motion_notify_callback(GtkWidget *widget, GdkEventMotion *
         dist = d2;
       }
     }
+
+    darktable.control->element = c->handle_move;
+
+    gtk_widget_queue_draw(widget);
   }
-  gtk_widget_queue_draw(widget);
 
   return TRUE;
 }
@@ -665,7 +672,6 @@ static gboolean _area_scroll_callback(GtkWidget *widget, GdkEventScroll *event,
   {
     const float new_position = p->levels[c->channel][c->handle_move] - interval * delta_y;
     _rgblevels_move_handle(self, c->handle_move, new_position, p->levels[c->channel], c->drag_start_percentage);
-    dt_dev_add_history_item(darktable.develop, self, TRUE);
     return TRUE;
   }
 
@@ -770,12 +776,9 @@ void color_picker_apply(dt_iop_module_t *self, GtkWidget *picker, dt_dev_pixelpi
    * update as rapidly */
   const float mean_picked_color = *self->picked_color;
 
-  if(self->color_picker_point[0] >= 0.0f
-     && self->color_picker_point[1] >= 0.0f
-     && self->picked_color_max[0] >= 0.0f
-     && mean_picked_color != c->last_picked_color)
+  if(mean_picked_color != c->last_picked_color)
   {
-    float previous_color[3];
+    dt_aligned_pixel_t previous_color;
     previous_color[0] = p->levels[channel][0];
     previous_color[1] = p->levels[channel][1];
     previous_color[2] = p->levels[channel][2];
@@ -939,6 +942,59 @@ void change_image(struct dt_iop_module_t *self)
   g->button_down = 0;
 }
 
+const dt_action_element_def_t _action_elements_levels[]
+  = { { N_("black"), dt_action_effect_value },
+      { N_("grey" ), dt_action_effect_value },
+      { N_("white"), dt_action_effect_value },
+      { NULL } };
+
+static float _action_process(gpointer target, dt_action_element_t element, dt_action_effect_t effect, float move_size)
+{
+  dt_iop_module_t *self = g_object_get_data(G_OBJECT(target), "iop-instance");
+  dt_iop_rgblevels_gui_data_t *c = (dt_iop_rgblevels_gui_data_t *)self->gui_data;
+  dt_iop_rgblevels_params_t *p = (dt_iop_rgblevels_params_t *)self->params;
+
+  if(!isnan(move_size))
+  {
+    float bottop = -1e6;
+    switch(effect)
+    {
+    case DT_ACTION_EFFECT_RESET:
+      p->levels[c->channel][0] = RGBLEVELS_MIN;
+      p->levels[c->channel][1] = RGBLEVELS_MID;
+      p->levels[c->channel][2] = RGBLEVELS_MAX;
+      gtk_widget_queue_draw(target);
+      break;
+    case DT_ACTION_EFFECT_BOTTOM:
+      bottop *= -1;
+    case DT_ACTION_EFFECT_TOP:
+      move_size = bottop;
+    case DT_ACTION_EFFECT_DOWN:
+      move_size *= -1;
+    case DT_ACTION_EFFECT_UP:
+      c->drag_start_percentage = (p->levels[c->channel][1] - p->levels[c->channel][0]) / (p->levels[c->channel][2] - p->levels[c->channel][0]);
+
+      const float interval = 0.02; // Distance moved for each scroll event
+      const float new_position = p->levels[c->channel][element] + interval * move_size;
+      _rgblevels_move_handle(self, element, new_position, p->levels[c->channel], c->drag_start_percentage);
+    default:
+      fprintf(stderr, "[_action_process_tabs] unknown shortcut effect (%d) for levels\n", effect);
+      break;
+    }
+
+    gchar *text = g_strdup_printf("%s %.2f", _action_elements_levels[element].name, p->levels[c->channel][element]);
+    dt_action_widget_toast(DT_ACTION(self), target, text);
+    g_free(text);
+  }
+
+  return p->levels[c->channel][element];
+}
+
+const dt_action_def_t _action_def_levels
+  = { N_("levels"),
+      _action_process,
+      _action_elements_levels };
+
 void gui_init(dt_iop_module_t *self)
 {
   dt_iop_rgblevels_gui_data_t *c = IOP_GUI_ALLOC(rgblevels);
@@ -953,22 +1009,28 @@ void gui_init(dt_iop_module_t *self)
   gtk_widget_set_tooltip_text(c->cmb_autoscale, _("choose between linked and independent channels."));
 
   c->channel_tabs = GTK_NOTEBOOK(gtk_notebook_new());
-  dt_ui_notebook_page(c->channel_tabs, _("R"), _("curve nodes for r channel"));
-  dt_ui_notebook_page(c->channel_tabs, _("G"), _("curve nodes for g channel"));
-  dt_ui_notebook_page(c->channel_tabs, _("B"), _("curve nodes for b channel"));
+  dt_action_define_iop(self, NULL, N_("channel"), GTK_WIDGET(c->channel_tabs), &dt_action_def_tabs_rgb);
+  dt_ui_notebook_page(c->channel_tabs, N_("R"), _("curve nodes for r channel"));
+  dt_ui_notebook_page(c->channel_tabs, N_("G"), _("curve nodes for g channel"));
+  dt_ui_notebook_page(c->channel_tabs, N_("B"), _("curve nodes for b channel"));
   g_signal_connect(G_OBJECT(c->channel_tabs), "switch_page", G_CALLBACK(_tab_switch_callback), self);
   gtk_box_pack_start(GTK_BOX(self->widget), GTK_WIDGET(c->channel_tabs), FALSE, FALSE, 0);
 
   const float aspect = dt_conf_get_int("plugins/darkroom/rgblevels/aspect_percent") / 100.0;
   c->area = GTK_DRAWING_AREA(dtgtk_drawing_area_new_with_aspect_ratio(aspect));
+
   gtk_box_pack_start(GTK_BOX(self->widget), GTK_WIDGET(c->area), TRUE, TRUE, 0);
 
+  g_object_set_data(G_OBJECT(c->area), "iop-instance", self);
+  dt_action_define_iop(self, NULL, N_("levels"), GTK_WIDGET(c->area), &_action_def_levels);
+
   gtk_widget_set_tooltip_text(GTK_WIDGET(c->area),_("drag handles to set black, gray, and white points. "
                                                     "operates on L channel."));
 
   gtk_widget_add_events(GTK_WIDGET(c->area), GDK_POINTER_MOTION_MASK
                                              | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
-                                             | GDK_LEAVE_NOTIFY_MASK | darktable.gui->scroll_mask);
+                                             | GDK_LEAVE_NOTIFY_MASK | GDK_ENTER_NOTIFY_MASK
+                                             | darktable.gui->scroll_mask);
   g_signal_connect(G_OBJECT(c->area), "draw", G_CALLBACK(_area_draw_callback), self);
   g_signal_connect(G_OBJECT(c->area), "button-press-event", G_CALLBACK(_area_button_press_callback), self);
   g_signal_connect(G_OBJECT(c->area), "button-release-event", G_CALLBACK(_area_button_release_callback), self);
@@ -977,16 +1039,19 @@ void gui_init(dt_iop_module_t *self)
   g_signal_connect(G_OBJECT(c->area), "scroll-event", G_CALLBACK(_area_scroll_callback), self);
 
   c->blackpick = dt_color_picker_new(self, DT_COLOR_PICKER_POINT, NULL);
+  dt_action_define_iop(self, "pickers", "black", c->blackpick, &dt_action_def_toggle);
   gtk_widget_set_tooltip_text(c->blackpick, _("pick black point from image"));
   gtk_widget_set_name(GTK_WIDGET(c->blackpick), "picker-black");
   g_signal_connect(G_OBJECT(c->blackpick), "toggled", G_CALLBACK(_color_picker_callback), self);
 
   c->greypick = dt_color_picker_new(self, DT_COLOR_PICKER_POINT, NULL);
+  dt_action_define_iop(self, "pickers", "gray", c->greypick, &dt_action_def_toggle);
   gtk_widget_set_tooltip_text(c->greypick, _("pick medium gray point from image"));
   gtk_widget_set_name(GTK_WIDGET(c->greypick), "picker-grey");
   g_signal_connect(G_OBJECT(c->greypick), "toggled", G_CALLBACK(_color_picker_callback), self);
 
   c->whitepick = dt_color_picker_new(self, DT_COLOR_PICKER_POINT, NULL);
+  dt_action_define_iop(self, "pickers", "white", c->whitepick, &dt_action_def_toggle);
   gtk_widget_set_tooltip_text(c->whitepick, _("pick white point from image"));
   gtk_widget_set_name(GTK_WIDGET(c->whitepick), "picker-white");
   g_signal_connect(G_OBJECT(c->whitepick), "toggled", G_CALLBACK(_color_picker_callback), self);
@@ -999,9 +1064,11 @@ void gui_init(dt_iop_module_t *self)
   gtk_box_pack_start(GTK_BOX(self->widget), pick_hbox, TRUE, TRUE, 0);
 
   c->bt_auto_levels = gtk_button_new_with_label(_("auto"));
+  dt_action_define_iop(self, NULL, "auto levels", c->bt_auto_levels, &dt_action_def_button);
   gtk_widget_set_tooltip_text(c->bt_auto_levels, _("apply auto levels"));
 
   c->bt_select_region = dtgtk_togglebutton_new(dtgtk_cairo_paint_colorpicker, CPF_STYLE_FLAT, NULL);
+  dt_action_define_iop(self, NULL, "auto region", c->bt_select_region, &dt_action_def_toggle);
   gtk_widget_set_tooltip_text(c->bt_select_region,
                               _("apply auto levels based on a region defined by the user\n"
                                 "click and drag to draw the area\n"
@@ -1040,7 +1107,7 @@ static void _get_selected_area(struct dt_iop_module_t *self, dt_dev_pixelpipe_io
   {
     const int width = roi_in->width;
     const int height = roi_in->height;
-    float box_cood[4] = { g->box_cood[0], g->box_cood[1], g->box_cood[2], g->box_cood[3] };
+    dt_boundingbox_t box_cood = { g->box_cood[0], g->box_cood[1], g->box_cood[2], g->box_cood[3] };
 
     box_cood[0] *= piece->pipe->iwidth;
     box_cood[1] *= piece->pipe->iheight;
@@ -1195,9 +1262,9 @@ void process(dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const void *c
     }
   }
 
-  const float mult[3] = { 1.f / (d->params.levels[0][2] - d->params.levels[0][0]),
-                          1.f / (d->params.levels[1][2] - d->params.levels[1][0]),
-                          1.f / (d->params.levels[2][2] - d->params.levels[2][0]) };
+  const dt_aligned_pixel_t mult = { 1.f / (d->params.levels[0][2] - d->params.levels[0][0]),
+                                    1.f / (d->params.levels[1][2] - d->params.levels[1][0]),
+                                    1.f / (d->params.levels[2][2] - d->params.levels[2][0]) };
 
   const size_t npixels = (size_t)roi_out->width * roi_out->height;
   const float *const restrict in = (const float*)ivoid;
