@@ -18,9 +18,6 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-#if defined(__SSE__)
-#include <xmmintrin.h>
-#endif
 #include "bauhaus/bauhaus.h"
 #include "common/imagebuf.h"
 #include "common/opencl.h"
@@ -112,6 +109,16 @@ void init_presets(dt_iop_module_so_t *self)
                             self->version(), FOR_RAW);
 }
 
+static float *const init_gaussian_kernel(const int rad, const size_t mat_size, const float sigma2)
+{
+  float weight = 0.0f;
+  float *const mat = dt_alloc_align_float(mat_size);
+  memset(mat, 0, sizeof(float) * mat_size);
+  for(int l = -rad; l <= rad; l++) weight += mat[l + rad] = expf(-l * l / (2.f * sigma2));
+  for(int l = -rad; l <= rad; l++) mat[l + rad] /= weight;
+  return mat;
+}
+
 #ifdef HAVE_OPENCL
 int process_cl(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, cl_mem dev_in, cl_mem dev_out,
                const dt_iop_roi_t *const roi_in, const dt_iop_roi_t *const roi_out)
@@ -149,15 +156,9 @@ int process_cl(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, cl_m
     return TRUE;
   }
 
-  mat = malloc(sizeof(float) * wd);
-
-  // init gaussian kernel
-  float *m = mat + rad;
   const float sigma2 = (1.0f / (2.5 * 2.5)) * (d->radius * roi_in->scale / piece->iscale)
                        * (d->radius * roi_in->scale / piece->iscale);
-  float weight = 0.0f;
-  for(int l = -rad; l <= rad; l++) weight += m[l] = expf(-(l * l) / (2.f * sigma2));
-  for(int l = -rad; l <= rad; l++) m[l] /= weight;
+  mat = init_gaussian_kernel(rad, wd, sigma2);
 
   int hblocksize;
   dt_opencl_local_buffer_t hlocopt
@@ -246,13 +247,13 @@ int process_cl(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, cl_m
 
   dt_opencl_release_mem_object(dev_m);
   dt_opencl_release_mem_object(dev_tmp);
-  free(mat);
+  dt_free_align(mat);
   return TRUE;
 
 error:
   dt_opencl_release_mem_object(dev_m);
   dt_opencl_release_mem_object(dev_tmp);
-  free(mat);
+  dt_free_align(mat);
   dt_print(DT_DEBUG_OPENCL, "[opencl_sharpen] couldn't enqueue kernel! %d\n", err);
   return FALSE;
 }
@@ -266,7 +267,8 @@ void tiling_callback(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t
   dt_iop_sharpen_data_t *d = (dt_iop_sharpen_data_t *)piece->data;
   const int rad = MIN(MAXR, ceilf(d->radius * roi_in->scale / piece->iscale));
 
-  tiling->factor = 3.0f; // in + out + tmp
+  tiling->factor = 2.1f; // in + out + tmprow
+  tiling->factor_cl = 3.0f; // in + out + tmp
   tiling->maxbuf = 1.0f;
   tiling->overhead = 0;
   tiling->overlap = rad;
@@ -278,22 +280,27 @@ void tiling_callback(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t
 void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const void *const ivoid,
              void *const ovoid, const dt_iop_roi_t *const roi_in, const dt_iop_roi_t *const roi_out)
 {
+  if (!dt_iop_have_required_input_format(4 /*we need full-color pixels*/, self, piece->colors,
+                                         ivoid, ovoid, roi_in, roi_out))
+    return;
   const dt_iop_sharpen_data_t *const data = (dt_iop_sharpen_data_t *)piece->data;
-  const int ch = piece->colors;
   const int rad = MIN(MAXR, ceilf(data->radius * roi_in->scale / piece->iscale));
   // Special case handling: very small image with one or two dimensions below 2*rad+1 treat as no sharpening and just
   // pass through.  This avoids handling of all kinds of border cases below.
   if(rad == 0 ||
      (roi_out->width < 2 * rad + 1 || roi_out->height < 2 * rad + 1))
   {
-    dt_iop_image_copy_by_size(ovoid, ivoid, roi_out->width, roi_out->height, ch);
+    dt_iop_image_copy_by_size(ovoid, ivoid, roi_out->width, roi_out->height, 4);
     return;
   }
 
-  float *restrict tmp;
-  if (!dt_iop_alloc_image_buffers(self, roi_in, roi_out, 1, &tmp, 0))
+  float *restrict tmp;	// one row per thread
+  size_t padded_size;
+  if (!dt_iop_alloc_image_buffers(self, roi_in, roi_out,
+                                  1 | DT_IMGSZ_WIDTH | DT_IMGSZ_PERTHREAD, &tmp, &padded_size,
+                                  0))
   {
-    dt_iop_copy_image_roi(ovoid, ivoid, ch, roi_in, roi_out, TRUE);
+    dt_iop_copy_image_roi(ovoid, ivoid, 4, roi_in, roi_out, TRUE);
     return;
   }
 
@@ -301,363 +308,95 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
   const int wd4 = (wd & 3) ? (wd >> 2) + 1 : wd >> 2;
 
   const size_t mat_size = (size_t)4 * wd4;
-  float *const mat = dt_alloc_align_float(mat_size);
-  memset(mat, 0, sizeof(float) * mat_size);
-
   const float sigma2 = (1.0f / (2.5 * 2.5)) * (data->radius * roi_in->scale / piece->iscale)
                        * (data->radius * roi_in->scale / piece->iscale);
-  float weight = 0.0f;
+  float *const mat = init_gaussian_kernel(rad, mat_size, sigma2);
 
-  // init gaussian kernel
-  for(int l = -rad; l <= rad; l++) weight += mat[l + rad] = expf(-l * l / (2.f * sigma2));
-  for(int l = -rad; l <= rad; l++) mat[l + rad] /= weight;
-
-// gauss blur the image horizontally
+  const float *const restrict in = (float*)ivoid;
+  const size_t width = roi_out->width;
 #ifdef _OPENMP
 #pragma omp parallel for default(none) \
-  dt_omp_firstprivate(ch, ivoid, mat, rad, roi_in, roi_out, tmp, wd4) \
+  dt_omp_firstprivate(in, ovoid, mat, rad, width, roi_in, roi_out, tmp, padded_size, data) \
   schedule(static)
 #endif
   for(int j = 0; j < roi_out->height; j++)
   {
-    const float *in = ((float *)ivoid) + (size_t)ch * (j * roi_in->width + rad);
-    float *out = tmp + (size_t)j * roi_out->width + rad;
-    int i;
-    for(i = rad; i < roi_out->width - wd4 * 4 + rad; i++)
+    // We skip the top and bottom 'rad' rows because the kernel would extend beyond the edge of the image, resulting
+    // in an incomplete summation.
+    if (j < rad || j >= roi_out->height - rad)
     {
-      const float *inp = in - ch * rad;
-      __attribute__((aligned(64))) float sum[4] = { 0.0f, 0.0f, 0.0f, 0.0f };
-
-      for(int k = 0; k < wd4 * 4; k += 4, inp += 4 * ch)
-      {
-        for(int c = 0; c < 4; c++)
-        {
-          sum[c] += ((mat[k + c]) * (inp[ch * c]));
-        }
-      }
-      *out = sum[0] + sum[1] + sum[2] + sum[3];
-      out++;
-      in += ch;
+      // fill in the top/bottom border with unchanged luma values from the input image.
+      const float *const restrict row_in = in + (size_t)4 * j * width;
+      float *const restrict row_out = ((float*)ovoid) + (size_t)4 * j * width;
+      memcpy(row_out, row_in, 4 * sizeof(float) * width);
+      continue;
     }
-    for(; i < roi_out->width - rad; i++)
+    // Get a thread-local temporary buffer for processing the current row of the image.
+    float *const restrict temp_buf = dt_get_perthread(tmp, padded_size);
+    // vertically blur the pixels of the current row into the temp buffer
+    const size_t start_row = j-rad;
+    const size_t end_row = j+rad;
+    // do the bulk of the row four at a time
+    for(int i = 0; i < width; i += 4)
+    {
+      dt_aligned_pixel_t sum = { 0.0f };
+      for(int k = start_row; k <= end_row; k++)
+      {
+        const int k_adj = k - (j-rad);
+        for_four_channels(c,aligned(in))
+          sum[c] += mat[k_adj] * in[4*(k*width+i+c)];
+      }
+      float *const vblurred = temp_buf + i;
+      for_four_channels(c,aligned(vblurred))
+        vblurred[c] = sum[c];
+    }
+    // do the leftover 0-3 pixels of the row
+    for(int i = width & ~3; i < width; i++)
     {
-      const float *inp = in - ch * rad;
-      const float *m = mat;
       float sum = 0.0f;
-      for(int k = -rad; k <= rad; k++, m++, inp += ch)
+      for(int k = start_row; k <= end_row; k++)
       {
-        sum += *m * *inp;
+        const int k_adj = k - (j-rad);
+        sum += mat[k_adj] * in[4*(k*width+i)];
       }
-      *out = sum;
-      out++;
-      in += ch;
+      temp_buf[i] = sum;
     }
-  }
 
-// gauss blur the image vertically
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-  dt_omp_firstprivate(ch, mat, ovoid, rad, roi_in, roi_out, tmp, wd4) \
-  schedule(static)
-#endif
-  for(int j = rad; j < roi_out->height - wd4 * 4 + rad; j++)
-  {
-    const float *in = tmp + (size_t)j * roi_in->width;
-    float *out = ((float *)ovoid) + (size_t)ch * j * roi_out->width;
-
-    const int step = roi_in->width;
-
-    for(int i = 0; i < roi_out->width; i++)
+    // now horizontally blur the already vertically-blurred pixels from the temp buffer to the final output buffer
+    // we can skip the left-most and right-most pixels for the same reason as we skipped the top and bottom borders.
+    float *const restrict row_out = ((float*)ovoid) + (size_t)4 * j * width;
+    for(int i = 0; i < rad; i++)
+      copy_pixel(row_out + 4*i, in + 4*(j*width+i));  //copy unsharpened border pixel
+    const float threshold = data->threshold;
+    const float amount = data->amount;
+    for(int i = rad; i < roi_out->width - rad; i++)
     {
-      const float *inp = in - step * rad;
-      __attribute__((aligned(64))) float sum[4] = { 0.0f, 0.0f, 0.0f, 0.0f };
-
-      for(int k = 0; k < wd4 * 4; k += 4, inp += step * 4)
-      {
-        for(int c = 0; c < 4; c++)
-        {
-          sum[c] += ((mat[k + c]) * (inp[step * c]));
-        }
-      }
-      *out = sum[0] + sum[1] + sum[2] + sum[3];
-      out += ch;
-      in++;
-    }
-  }
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-  dt_omp_firstprivate(ch, mat, ovoid, rad, roi_in, roi_out, tmp, wd4) \
-  schedule(static)
-#endif
-  for(int j = roi_out->height - wd4 * 4 + rad; j < roi_out->height - rad; j++)
-  {
-    const float *in = tmp + (size_t)j * roi_in->width;
-    float *out = ((float *)ovoid) + (size_t)ch * j * roi_out->width;
-    const int step = roi_in->width;
-
-    for(int i = 0; i < roi_out->width; i++)
-    {
-      const float *inp = in - step * rad;
-      const float *m = mat;
       float sum = 0.0f;
-      for(int k = -rad; k <= rad; k++, m++, inp += step) sum += *m * *inp;
-      *out = sum;
-      out += ch;
-      in++;
+      for(int k = i-rad; k <= i+rad; k++)
+      {
+        const int k_adj = k - (i-rad);
+        sum += mat[k_adj] * temp_buf[k];
+      }
+      // subtract the blurred pixel's luma from the original input pixel's luma
+      const size_t index = 4 * (j * width + i);
+      const float diff = in[index] - sum;
+      const float absdiff = fabs(diff);
+      const float detail = (absdiff > threshold) ? copysignf(MAX(absdiff - threshold, 0.0f), diff) : 0.0f;
+      row_out[4*i] = in[index] + detail * amount;
+      row_out[4*i + 1] = in[index + 1];
+      row_out[4*i + 2] = in[index + 2];
     }
+    for(int i = roi_out->width - rad; i < roi_out->width; i++)
+      copy_pixel(row_out + 4*i, in + 4*(j*width+i));  //copy unsharpened border pixel
   }
 
   dt_free_align(mat);
-
-  // fill unsharpened border
-  for(int j = 0; j < rad; j++)
-    memcpy(((float *)ovoid) + (size_t)ch * j * roi_out->width,
-           ((float *)ivoid) + (size_t)ch * j * roi_in->width, (size_t)ch * sizeof(float) * roi_out->width);
-  for(int j = roi_out->height - rad; j < roi_out->height; j++)
-    memcpy(((float *)ovoid) + (size_t)ch * j * roi_out->width,
-           ((float *)ivoid) + (size_t)ch * j * roi_in->width, (size_t)ch * sizeof(float) * roi_out->width);
-
   dt_free_align(tmp);
 
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-  dt_omp_firstprivate(ch, ivoid, ovoid, rad, roi_out) \
-  schedule(static)
-#endif
-  for(int j = rad; j < roi_out->height - rad; j++)
-  {
-    float *in = ((float *)ivoid) + (size_t)ch * roi_out->width * j;
-    float *out = ((float *)ovoid) + (size_t)ch * roi_out->width * j;
-    for(int i = 0; i < rad; i++) out[ch * i] = in[ch * i];
-    for(int i = roi_out->width - rad; i < roi_out->width; i++) out[ch * i] = in[ch * i];
-  }
-
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-  dt_omp_firstprivate(ch, data, ivoid, ovoid, roi_out) \
-  schedule(static)
-#endif
-  // subtract blurred image, if diff > thrs, add *amount to original image
-  for(int j = 0; j < roi_out->height; j++)
-  {
-    float *in = (float *)ivoid + (size_t)j * ch * roi_out->width;
-    float *out = (float *)ovoid + (size_t)j * ch * roi_out->width;
-
-    for(int i = 0; i < roi_out->width; i++)
-    {
-      out[1] = in[1];
-      out[2] = in[2];
-      const float diff = in[0] - out[0];
-      if(fabsf(diff) > data->threshold)
-      {
-        const float detail = copysignf(fmaxf(fabsf(diff) - data->threshold, 0.0), diff);
-        out[0] = in[0] + detail * data->amount;
-      }
-      else
-        out[0] = in[0];
-      out += ch;
-      in += ch;
-    }
-  }
-
-  if(piece->pipe->mask_display & DT_DEV_PIXELPIPE_DISPLAY_MASK) dt_iop_alpha_copy(ivoid, ovoid, roi_out->width, roi_out->height);
+  if(piece->pipe->mask_display & DT_DEV_PIXELPIPE_DISPLAY_MASK)
+    dt_iop_alpha_copy(ivoid, ovoid, roi_out->width, roi_out->height);
 }
 
-#if defined(__SSE__)
-void process_sse2(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const void *const ivoid,
-                  void *const ovoid, const dt_iop_roi_t *const roi_in, const dt_iop_roi_t *const roi_out)
-{
-  const dt_iop_sharpen_data_t *const data = (dt_iop_sharpen_data_t *)piece->data;
-  const int ch = piece->colors;
-  const int rad = MIN(MAXR, ceilf(data->radius * roi_in->scale / piece->iscale));
-  // Special case handling: very small image with one or two dimensions below 2*rad+1 treat as no sharpening and just
-  // pass through.  This avoids handling of all kinds of border cases below.
-  if(rad == 0 ||
-     (roi_out->width < 2 * rad + 1 || roi_out->height < 2 * rad + 1))
-  {
-    dt_iop_image_copy_by_size(ovoid, ivoid, roi_out->width, roi_out->height, ch);
-    return;
-  }
-
-  float *restrict tmp;
-  if (!dt_iop_alloc_image_buffers(self, roi_in, roi_out, 1, &tmp, 0))
-  {
-    dt_iop_copy_image_roi(ovoid, ivoid, ch, roi_in, roi_out, TRUE);
-    return;
-  }
-
-  const int wd = 2 * rad + 1;
-  const int wd4 = (wd & 3) ? (wd >> 2) + 1 : wd >> 2;
-
-  const size_t mat_size = (size_t)4 * wd4;
-  float *const mat = dt_alloc_align_float(mat_size);
-  memset(mat, 0, sizeof(float) * mat_size);
-
-  const float sigma2 = (1.0f / (2.5 * 2.5)) * (data->radius * roi_in->scale / piece->iscale)
-                       * (data->radius * roi_in->scale / piece->iscale);
-  float weight = 0.0f;
-
-  // init gaussian kernel
-  for(int l = -rad; l <= rad; l++) weight += mat[l + rad] = expf(-l * l / (2.f * sigma2));
-  for(int l = -rad; l <= rad; l++) mat[l + rad] /= weight;
-
-// gauss blur the image horizontally
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-  dt_omp_firstprivate(ch, ivoid, mat, rad, roi_in, roi_out, tmp, wd4) \
-  schedule(static)
-#endif
-  for(int j = 0; j < roi_out->height; j++)
-  {
-    const float *in = ((float *)ivoid) + (size_t)ch * (j * roi_in->width + rad);
-    float *out = tmp + (size_t)j * roi_out->width + rad;
-    int i;
-    for(i = rad; i < roi_out->width - wd4 * 4 + rad; i++)
-    {
-      const float *inp = in - ch * rad;
-      __attribute__((aligned(64))) float sum[4] = { 0.0f, 0.0f, 0.0f, 0.0f };
-      __m128 msum = _mm_setzero_ps();
-
-      for(int k = 0; k < wd4 * 4; k += 4, inp += 4 * ch)
-      {
-        msum = _mm_add_ps(
-            msum, _mm_mul_ps(_mm_load_ps(mat + k), _mm_set_ps(inp[3 * ch], inp[2 * ch], inp[ch], inp[0])));
-      }
-      _mm_store_ps(sum, msum);
-      *out = sum[0] + sum[1] + sum[2] + sum[3];
-      out++;
-      in += ch;
-    }
-    for(; i < roi_out->width - rad; i++)
-    {
-      const float *inp = in - ch * rad;
-      const float *m = mat;
-      float sum = 0.0f;
-      for(int k = -rad; k <= rad; k++, m++, inp += ch)
-      {
-        sum += *m * *inp;
-      }
-      *out = sum;
-      out++;
-      in += ch;
-    }
-  }
-  _mm_sfence();
-
-// gauss blur the image vertically
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-  dt_omp_firstprivate(ch, mat, ovoid, rad, roi_in, roi_out, tmp, wd4) \
-  schedule(static)
-#endif
-  for(int j = rad; j < roi_out->height - wd4 * 4 + rad; j++)
-  {
-    const float *in = tmp + (size_t)j * roi_in->width;
-    float *out = ((float *)ovoid) + (size_t)ch * j * roi_out->width;
-
-    const int step = roi_in->width;
-
-    __attribute__((aligned(64))) float sum[4] = { 0.0f, 0.0f, 0.0f, 0.0f };
-
-    for(int i = 0; i < roi_out->width; i++)
-    {
-      const float *inp = in - step * rad;
-      __m128 msum = _mm_setzero_ps();
-
-      for(int k = 0; k < wd4 * 4; k += 4, inp += step * 4)
-      {
-        msum = _mm_add_ps(msum, _mm_mul_ps(_mm_load_ps(mat + k),
-                                           _mm_set_ps(inp[3 * step], inp[2 * step], inp[step], inp[0])));
-      }
-      _mm_store_ps(sum, msum);
-      *out = sum[0] + sum[1] + sum[2] + sum[3];
-      out += ch;
-      in++;
-    }
-  }
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-  dt_omp_firstprivate(ch, ivoid, mat, ovoid, rad, roi_in, roi_out, tmp, wd4) \
-  schedule(static)
-#endif
-  for(int j = roi_out->height - wd4 * 4 + rad; j < roi_out->height - rad; j++)
-  {
-    const float *in = tmp + (size_t)j * roi_in->width;
-    float *out = ((float *)ovoid) + (size_t)ch * j * roi_out->width;
-    const int step = roi_in->width;
-
-    for(int i = 0; i < roi_out->width; i++)
-    {
-      const float *inp = in - step * rad;
-      const float *m = mat;
-      float sum = 0.0f;
-      for(int k = -rad; k <= rad; k++, m++, inp += step) sum += *m * *inp;
-      *out = sum;
-      out += ch;
-      in++;
-    }
-  }
-
-  dt_free_align(mat);
-
-  _mm_sfence();
-
-  // fill unsharpened border
-  for(int j = 0; j < rad; j++)
-    memcpy(((float *)ovoid) + (size_t)ch * j * roi_out->width,
-           ((float *)ivoid) + (size_t)ch * j * roi_in->width, (size_t)ch * sizeof(float) * roi_out->width);
-  for(int j = roi_out->height - rad; j < roi_out->height; j++)
-    memcpy(((float *)ovoid) + (size_t)ch * j * roi_out->width,
-           ((float *)ivoid) + (size_t)ch * j * roi_in->width, (size_t)ch * sizeof(float) * roi_out->width);
-
-  dt_free_align(tmp);
-
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-  dt_omp_firstprivate(ch, ivoid, ovoid, rad, roi_out) \
-  schedule(static)
-#endif
-  for(int j = rad; j < roi_out->height - rad; j++)
-  {
-    float *in = ((float *)ivoid) + (size_t)ch * roi_out->width * j;
-    float *out = ((float *)ovoid) + (size_t)ch * roi_out->width * j;
-    for(int i = 0; i < rad; i++) out[ch * i] = in[ch * i];
-    for(int i = roi_out->width - rad; i < roi_out->width; i++) out[ch * i] = in[ch * i];
-  }
-
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-  dt_omp_firstprivate(ch, ivoid, ovoid, roi_out) \
-  dt_omp_sharedconst(data) \
-  schedule(static)
-#endif
-  // subtract blurred image, if diff > thrs, add *amount to original image
-  for(int j = 0; j < roi_out->height; j++)
-  {
-    float *in = (float *)ivoid + (size_t)j * ch * roi_out->width;
-    float *out = (float *)ovoid + (size_t)j * ch * roi_out->width;
-
-    for(int i = 0; i < roi_out->width; i++)
-    {
-      out[1] = in[1];
-      out[2] = in[2];
-      const float diff = in[0] - out[0];
-      if(fabsf(diff) > data->threshold)
-      {
-        const float detail = copysignf(fmaxf(fabsf(diff) - data->threshold, 0.0), diff);
-        out[0] = in[0] + detail * data->amount;
-      }
-      else
-        out[0] = in[0];
-      out += ch;
-      in += ch;
-    }
-  }
-
-  if(piece->pipe->mask_display & DT_DEV_PIXELPIPE_DISPLAY_MASK) dt_iop_alpha_copy(ivoid, ovoid, roi_out->width, roi_out->height);
-}
-#endif
-
 void commit_params(struct dt_iop_module_t *self, dt_iop_params_t *p1, dt_dev_pixelpipe_t *pipe,
                    dt_dev_pixelpipe_iop_t *piece)
 {
