@@ -175,7 +175,7 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
     rgb2hsl(in+k, &h, &s, &l);
     if(l < data->balance - compress)
     {
-      float DT_ALIGNED_PIXEL mixrgb[4];
+      dt_aligned_pixel_t mixrgb;
       hsl2rgb(mixrgb, data->shadow_hue, data->shadow_saturation, l);
 
       const float ra = CLIP((data->balance - compress - l) * 2.0f);
@@ -186,7 +186,7 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
     }
     else if(l > data->balance + compress)
     {
-      float DT_ALIGNED_PIXEL mixrgb[4];
+      dt_aligned_pixel_t mixrgb;
       hsl2rgb(mixrgb, data->highlight_hue, data->highlight_saturation, l);
 
       const float ra = CLIP((l - (data->balance + compress)) * 2.0f);
@@ -265,7 +265,7 @@ void cleanup_global(dt_iop_module_so_t *module)
 
 static inline void update_colorpicker_color(GtkWidget *colorpicker, float hue, float sat)
 {
-  float rgb[3];
+  dt_aligned_pixel_t rgb;
   hsl2rgb(rgb, hue, sat, 0.5);
 
   GdkRGBA color = (GdkRGBA){.red = rgb[0], .green = rgb[1], .blue = rgb[2], .alpha = 1.0 };
@@ -274,7 +274,7 @@ static inline void update_colorpicker_color(GtkWidget *colorpicker, float hue, f
 
 static inline void update_saturation_slider_end_color(GtkWidget *slider, float hue)
 {
-  float rgb[3];
+  dt_aligned_pixel_t rgb;
   hsl2rgb(rgb, hue, 1.0, 0.5);
   dt_bauhaus_slider_set_stop(slider, 1.0, rgb[0], rgb[1], rgb[2]);
 }
@@ -284,7 +284,7 @@ static inline void update_balance_slider_colors(
     float shadow_hue,
     float highlight_hue)
 {
-  float rgb[3];
+  dt_aligned_pixel_t rgb;
   if(shadow_hue != -1)
   {
     hsl2rgb(rgb, shadow_hue, 1.0, 0.5);
@@ -336,7 +336,8 @@ static void colorpick_callback(GtkColorButton *widget, dt_iop_module_t *self)
 
   dt_iop_splittoning_gui_data_t *g = (dt_iop_splittoning_gui_data_t *)self->gui_data;
 
-  float color[3], h, s, l;
+  dt_aligned_pixel_t color;
+  float h, s, l;
 
   GdkRGBA c;
   gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(widget), &c);
@@ -508,10 +509,14 @@ void gui_init(struct dt_iop_module_t *self)
   ++darktable.bauhaus->skip_accel;
   GtkWidget *shadows_box = self->widget = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
   g->shadow_hue_gslider = dt_bauhaus_slider_from_params(self, "shadow_hue");
+  dt_bauhaus_slider_set_factor(g->shadow_hue_gslider, 360.0f);
+  dt_bauhaus_slider_set_format(g->shadow_hue_gslider, "%.2f°");
   g->shadow_sat_gslider = dt_bauhaus_slider_from_params(self, "shadow_saturation");
 
   GtkWidget *highlights_box = self->widget = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
   g->highlight_hue_gslider = dt_bauhaus_slider_from_params(self, "highlight_hue");
+  dt_bauhaus_slider_set_factor(g->highlight_hue_gslider, 360.0f);
+  dt_bauhaus_slider_set_format(g->highlight_hue_gslider, "%.2f°");
   g->highlight_sat_gslider = dt_bauhaus_slider_from_params(self, "highlight_saturation");
   --darktable.bauhaus->skip_accel;
 
@@ -538,7 +543,7 @@ void gui_init(struct dt_iop_module_t *self)
 
   g->compress_scale = dt_bauhaus_slider_from_params(self, N_("compress"));
   dt_bauhaus_slider_set_format(g->compress_scale, "%.2f%%");
-  gtk_widget_set_tooltip_text(g->compress_scale, _("compress the effect on highlights/shadows and\npreserve midtones"));
+  gtk_widget_set_tooltip_text(g->compress_scale, _("compress the effect on highlights/shadows and\npreserve mid-tones"));
 }
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
