@@ -125,7 +125,7 @@ int default_group()
 
 int default_colorspace(dt_iop_module_t *self, dt_dev_pixelpipe_t *pipe, dt_dev_pixelpipe_iop_t *piece)
 {
-  return iop_cs_Lab;
+  return iop_cs_rgb;
 }
 
 // Whenever new fields are added to (or removed from) dt_iop_..._params_t or when their meaning
