@@ -260,7 +260,7 @@ void gui_post_expose(dt_lib_module_t *self, cairo_t *cri, int32_t width, int32_t
     if(cur_scale >= 2.0f)
     {
       /* xgettext:no-c-format */
-      dt_control_log(_("preview is only possible for zoom lower than 200%%..."));
+      dt_control_log(_("preview is only possible for zoom lower than 200%%"));
       return;
     }
     nz = cur_scale / min_scale;
@@ -445,8 +445,8 @@ static void _lib_duplicate_init_callback(gpointer instance, dt_lib_module_t *sel
     gtk_entry_set_width_chars(GTK_ENTRY(tb), 0);
     gtk_widget_set_hexpand(tb, TRUE);
     g_object_set_data (G_OBJECT(tb), "imgid", GINT_TO_POINTER(imgid));
+    gtk_widget_add_events(tb, GDK_FOCUS_CHANGE_MASK);
     g_signal_connect(G_OBJECT(tb), "focus-out-event", G_CALLBACK(_lib_duplicate_caption_out_callback), self);
-    dt_gui_key_accel_block_on_focus_connect(GTK_WIDGET(tb));
     GtkWidget *lb = gtk_label_new (g_strdup(chl));
     gtk_widget_set_hexpand(lb, TRUE);
     bt = dtgtk_button_new(dtgtk_cairo_paint_cancel, CPF_STYLE_FLAT, NULL);
