@@ -108,16 +108,13 @@ void dt_lib_cleanup(dt_lib_t *lib);
 
 /** creates a label widget for the expander, with callback to enable/disable this module. */
 GtkWidget *dt_lib_gui_get_expander(dt_lib_module_t *module);
-/** set a expand/collaps plugin expander */
+/** set an expand/collapse plugin expander */
 void dt_lib_gui_set_expanded(dt_lib_module_t *module, gboolean expanded);
 /** get the expanded state of a plugin */
 gboolean dt_lib_gui_get_expanded(dt_lib_module_t *module);
 
 extern const struct dt_action_def_t dt_action_def_lib;
 
-/** connects the reset and presets shortcuts to a lib */
-void dt_lib_connect_common_accels(dt_lib_module_t *module);
-
 /** return the plugin with the given name */
 dt_lib_module_t *dt_lib_get_module(const char *name);
 
