@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2019-2020 darktable developers.
+    Copyright (C) 2019-2021 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -269,7 +269,7 @@ static int _time_compare(dt_lib_timeline_time_t t1, dt_lib_timeline_time_t t2)
   return 0;
 }
 
-// add/substract value to a time at certain level
+// add/subtract value to a time at certain level
 static void _time_add(dt_lib_timeline_time_t *t, int val, dt_lib_timeline_zooms_t level)
 {
   if(level == DT_LIB_TIMELINE_ZOOM_YEAR)
@@ -385,8 +385,7 @@ static dt_lib_timeline_time_t _time_get_from_pos(int pos, dt_lib_timeline_t *str
   dt_lib_timeline_time_t tt = _time_init();
 
   int x = 0;
-  GList *bl = strip->blocks;
-  while(bl)
+  for(const GList *bl = strip->blocks; bl; bl = g_list_next(bl))
   {
     dt_lib_timeline_block_t *blo = bl->data;
     if(pos < x + blo->width)
@@ -439,7 +438,6 @@ static dt_lib_timeline_time_t _time_get_from_pos(int pos, dt_lib_timeline_t *str
       return tt;
     }
     x += blo->width + 2;
-    bl = bl->next;
   }
 
   return tt;
@@ -455,13 +453,12 @@ static dt_lib_timeline_time_t _time_compute_offset_for_zoom(int pos, dt_lib_time
   // we search the number of the bloc under pos
   int bloc_nb = 0;
   int x = 0;
-  GList *bl = strip->blocks;
-  while(bl)
+  GList *bl;
+  for(bl = strip->blocks; bl; bl = g_list_next(bl))
   {
     dt_lib_timeline_block_t *blo = bl->data;
     if(pos < x + blo->width) break;
     x += blo->width + 2;
-    bl = bl->next;
     bloc_nb++;
   }
   if(!bl)
@@ -572,7 +569,7 @@ static gboolean _time_read_bounds_from_db(dt_lib_module_t *self)
 
   sqlite3_stmt *stmt;
   const char *query = "SELECT datetime_taken FROM main.images WHERE LENGTH(datetime_taken) = 19 AND "
-                      "datetime_taken > '0001:01:01 00:00:00' ORDER BY "
+                      "datetime_taken > '0001:01:01 00:00:00' COLLATE NOCASE ORDER BY "
                       "datetime_taken ASC LIMIT 1";
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query, -1, &stmt, NULL);
 
@@ -592,7 +589,7 @@ static gboolean _time_read_bounds_from_db(dt_lib_module_t *self)
   sqlite3_finalize(stmt);
 
   const char *query2 = "SELECT datetime_taken FROM main.images WHERE LENGTH(datetime_taken) = 19 AND "
-                       "datetime_taken > '0001:01:01 00:00:00' ORDER BY "
+                       "datetime_taken > '0001:01:01 00:00:00' COLLATE NOCASE ORDER BY "
                        "datetime_taken DESC LIMIT 1";
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query2, -1, &stmt, NULL);
 
@@ -619,7 +616,7 @@ static gboolean _time_read_bounds_from_collection(dt_lib_module_t *self)
   sqlite3_stmt *stmt;
   const char *query = "SELECT db.datetime_taken FROM main.images AS db, memory.collected_images AS col WHERE "
                       "db.id=col.imgid AND LENGTH(db.datetime_taken) = 19 AND db.datetime_taken > '0001:01:01 "
-                      "00:00:00' ORDER BY "
+                      "00:00:00' COLLATE NOCASE ORDER BY "
                       "db.datetime_taken ASC LIMIT 1";
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query, -1, &stmt, NULL);
 
@@ -640,7 +637,7 @@ static gboolean _time_read_bounds_from_collection(dt_lib_module_t *self)
 
   const char *query2 = "SELECT db.datetime_taken FROM main.images AS db, memory.collected_images AS col WHERE "
                        "db.id=col.imgid AND LENGTH(db.datetime_taken) = 19 AND db.datetime_taken > '0001:01:01 "
-                       "00:00:00' ORDER BY "
+                       "00:00:00' COLLATE NOCASE ORDER BY "
                        "db.datetime_taken DESC LIMIT 1";
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query2, -1, &stmt, NULL);
 
@@ -737,7 +734,7 @@ static int _block_get_at_zoom(dt_lib_module_t *self, int width)
   gchar *query = g_strdup_printf("SELECT db.datetime_taken, col.imgid FROM main.images AS db LEFT JOIN "
                                  "memory.collected_images AS col ON db.id=col.imgid WHERE "
                                  "LENGTH(db.datetime_taken) = 19 AND "
-                                 "db.datetime_taken > '%s' ORDER BY db.datetime_taken ASC",
+                                 "db.datetime_taken > '%s' COLLATE NOCASE ORDER BY db.datetime_taken ASC",
                                  _time_format_for_db(strip->time_pos, strip->zoom, TRUE));
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query, -1, &stmt, NULL);
 
@@ -870,8 +867,9 @@ static gboolean _time_is_visible(dt_lib_timeline_time_t t, dt_lib_timeline_t *st
   return TRUE;
 }
 
-static void _lib_timeline_collection_changed(gpointer instance, dt_collection_change_t query_change, gpointer imgs,
-                                             int next, gpointer user_data)
+static void _lib_timeline_collection_changed(gpointer instance, dt_collection_change_t query_change,
+                                             dt_collection_properties_t changed_property, gpointer imgs, int next,
+                                             gpointer user_data)
 {
   dt_lib_module_t *self = (dt_lib_module_t *)user_data;
   dt_lib_timeline_t *strip = (dt_lib_timeline_t *)self->data;
@@ -892,6 +890,12 @@ static void _lib_timeline_collection_changed(gpointer instance, dt_collection_ch
 }
 
 
+static gboolean _timespec_has_date_only(const char *const spec)
+{
+  // spec could be "YYYY:MM", "YYYY:MM:DD", "YYYY:MM:DD HH", etc.
+  return strlen(spec) <= 10; // is string YYYY:MM:DD or shorter?
+}
+
 // add the selected portions to the collect
 static void _selection_collect(dt_lib_timeline_t *strip, dt_lib_timeline_mode_t mode)
 {
@@ -910,8 +914,8 @@ static void _selection_collect(dt_lib_timeline_t *strip, dt_lib_timeline_mode_t
     snprintf(confname, sizeof(confname), "plugins/lighttable/collect/string%1d", nb_rules - 1);
     gchar *string = dt_conf_get_string(confname);
     string = g_strstrip(string);
-    if((prop == DT_COLLECTION_PROP_TIME && rmode == 0) || !string || strlen(string) == 0
-       || g_strcmp0(string, "%") == 0)
+    if(((prop == DT_COLLECTION_PROP_TIME || prop == DT_COLLECTION_PROP_DAY) && rmode == 0)
+       || !string || strlen(string) == 0 || g_strcmp0(string, "%") == 0)
       new_rule = nb_rules - 1;
     else
       new_rule = nb_rules;
@@ -920,9 +924,11 @@ static void _selection_collect(dt_lib_timeline_t *strip, dt_lib_timeline_mode_t
 
   // we construct the rule
   gchar *coll = NULL;
+  gboolean date_only = FALSE;
   if(strip->start_x == strip->stop_x)
   {
     coll = _time_format_for_db(strip->start_t, (strip->zoom + 1) / 2 * 2 + 2, FALSE);
+    date_only = _timespec_has_date_only(coll);
   }
   else
   {
@@ -936,7 +942,11 @@ static void _selection_collect(dt_lib_timeline_t *strip, dt_lib_timeline_mode_t
     }
     gchar *d1 = _time_format_for_db(start, (strip->zoom + 1) / 2 * 2 + 2, FALSE);
     gchar *d2 = _time_format_for_db(stop, (strip->zoom + 1) / 2 * 2 + 2, FALSE);
-    if(d1 && d2) coll = g_strdup_printf("[%s;%s]", d1, d2);
+    if(d1 && d2)
+    {
+      coll = g_strdup_printf("[%s;%s]", d1, d2);
+      date_only = _timespec_has_date_only(d1) && _timespec_has_date_only(d2);
+    }
     g_free(d1);
     g_free(d2);
   }
@@ -946,14 +956,15 @@ static void _selection_collect(dt_lib_timeline_t *strip, dt_lib_timeline_mode_t
     dt_conf_set_int("plugins/lighttable/collect/num_rules", new_rule + 1);
     char confname[200] = { 0 };
     snprintf(confname, sizeof(confname), "plugins/lighttable/collect/item%1d", new_rule);
-    dt_conf_set_int(confname, DT_COLLECTION_PROP_TIME);
+    dt_conf_set_int(confname, date_only ? DT_COLLECTION_PROP_DAY : DT_COLLECTION_PROP_TIME);
     snprintf(confname, sizeof(confname), "plugins/lighttable/collect/mode%1d", new_rule);
     dt_conf_set_int(confname, 0);
     snprintf(confname, sizeof(confname), "plugins/lighttable/collect/string%1d", new_rule);
     dt_conf_set_string(confname, coll);
     g_free(coll);
 
-    dt_collection_update_query(darktable.collection, DT_COLLECTION_CHANGE_NEW_QUERY, NULL);
+    dt_collection_update_query(darktable.collection, DT_COLLECTION_CHANGE_NEW_QUERY, DT_COLLECTION_PROP_UNDEF,
+                               NULL);
   }
 }
 
@@ -1005,9 +1016,8 @@ static gboolean _lib_timeline_draw_callback(GtkWidget *widget, cairo_t *wcr, gpo
     cairo_paint(cr);
 
     // draw content depending of zoom level
-    GList *bl = strip->blocks;
     int posx = 0;
-    while(bl)
+    for(const GList *bl = strip->blocks; bl; bl = g_list_next(bl))
     {
       dt_lib_timeline_block_t *blo = bl->data;
 
@@ -1015,30 +1025,29 @@ static gboolean _lib_timeline_draw_callback(GtkWidget *widget, cairo_t *wcr, gpo
       int wb = blo->values_count * wu;
 
       cairo_text_extents_t te;
-      dt_gui_gtk_set_source_rgb(cr, DT_GUI_COLOR_BRUSH_CURSOR);
+      dt_gui_gtk_set_source_rgb(cr, DT_GUI_COLOR_TIMELINE_TEXT_FG);
       cairo_set_font_size(cr, 10 * (1 + (darktable.gui->dpi_factor - 1) / 2));
       cairo_text_extents(cr, blo->name, &te);
       int bh = allocation.height - te.height - 4;
       cairo_move_to(cr, posx + (wb - te.width) / 2 - te.x_bearing, allocation.height - 2);
       cairo_show_text(cr, blo->name);
 
-      dt_gui_gtk_set_source_rgb(cr, DT_GUI_COLOR_THUMBNAIL_BG);
+      dt_gui_gtk_set_source_rgb(cr, DT_GUI_COLOR_TIMELINE_BG);
       cairo_rectangle(cr, posx, 0, wb, bh);
       cairo_fill(cr);
 
       for(int i = 0; i < blo->values_count; i++)
       {
-        dt_gui_gtk_set_source_rgba(cr, DT_GUI_COLOR_THUMBNAIL_HOVER_BG, 0.5);
+        dt_gui_gtk_set_source_rgba(cr, DT_GUI_COLOR_TIMELINE_FG, 0.5);
         int h = _block_get_bar_height(blo->values[i], bh);
         cairo_rectangle(cr, posx + (i * wu), bh - h, wu, h);
         cairo_fill(cr);
-        dt_gui_gtk_set_source_rgba(cr, DT_GUI_COLOR_THUMBNAIL_HOVER_BG, 1.0);
+        dt_gui_gtk_set_source_rgba(cr, DT_GUI_COLOR_TIMELINE_FG, 1.0);
         h = _block_get_bar_height(blo->collect_values[i], bh);
         cairo_rectangle(cr, posx + (i * wu), bh - h, wu, h);
         cairo_fill(cr);
       }
 
-      bl = bl->next;
       posx += wb + 2;
       if(posx >= allocation.width) break;
     }
@@ -1072,7 +1081,7 @@ static gboolean _lib_timeline_draw_callback(GtkWidget *widget, cairo_t *wcr, gpo
       if(start >= 0)
       {
         // dt_gui_gtk_set_source_rgb(wcr, DT_GUI_COLOR_THUMBNAIL_HOVER_BG);
-        dt_gui_gtk_set_source_rgba(wcr, DT_GUI_COLOR_THUMBNAIL_HOVER_BG, 0.8);
+        dt_gui_gtk_set_source_rgba(wcr, DT_GUI_COLOR_TIMELINE_FG, 0.8);
         cairo_move_to(wcr, start, 0);
         cairo_line_to(wcr, start, allocation.height);
         cairo_stroke(wcr);
@@ -1081,12 +1090,12 @@ static gboolean _lib_timeline_draw_callback(GtkWidget *widget, cairo_t *wcr, gpo
         cairo_line_to(wcr, start, allocation.height);
         cairo_stroke(wcr);
       }
-      dt_gui_gtk_set_source_rgba(wcr, DT_GUI_COLOR_THUMBNAIL_HOVER_BG, 0.5);
+      dt_gui_gtk_set_source_rgba(wcr, DT_GUI_COLOR_TIMELINE_FG, 0.5);
       cairo_rectangle(wcr, start, 0, stop - start, allocation.height);
       cairo_fill(wcr);
       if(stop <= strip->panel_width)
       {
-        dt_gui_gtk_set_source_rgba(wcr, DT_GUI_COLOR_THUMBNAIL_HOVER_BG, 0.8);
+        dt_gui_gtk_set_source_rgba(wcr, DT_GUI_COLOR_TIMELINE_FG, 0.8);
         cairo_move_to(wcr, stop, 0);
         cairo_line_to(wcr, stop, allocation.height);
         cairo_stroke(wcr);
@@ -1110,7 +1119,7 @@ static gboolean _lib_timeline_draw_callback(GtkWidget *widget, cairo_t *wcr, gpo
     // we don't display NULL date (if it's outside bounds)
     if(_time_compare(tt, _time_init()) != 0)
     {
-      dt_gui_gtk_set_source_rgb(wcr, DT_GUI_COLOR_BRUSH_TRACE);
+      dt_gui_gtk_set_source_rgb(wcr, DT_GUI_COLOR_TIMELINE_TEXT_BG);
       cairo_move_to(wcr, strip->current_x, 0);
       cairo_line_to(wcr, strip->current_x, allocation.height);
       cairo_stroke(wcr);
@@ -1119,10 +1128,10 @@ static gboolean _lib_timeline_draw_callback(GtkWidget *widget, cairo_t *wcr, gpo
       cairo_set_font_size(wcr, 10 * darktable.gui->dpi_factor);
       cairo_text_extents(wcr, dte, &te2);
       cairo_rectangle(wcr, strip->current_x, 8, te2.width + 4, te2.height + 4);
-      dt_gui_gtk_set_source_rgb(wcr, DT_GUI_COLOR_BRUSH_TRACE);
+      dt_gui_gtk_set_source_rgb(wcr, DT_GUI_COLOR_TIMELINE_TEXT_BG);
       cairo_fill(wcr);
       cairo_move_to(wcr, strip->current_x + 2, 10 + te2.height);
-      dt_gui_gtk_set_source_rgb(wcr, DT_GUI_COLOR_BRUSH_CURSOR);
+      dt_gui_gtk_set_source_rgb(wcr, DT_GUI_COLOR_TIMELINE_TEXT_FG);
       cairo_show_text(wcr, dte);
       g_free(dte);
     }
@@ -1180,7 +1189,8 @@ static gboolean _lib_timeline_button_press_callback(GtkWidget *w, GdkEventButton
       if(dt_conf_get_int(confname) == DT_COLLECTION_PROP_TIME)
       {
         dt_conf_set_int("plugins/lighttable/collect/num_rules", nb_rules - 1);
-        dt_collection_update_query(darktable.collection, DT_COLLECTION_CHANGE_RELOAD, NULL);
+        dt_collection_update_query(darktable.collection, DT_COLLECTION_CHANGE_RELOAD, DT_COLLECTION_PROP_UNDEF,
+                                   NULL);
 
         strip->selecting = FALSE;
       }
@@ -1220,7 +1230,7 @@ static gboolean _lib_timeline_button_release_callback(GtkWidget *w, GdkEventButt
     }
     strip->selecting = FALSE;
 
-    if(!strip->move_edge && (e->state & GDK_SHIFT_MASK))
+    if(!strip->move_edge && dt_modifier_is(e->state, GDK_SHIFT_MASK))
       _selection_collect(strip, DT_LIB_TIMELINE_MODE_RESET);
     else
       _selection_collect(strip, DT_LIB_TIMELINE_MODE_AND);
@@ -1375,16 +1385,20 @@ static gboolean _lib_timeline_scroll_callback(GtkWidget *w, GdkEventScroll *e, g
   dt_lib_timeline_t *strip = (dt_lib_timeline_t *)self->data;
 
   // zoom change (with Ctrl key)
-  if(e->state & GDK_CONTROL_MASK)
+  if(dt_modifier_is(e->state, GDK_CONTROL_MASK))
   {
     int z = strip->zoom;
-    if(e->direction == GDK_SCROLL_UP)
+    int delta_y = 0;
+    if(dt_gui_get_scroll_unit_deltas(e, NULL, &delta_y))
     {
-      if(z != DT_LIB_TIMELINE_ZOOM_HOUR) z++;
-    }
-    else if(e->direction == GDK_SCROLL_DOWN)
-    {
-      if(z != DT_LIB_TIMELINE_ZOOM_YEAR) z--;
+      if(delta_y < 0)
+      {
+        if(z != DT_LIB_TIMELINE_ZOOM_HOUR) z++;
+      }
+      else if(delta_y > 0)
+      {
+        if(z != DT_LIB_TIMELINE_ZOOM_YEAR) z--;
+      }
     }
 
     // if the zoom as changed, we need to recompute blocks and redraw
@@ -1408,8 +1422,8 @@ static gboolean _lib_timeline_scroll_callback(GtkWidget *w, GdkEventScroll *e, g
     int delta;
     if(dt_gui_get_scroll_unit_delta(e, &delta))
     {
-      int move = -delta;
-      if(e->state & GDK_SHIFT_MASK) move *= 2;
+      int move = delta;
+      if(dt_modifier_is(e->state, GDK_SHIFT_MASK)) move *= 2;
 
       _time_add(&(strip->time_pos), move, strip->zoom);
       // we ensure that the fimlstrip stay in the bounds
@@ -1469,11 +1483,12 @@ void gui_init(dt_lib_module_t *self)
   d->time_pos = d->time_mini;
   /* creating drawing area */
   self->widget = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+  dt_gui_add_help_link(self->widget, dt_get_help_url(self->plugin_name));
 
   /* creating timeline box*/
   d->timeline = gtk_event_box_new();
 
-  gtk_widget_add_events(d->timeline, GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_PRESS_MASK
+  gtk_widget_add_events(d->timeline, GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK
                                          | GDK_BUTTON_RELEASE_MASK | darktable.gui->scroll_mask
                                          | GDK_LEAVE_NOTIFY_MASK);
 
@@ -1491,7 +1506,7 @@ void gui_init(dt_lib_module_t *self)
   gtk_box_pack_start(GTK_BOX(self->widget), d->timeline, TRUE, TRUE, 0);
 
   // we update the selection with actual collect rules
-  _lib_timeline_collection_changed(NULL, DT_COLLECTION_CHANGE_NEW_QUERY, NULL, -1, self);
+  _lib_timeline_collection_changed(NULL, DT_COLLECTION_CHANGE_NEW_QUERY, DT_COLLECTION_PROP_UNDEF, NULL, -1, self);
 
   /* initialize view manager proxy */
   darktable.view_manager->proxy.timeline.module = self;
