@@ -162,10 +162,9 @@ static int write_image(lua_State *L)
   gboolean export_masks = dt_conf_get_bool("plugins/lighttable/export/export_masks");
   // TODO: expose icc overwrites to the user!
   dt_colorspaces_color_profile_type_t icc_type = dt_conf_get_int("plugins/lighttable/export/icctype");
-  gchar *icc_filename = dt_conf_get_string("plugins/lighttable/export/iccprofile");
+  const char *icc_filename = dt_conf_get_string_const("plugins/lighttable/export/iccprofile");
   gboolean result = dt_imageio_export(imgid, filename, format, fdata, high_quality, upscale, FALSE, export_masks,
                                       icc_type, icc_filename, DT_INTENT_LAST, NULL, NULL, 1, 1, NULL);
-  g_free(icc_filename);
   dt_lua_lock();
   lua_pushboolean(L, result);
   format->free_params(format, fdata);
