@@ -1,6 +1,6 @@
 /*
    This file is part of darktable,
-   Copyright (C) 2013-2020 darktable developers.
+   Copyright (C) 2013-2021 darktable developers.
 
    darktable is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,13 +22,13 @@
 
 void dt_lua_push_glist_type(lua_State *L, GList *list, luaA_Type elt_type)
 {
-  GList *elt = list;
   lua_newtable(L);
-  while(elt)
+  int index_table = 1;
+  for(const GList *elt = list; elt; elt = g_list_next(elt))
   {
     luaA_push_type(L, elt_type, elt->data);
-    luaL_ref(L, -2);
-    elt = g_list_next(elt);
+    lua_seti(L, -2, index_table);
+    index_table++;
   }
 }
 
