@@ -127,7 +127,7 @@ static int async_lib_call(lua_State * L)
   const char* event = lua_tostring(L,1);
   dt_lib_module_t * module = *(dt_lib_module_t**)lua_touserdata(L,2);
   dt_lua_module_entry_push(L,"lib",module->plugin_name);
-  lua_getuservalue(L,-1);
+  lua_getiuservalue(L, -1, 1);
   lua_getfield(L,-1,event);
   if(lua_isnoneornil(L,-1)) {
     lua_pop(L,7);
@@ -191,7 +191,6 @@ static dt_lib_module_t ref_lib = {
   .init_presets = NULL,
   .init_key_accels = NULL,
   .connect_key_accels = NULL,
-  .accel_closures = NULL,
   .reset_button = NULL,
   .presets_button = NULL,
   .view_enter = view_enter_wrapper,
@@ -210,7 +209,7 @@ static int register_lib(lua_State *L)
   dt_lua_lib_register(L, lib);
   /* push the object on the stack to have its metadata */
   dt_lua_module_entry_push(L,"lib",lib->plugin_name);
-  lua_getuservalue(L,-1);
+  lua_getiuservalue(L, -1, 1);
   lua_pushvalue(L, 1);
   lua_setfield(L, -2, "plugin_name");
   const char *name = luaL_checkstring(L, 2);
