@@ -234,6 +234,7 @@ static int tag_lib_find(lua_State *L)
 int dt_lua_tag_get_attached(lua_State *L)
 {
   dt_lua_image_t imgid;
+  int table_index = 1;
   luaA_to(L, dt_lua_image_t, &imgid, 1);
   sqlite3_stmt *stmt;
 
@@ -246,7 +247,8 @@ int dt_lua_tag_get_attached(lua_State *L)
   {
     int tagid = sqlite3_column_int(stmt, 0);
     luaA_push(L, dt_lua_tag_t, &tagid);
-    luaL_ref(L, -2);
+    lua_seti(L, -2, table_index);
+    table_index++;
     rv = sqlite3_step(stmt);
   }
   sqlite3_finalize(stmt);
@@ -257,6 +259,7 @@ int dt_lua_tag_get_attached(lua_State *L)
 int dt_lua_tag_get_tagged_images(lua_State *L)
 {
   dt_lua_tag_t tagid;
+  int table_index = 1;
   luaA_to(L, dt_lua_tag_t, &tagid, 1);
   sqlite3_stmt *stmt;
 
@@ -269,7 +272,8 @@ int dt_lua_tag_get_tagged_images(lua_State *L)
   {
     int imgid = sqlite3_column_int(stmt, 0);
     luaA_push(L, dt_lua_image_t, &imgid);
-    luaL_ref(L, -2);
+    lua_seti(L, -2, table_index);
+    table_index++;
     rv = sqlite3_step(stmt);
   }
   sqlite3_finalize(stmt);
@@ -295,7 +299,7 @@ int dt_lua_init_tags(lua_State *L)
   lua_pushcclosure(L, dt_lua_type_member_common, 1);
   dt_lua_type_register_const(L, dt_lua_tag_t, "detach");
   lua_pushcfunction(L, tag_tostring);
-  dt_lua_type_setmetafield(L,dt_lua_tag_t,"__tostring");
+  dt_lua_type_setmetafield(L, dt_lua_tag_t, "__tostring");
 
   /* tags */
   dt_lua_push_darktable_lib(L);
