@@ -346,7 +346,6 @@ int dt_view_manager_switch_by_view(dt_view_manager_t *vm, const dt_view_t *nv)
       GtkWidget *w = dt_lib_gui_get_expander(plugin);
 
       if(plugin->connect_key_accels) plugin->connect_key_accels(plugin);
-      dt_lib_connect_common_accels(plugin);
 
       /* if we didn't get an expander let's add the widget */
       if(!w) w = plugin->widget;
@@ -644,353 +643,6 @@ void dt_view_set_scrollbar(dt_view_t *view, float hpos, float hlower, float hsiz
     dt_ui_update_scrollbars(darktable.gui->ui);
 }
 
-static int _images_to_act_on_find_custom(gconstpointer a, gconstpointer b)
-{
-  return (GPOINTER_TO_INT(a) != GPOINTER_TO_INT(b));
-}
-static void _images_to_act_on_insert_in_list(GList **list, const int imgid, gboolean only_visible)
-{
-  if(only_visible)
-  {
-    if(!g_list_find_custom(*list, GINT_TO_POINTER(imgid), _images_to_act_on_find_custom))
-      *list = g_list_append(*list, GINT_TO_POINTER(imgid));
-    return;
-  }
-
-  const dt_image_t *image = dt_image_cache_get(darktable.image_cache, imgid, 'r');
-  if(image)
-  {
-    const int img_group_id = image->group_id;
-    dt_image_cache_read_release(darktable.image_cache, image);
-
-    if(!darktable.gui
-       || !darktable.gui->grouping
-       || darktable.gui->expanded_group_id == img_group_id
-       || !dt_selection_get_collection(darktable.selection))
-    {
-      if(!g_list_find_custom(*list, GINT_TO_POINTER(imgid), _images_to_act_on_find_custom))
-        *list = g_list_append(*list, GINT_TO_POINTER(imgid));
-    }
-    else
-    {
-      sqlite3_stmt *stmt;
-      gchar *query = g_strdup_printf(
-          "SELECT id"
-          "  FROM main.images"
-          "  WHERE group_id = %d AND id IN (%s)",
-          img_group_id, dt_collection_get_query_no_group(dt_selection_get_collection(darktable.selection)));
-      DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query, -1, &stmt, NULL);
-      while(sqlite3_step(stmt) == SQLITE_ROW)
-      {
-        const int imgidg = sqlite3_column_int(stmt, 0);
-        if(!g_list_find_custom(*list, GINT_TO_POINTER(imgidg), _images_to_act_on_find_custom))
-          *list = g_list_append(*list, GINT_TO_POINTER(imgidg));
-      }
-      sqlite3_finalize(stmt);
-      g_free(query);
-    }
-  }
-}
-
-// get the list of images to act on during global changes (libs, accels)
-const GList *dt_view_get_images_to_act_on(const gboolean only_visible, const gboolean force,
-                                          const gboolean ordered)
-{
-  /** Here's how it works
-   *
-   *             mouse over| x | x | x |   |   |
-   *     mouse inside table| x | x |   |   |   |
-   * mouse inside selection| x |   |   |   |   |
-   *          active images| ? | ? | x |   | x |
-   *                       |   |   |   |   |   |
-   *                       | S | O | O | S | A |
-   *  S = selection ; O = mouseover ; A = active images
-   *  the mouse can be outside thumbtable in case of filmstrip + mouse in center widget
-   *
-   *  if only_visible is FALSE, then it will add also not visible images because of grouping
-   *  force define if we try to use cache or not
-   *  if ordered is TRUE, we return the list in the gui order. Otherwise the order is undefined (but quicker)
-   **/
-
-  const int mouseover = dt_control_get_mouse_over_id();
-
-  // if possible, we return the cached list
-  if(!force
-     && darktable.view_manager->act_on.ok
-     && darktable.view_manager->act_on.image_over == mouseover
-     && darktable.view_manager->act_on.ordered == ordered
-     && darktable.view_manager->act_on.inside_table
-            == dt_ui_thumbtable(darktable.gui->ui)->mouse_inside
-     && g_slist_length(darktable.view_manager->act_on.active_imgs)
-            == g_slist_length(darktable.view_manager->active_images))
-  {
-    // we test active images if mouse outside table
-    gboolean ok = TRUE;
-    if(!dt_ui_thumbtable(darktable.gui->ui)->mouse_inside
-       && darktable.view_manager->act_on.active_imgs)
-    {
-      GSList *l1 = darktable.view_manager->act_on.active_imgs;
-      GSList *l2 = darktable.view_manager->active_images;
-      while(l1 && l2)
-      {
-        if(GPOINTER_TO_INT(l1->data) != GPOINTER_TO_INT(l2->data))
-        {
-          ok = FALSE;
-          break;
-        }
-        l2 = g_slist_next(l2);
-        l1 = g_slist_next(l1);
-      }
-    }
-    if(ok) return darktable.view_manager->act_on.images;
-  }
-
-  GList *l = NULL;
-  gboolean inside_sel = FALSE;
-  if(mouseover > 0)
-  {
-    // column 1,2,3
-    if(dt_ui_thumbtable(darktable.gui->ui)->mouse_inside)
-    {
-      // column 1,2
-      sqlite3_stmt *stmt;
-      gchar *query = g_strdup_printf("SELECT imgid FROM main.selected_images WHERE imgid=%d", mouseover);
-      DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query, -1, &stmt, NULL);
-      if(stmt != NULL && sqlite3_step(stmt) == SQLITE_ROW)
-      {
-        inside_sel = TRUE;
-        sqlite3_finalize(stmt);
-      }
-      g_free(query);
-
-      if(inside_sel)
-      {
-        // column 1
-
-        // first, we try to return cached list if we were already
-        // inside sel and the selection has not changed
-        if(!force
-           && darktable.view_manager->act_on.ok
-           && darktable.view_manager->act_on.image_over_inside_sel
-           && darktable.view_manager->act_on.inside_table
-           && darktable.view_manager->act_on.ordered == ordered)
-        {
-          return darktable.view_manager->act_on.images;
-        }
-
-        // we return the list of the selection
-        l = dt_selection_get_list(darktable.selection, only_visible, ordered);
-      }
-      else
-      {
-        // column 2
-        _images_to_act_on_insert_in_list(&l, mouseover, only_visible);
-      }
-    }
-    else
-    {
-      // column 3
-      _images_to_act_on_insert_in_list(&l, mouseover, only_visible);
-      // be absolutely sure we have the id in the list (in darkroom,
-      // the active image can be out of collection)
-      if(!only_visible) _images_to_act_on_insert_in_list(&l, mouseover, TRUE);
-    }
-  }
-  else
-  {
-    // column 4,5
-    if(darktable.view_manager->active_images)
-    {
-      // column 5
-      for(GSList *ll = darktable.view_manager->active_images; ll; ll = g_slist_next(ll))
-      {
-        const int id = GPOINTER_TO_INT(ll->data);
-        _images_to_act_on_insert_in_list(&l, id, only_visible);
-        // be absolutely sure we have the id in the list (in darkroom,
-        // the active image can be out of collection)
-        if(!only_visible) _images_to_act_on_insert_in_list(&l, id, TRUE);
-      }
-    }
-    else
-    {
-      // column 4
-      // we return the list of the selection
-      l = dt_selection_get_list(darktable.selection, only_visible, ordered);
-    }
-  }
-
-  // let's register the new list as cached
-  darktable.view_manager->act_on.image_over_inside_sel = inside_sel;
-  darktable.view_manager->act_on.ordered = ordered;
-  darktable.view_manager->act_on.image_over = mouseover;
-  g_list_free(darktable.view_manager->act_on.images);
-  darktable.view_manager->act_on.images = l;
-  g_slist_free(darktable.view_manager->act_on.active_imgs);
-  darktable.view_manager->act_on.active_imgs = g_slist_copy(darktable.view_manager->active_images);
-  darktable.view_manager->act_on.inside_table = dt_ui_thumbtable(darktable.gui->ui)->mouse_inside;
-  darktable.view_manager->act_on.ok = TRUE;
-
-  if((darktable.unmuted & DT_DEBUG_ACT_ON) == DT_DEBUG_ACT_ON)
-  {
-    gchar *tx = dt_util_dstrcat(NULL, "[images to act on] images list : ");
-    for(GList *ll = darktable.view_manager->act_on.images; ll; ll = g_list_next(ll))
-      tx = dt_util_dstrcat(tx, "%d ", GPOINTER_TO_INT(ll->data));
-    dt_print(DT_DEBUG_ACT_ON, "%s\n", tx);
-    g_free(tx);
-  }
-
-  return darktable.view_manager->act_on.images;
-}
-
-// get the query to retrieve images to act on. this is useful to speedup actions if they already use sqlite queries
-gchar *dt_view_get_images_to_act_on_query(const gboolean only_visible)
-{
-  /** Here's how it works
-   *
-   *             mouse over| x | x | x |   |   |
-   *     mouse inside table| x | x |   |   |   |
-   * mouse inside selection| x |   |   |   |   |
-   *          active images| ? | ? | x |   | x |
-   *                       |   |   |   |   |   |
-   *                       | S | O | O | S | A |
-   *  S = selection ; O = mouseover ; A = active images
-   *  the mouse can be outside thumbtable in case of filmstrip + mouse in center widget
-   *
-   *  if only_visible is FALSE, then it will add also not visible images because of grouping
-   *  due to dt_selection_get_list_query limitation, order is always considered as undefined
-   **/
-
-  const int mouseover = dt_control_get_mouse_over_id();
-
-  GList *l = NULL;
-  gboolean inside_sel = FALSE;
-  if(mouseover > 0)
-  {
-    // column 1,2,3
-    if(dt_ui_thumbtable(darktable.gui->ui)->mouse_inside)
-    {
-      // column 1,2
-      sqlite3_stmt *stmt;
-      gchar *query = g_strdup_printf("SELECT imgid FROM main.selected_images WHERE imgid =%d", mouseover);
-      DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), query, -1, &stmt, NULL);
-      if(stmt != NULL && sqlite3_step(stmt) == SQLITE_ROW)
-      {
-        inside_sel = TRUE;
-        sqlite3_finalize(stmt);
-      }
-      g_free(query);
-
-      if(inside_sel)
-      {
-        // column 1
-        return dt_selection_get_list_query(darktable.selection, only_visible, FALSE);
-      }
-      else
-      {
-        // column 2
-        _images_to_act_on_insert_in_list(&l, mouseover, only_visible);
-      }
-    }
-    else
-    {
-      // column 3
-      _images_to_act_on_insert_in_list(&l, mouseover, only_visible);
-      // be absolutely sure we have the id in the list (in darkroom,
-      // the active image can be out of collection)
-      if(!only_visible) _images_to_act_on_insert_in_list(&l, mouseover, TRUE);
-    }
-  }
-  else
-  {
-    // column 4,5
-    if(darktable.view_manager->active_images)
-    {
-      // column 5
-      for(GSList *ll = darktable.view_manager->active_images;
-          ll;
-          ll = g_slist_next(ll))
-      {
-        const int id = GPOINTER_TO_INT(ll->data);
-        _images_to_act_on_insert_in_list(&l, id, only_visible);
-        // be absolutely sure we have the id in the list (in darkroom,
-        // the active image can be out of collection)
-        if(!only_visible) _images_to_act_on_insert_in_list(&l, id, TRUE);
-      }
-    }
-    else
-    {
-      // column 4
-      return dt_selection_get_list_query(darktable.selection, only_visible, FALSE);
-    }
-  }
-
-  // if we don't return the selection, we return the list of imgid separated by comma
-  // in the form it can be used inside queries
-  gchar *images = NULL;
-  for(; l; l = g_list_next(l))
-  {
-    images = dt_util_dstrcat(images, "%d,", GPOINTER_TO_INT(l->data));
-  }
-  if(images)
-  {
-    // remove trailing comma
-    images[strlen(images) - 1] = '\0';
-  }
-  else
-    images = g_strdup(" ");
-  return images;
-}
-
-// get the main image to act on during global changes (libs, accels)
-int dt_view_get_image_to_act_on()
-{
-  /** Here's how it works -- same as for list, except we don't care about mouse inside selection or table
-   *
-   *             mouse over| x |   |   |
-   *          active images| ? |   | x |
-   *                       |   |   |   |
-   *                       | O | S | A |
-   *  First image of ...
-   *  S = selection ; O = mouseover ; A = active images
-   **/
-
-  int ret = -1;
-  const int mouseover = dt_control_get_mouse_over_id();
-
-  if(mouseover > 0)
-  {
-    ret = mouseover;
-  }
-  else
-  {
-    if(darktable.view_manager->active_images)
-    {
-      ret = GPOINTER_TO_INT(darktable.view_manager->active_images->data);
-    }
-    else
-    {
-      sqlite3_stmt *stmt;
-      DT_DEBUG_SQLITE3_PREPARE_V2
-        (dt_database_get(darktable.db),
-         "SELECT s.imgid"
-         " FROM main.selected_images as s, memory.collected_images as c"
-         " WHERE s.imgid=c.imgid"
-         " ORDER BY c.rowid LIMIT 1",
-                                  -1, &stmt, NULL);
-      if(stmt != NULL && sqlite3_step(stmt) == SQLITE_ROW)
-      {
-        ret = sqlite3_column_int(stmt, 0);
-      }
-      if(stmt) sqlite3_finalize(stmt);
-    }
-  }
-
-  if((darktable.unmuted & DT_DEBUG_ACT_ON) == DT_DEBUG_ACT_ON)
-    dt_print(DT_DEBUG_ACT_ON, "[images to act on] single image : %d\n", ret);
-
-  return ret;
-}
-
 dt_view_surface_value_t dt_view_image_get_surface(int imgid, int width, int height, cairo_surface_t **surface,
                                                   const gboolean quality)
 {
