@@ -18,6 +18,7 @@
 
 #pragma once
 
+#include "common/act_on.h"
 #include "common/action.h"
 #include "common/history.h"
 #include "common/image.h"
@@ -160,14 +161,6 @@ typedef enum dt_view_image_over_t
   DT_VIEW_END     = 10, // placeholder for the end of the list
 } dt_view_image_over_t;
 
-// get images to act on for gloabals change (via libs or accels)
-// no need to free the list - done internally
-const GList *dt_view_get_images_to_act_on(const gboolean only_visible, const gboolean force,
-                                          const gboolean ordered);
-gchar *dt_view_get_images_to_act_on_query(const gboolean only_visible);
-// get the main image to act on during global changes (libs, accels)
-int dt_view_get_image_to_act_on();
-
 /** returns an uppercase string of file extension **plus** some flag information **/
 char* dt_view_extend_modes_str(const char * name, const gboolean is_hdr, const gboolean is_bw, const gboolean is_bw_flow);
 /** expose an image and return a cair0_surface. */
@@ -204,16 +197,9 @@ typedef struct dt_view_manager_t
     gboolean prevent_refresh;
   } accels_window;
 
-  struct
-  {
-    GList *images;
-    gboolean ok;
-    int image_over;
-    gboolean inside_table;
-    GSList *active_imgs;
-    gboolean image_over_inside_sel;
-    gboolean ordered;
-  } act_on;
+  // cached list of images to act on
+  dt_act_on_cache_t act_on_cache_all;
+  dt_act_on_cache_t act_on_cache_visible;
 
   /* reusable db statements
    * TODO: reconsider creating a common/database helper API
@@ -243,7 +229,7 @@ typedef struct dt_view_manager_t
   } audio;
 
   // toggle button for guides (in the module toolbox)
-  GtkWidget *guides_toggle, *guides, *guides_popover;
+  GtkWidget *guides_toggle, *guides, *guides_colors, *guides_popover;
 
   /*
    * Proxy
